@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item Y2K
[Year 2000] [problem] (slang)

@item YAAS
Yet Another Acronym Server (WWW)

@item YABA
Yet Another Bloody Acronym (slang)

@item YACC
Yet Another Compiler Compiler (Unix)

@item YACY
Yet Another CYberspace (P2P), "YaCy"

@item YADE
Yet Another DSSSL Engine (DSSSL)

@item YAFFS
Yet Another Flash File System (FS, Flash)

@item YAFIYGI
You asked for it, you got it (Usenet, IRC, slang)

@item YAGNI
Youn Ain't Gonna Need It (slang, Usenet, IRC)

@item YAHOO
Yet Another Hierarchically Officious Oracle (WWW)

@item YAML
Yet Another Multicolumn Layout (HTML, XHTML, CSS)

@item YAPC
Yet Another PERL Conference (PERL)

@item YARN
Yet Another Resource Negotiator (Hadoop)

@item YASOS
Yet Another Scheme Object System

@item YAST
Yet Another Setup Tool (Linux, SUSE), "YaST"

@item YAUN
Yet Another Unix Nerd

@item YAY
Yet Another YACC (YACC, Bull)

@item YCPS
Yale Center for Parallel Supercomputing (org., USA, HPC)

@item YGWYPF
You Get What You Pay For (slang, Usenet, IRC)

@item YHTWFWYWTS
You Have To Wait For What You Want To See (slang, WYSIWYG)

@item YLOD
Yellow Light Of Death (Sony, Playstation)

@item YMMD
You Made My Day (slang, Usenet, IRC)

@item YMMV
Your Mileage May Vary (slang)

@item YOU
YAST Online Update (YAST, Linux, SuSE)

@item YOYO
You're On Your Own (slang, Usenet, IRC)

@item YSM
Yourdon Structured Method

@item YST
Yukon Standard Time [-0900] (TZ)

@end table

