@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item D2B
Domestic Digital Bus

@item D2D2T
Disk To Disk To Tape (Streamer, LTO)

@item D3D
Direct3D (DirectX, MS)

@item D3DRM
Direct3D Retained Mode (DirectX, MS)

@item DA
Data Area (CD-MRW, SA)

@item DA
Destination [MAC] Address (SNA, Token Ring, ATM, FDDI, ...)

@item DA
Digital-to-Analog (D/A), "D/A"

@item DA11
DatenAustauschphase 11 [allgemeine bauabrechnung] (GAEB)

@item DA81
DatenAustauschphase 81 [leistungsverzeichnis] (GAEB)

@item DA82
DatenAustauschphase 82 [kostenanschlag] (GAEB)

@item DA83
DatenAustauschphase 83 [angebotsanforderung] (GAEB)

@item DA84
DatenAustauschphase 84 [angebotsabgabe] (GAEB)

@item DA85
DatenAustauschphase 85 [nebenangebot] (GAEB)

@item DA86
DatenAustauschphase 86 [zuschlag/auftragserteilung] (GAEB)

@item DAA
Device Access Architecture (Vireo)

@item DAA
Digest Access Authentication (HTTP)

@item DAAP
Digital Audio Access Protocol (DMAP, Apple)

@item DAAS
Desktop As A Service, "DaaS"

@item DAB
Digital Audio Broadcasting

@item DAC
Digital to Analog Converter

@item DAC
Direct Attached Copper

@item DAC
Discretionary Access Control (Unix, Linux, MAC)

@item DAC
Dual Address Cycle (PCI)

@item DAC
Dual Attached Concentrator (FDDI)

@item DACAPO
??? [hardware description language] (HDL)

@item DACL
Discretionary Access Control List (ACL)

@item DACNOS
Distributed Academic Computing Network Operating System (OS, HECTOR)

@item DACS
Digital Access Control System (ISDN, DES, cryptography)

@item DACS
Distributed Access Control System (Apache)

@item DACT
DAta Compression Technology

@item DAD
Desktop Application Director (WordPerfect)

@item DAD
Duplicate Address Detection (NDP, IPv6)

@item DADIU
Danske Akademi for Digital Interaktiv Underholdning (org., Denmark)

@item DAE
Digital Audio Extraction (CD, audio)

@item DAEMON
Disk And Execution MONitor (Unix)

@item DAF
Distributed Application Framework (CCITT)

@item DAG
DatenAnschaltGeraet

@item DAG
Directed Acyclic Graph (NVSG)

@item DAI
??? (Sun)

@item DAI
Device Application Interface (Novell, Netware, SMS)

@item DAI
Distributed Artificial Intelligence (AI)

@item DAIDALOS
Designing Advanced network Interfaces for the Delivery and Administration of Location independent, Optimized personal Services (Europe)

@item DAINET
Deutsches AgrarInformationsNETz (WWW, org.)

@item DAIS
Database Access and Integration Services (GGF, WG, grid, OGSA)

@item DAIS
Distributed Application Integration System (ORB)

@item DAISGR
Database Access and Integration Service Group Registry (DAIS, grid)

@item DAISY
Digital Accessible Information System

@item DAL
Data Access Language (Apple)

@item DALI
Distributed Artificial LIfe (AI), "DALi"

@item DAM
Debian Account Manager (Linux, Debian)

@item DAM
Digital Asset Management

@item DAM
Direct Access Method / Mode (DAM, SAM)

@item DAM
Distributed Abstract Machine

@item DAM
Draft AMendment (ISO)

@item DAMLOIL
DARPA Agent Markup Language and Ontology Inference Layer (DARPA, RDF, KM), "DAML+OIL"

@item DAMQAM
Dynamically Adaptive Multicarrier Quadrature Amplitude Modulation

@item DANA
De.Admin.News.Announce (Usenet), "D.A.N.A."

@item DANE
DNS-based Authentication of Named Entities (DNS, DNSSEC, cryptography)

@item DANTE
Delivery of Advanced Network Technology to Europe (org., Europe)

@item DANTE
Deutschsprachige ANwendervereinigung TEx [e.v.] (TeX, user group, org.)

@item DAO
Data Access Objects (DB)

@item DAO
Destination Address Omitted [flag] (CATNIP)

@item DAO
Disk At Once (CD-R, SAO)

@item DAP
Data Access Protocol (DEC, DNA)

@item DAP
Developers Assistance Program (IBM)

@item DAP
Directory Access Protocol (X.500, DS)

@item DAP
Directory Application Protocol (IN)

@item DAP
Document Application Profile (JTC1, ODIF, ODA)

@item DAPE
Distributed Application Programming Environment (ORB)

@item DAPHNE
Document Application Processing in a Heterogeneous Network Environment

@item DAPIE
Developer API Extensions (IBM, OS/2, API)

@item DARI
Database Application Remote Interface (IBM, DB)

@item DARMP
Defense Automation Resources Management Program (mil., USA)

@item DARPA
Defense Advanced Research Projects Agency (org., USA)

@item DARSIMCO
DARtmouth SINplified COde, "Darsimco"

@item DART
Dynamic Advertising Reporting & Targeting [technology] (WWW, Doubleclick)

@item DAS
Database Access Service (MS, MOM)

@item DAS
Direct Attached Storage

@item DAS
Directory Assistance Service [protocol] (RFC 1202)

@item DAS
Disk Array Subsystem (Unix, HP-UX)

@item DAS
Dual Attached Station (FDDI)

@item DAS
Dual Attachment Station (FDDI, Schneider & Koch)

@item DAS
Dynamic Allocation Scheme [protocol]

@item DASD
Direct Access Storage Device

@item DASI
Dial Access Signaling Interface

@item DASP
Disk Anti Shock Protection (Acer)

@item DASP
Drive Active, Slave Present (IDE)

@item DASS
Digital Access Signaling System

@item DASS
Distributed Authentication Security Service (RFC 1507)

@item DAT
Digital Audio Tape (Digital audio)

@item DATEV
DATEnVerarbeitungszentrale der steuerberatenden Berufe (org., Nuernberg, Germany)

@item DATEX
DATa EXchange

@item DATEXJ
DATa EXchange - Jedermann (DTAG), "DATEX-J"

@item DATEXL
DATa EXchange - Leitungsvermittlung

@item DATEXM
DATa EXchange - Multimegabit (DTAG, SMDS, BIT), "DATEX-M"

@item DATEXP
DATa EXchange - Packetized / Packetvermittlung (DTAG, X.25), "DATEX-P"

@item DAU
Duemmster Anzunehmender User (slang, Usenet, IRC)

@item DAV
[WWW] Distributed Authoring Versioning (WWW, HTTP)

@item DAV
Digital Audio Video (Apple, Digital audio)

@item DAVIC
Digital Audio Visual Interoperatibility Council (org., Digital audio)

@item DAVID
Digital Audio Video Interactive Decoder (Digital audio)

@item DAVIS
DAimler-Benz Vertragspartner-InformationsSystem (MBAG)

@item DAW
Digital Audio Workstation

@item DAWAK
DAta WArehousing and Knowledge discovery

@item DAWN
Defense Attache Worldwide Network (network, mil.)

@item DAX
Developer API eXtension (OS/2, IBM, API)

@item DB
DataBase

@item DB2
DataBase 2 (IBM, DB)

@item DB2CS
DataBase 2 Client/Server (IBM, DB2, DB), "DB2 C/S"

@item DB2SDK
DataBase 2 Software Development Toolkit (DB2, IBM, DB), "DB2 SDK"

@item DBA
DataBase Administrator (DB)

@item DBA
Drei Buchstaben Akronym

@item DBAC
DataBase Administration Center (DB)

@item DBAS
DataBase Administration System (DB)

@item DBC
Design By Contract

@item DBC
Device Bay Controller

@item DBCS
Double-Byte Character Set

@item DBD
DataBase Description (IBM, DB)

@item DBDMA
Descriptor Based Direct Memory Access (Apple, DMA)

@item DBEF
Dual Brightness Enhancement Foile (LCD)

@item DBI
DataBase Interface (DB)

@item DBL
DataBase Language (DB)

@item DBLO
Dual Beam Landing Optimizer

@item DBLT
Dynamic Back Link Technology (WWW)

@item DBM
DataBase Manager (DB)

@item DBME
DataBase Management Environment (DB)

@item DBMS
DataBase Management System (DB)

@item DBOS
Disk/Drum Based Operating System (OS)

@item DBP
DataBase Publishing (DB)

@item DBP
Delay Bandwidth Product

@item DBRAD
Data Base Relational Application Directory (DB)

@item DBRM
Data Base Request Module (DB)

@item DBS
Demand-Based Switching (Intel, Xeon)

@item DBS
Deutscher Bildungs-Server (DFN, WWW)

@item DBS
Duplex Bus Selector

@item DBSC
Dynamic Beam Spot Control (Eizo)

@item DBTG
Data Base Task Group (CODASYL, DB)

@item DBVS
DatenBankVerwaltungsSystem (DB)

@item DC
Data Cartridge

@item DC
Data-to-Clock [jitter] (DVD)

@item DC
Device Context

@item DC
Dublin Core [meta data]

@item DCA
Data Center Automation

@item DCA
Defense Communications Agency (org., USA, mil., predecessor, DISA)

@item DCA
Digital Communication Associates

@item DCA
Digital Controlled Amplifier (VCA)

@item DCA
Distributed Communication Architecture (Sperry Univac)

@item DCA
Document Center Architecture

@item DCA
Document Content Architecture (IBM, CCS)

@item DCA2
Dynamic Cache Architecture [level] 2

@item DCAF
Distributed Console Access Facility

@item DCAP
Data link switching Client Access Protocol (DLSW, RFC 2114)

@item DCB
Data Center Bridging (FCoE, QoS)

@item DCB
Data Control Block

@item DCB
Disk Coprocessor Board (Novell, SCSI, HBA)

@item DCBX
Data Center Bridging eXchange (LLDP, DCB)

@item DCC
Data Communications Computer

@item DCC
Data Country Code (ATM)

@item DCC
Desktop Control Center (Intel)

@item DCC
Digital Content Creation

@item DCC
Direct Client to Client (IRC)

@item DCC
Display Combination Code

@item DCC
DOS Command Center

@item DCCA
Dependable Computing for Critical Applications (Konferenz)

@item DCCA
Distributed Component Computing Architecture (Star, C/S)

@item DCCH
Dedicated Control CHannel (GSM, mobile-systems)

@item DCCP
Datagram Congestion Control Protocol

@item DCCS
DisContiguous Shared Segments

@item DCD
Data Carrier Detect (MODEM, RS-232)

@item DCDB
Domain Control DataBase (Domain)

@item DCE
[picture publisher] Digital Camera Edition (Micrografx)

@item DCE
Data Circuit terminating Equipment (X.25, CCITT, IBM, HP, DEC, Tandem, Sun)

@item DCE
Data Communications Equipment

@item DCE
Distributed Computing Environment (OSF)

@item DCERPC
Distributed Computing Environment / Remote Procedure Call (DCE, RPC), "DCE/RPC" , "DCE RPC"

@item DCF
Design rule for Camera File system (JEIDA, photo)

@item DCF
Distributed Coordination Function (MAC, 802.11a, WLAN)

@item DCHSDPA
Dual Cell High Speed Downlink Packet Access (HSDPA, mobile-systems), DC-HSDPA

@item DCI
Data Capture Interface (UMA)

@item DCI
Device Control Interface

@item DCI
Digital Cinema Initiative (DCI, org.)

@item DCI
Display Control Interface (MS, Windows, Intel)

@item DCL
Data Center Linux (Linux, OSDL)

@item DCL
Data Control Language

@item DCL
DEC Control Language (DEC)

@item DCL
Digital Command [scripting] Language (DEC, VMS)

@item DCLU
Digital Carrier Line Unit

@item DCLZ
Data Compression Lempel-Ziv

@item DCM
Digital Carrier Module

@item DCM
Domain Controller Master (Debian, Univention)

@item DCM
Dual Chip Modul

@item DCM
Dual Core Modul (IBM, QCM)

@item DCME
Digital Circuit Multiplication Equipment

@item DCNA
Data Communication Network Architecture

@item DCO
Device Configuration Overlay (ATA)

@item DCO
Digital Controlled Oscillator

@item DCOF
Digital Print Order Format

@item DCOM
Distributed Component Object Model (COM, MS, OLE, ActiveX)

@item DCOP
Desktop COmmunication Protocol (Linux, KDE)

@item DCP
Data Compression Protocol (Motorola)

@item DCP
Digital Cinema Package (DCI)

@item DCPS
Data Communications Protocol Standards

@item DCR
Design Change Request (AIX, IBM)

@item DCRC
Digital Cellular Radio Conference (GSM, conference, mobile-systems)

@item DCS
Damage Cleanup Service (Firewall, TrendMicro)

@item DCS
Data sharing Control System (NEC)

@item DCS
Defense Communications System (mil., USA)

@item DCS
Desktop Color Separation

@item DCS
Digital Cellular System (mobile-systems)

@item DCS
Digital Colour System (Adobe, Photoshop)

@item DCS
Digital Control System (NEC)

@item DCS
Digital Cross-connect System (DEC)

@item DCS
Distributed Control System

@item DCS
Dogital Camera System

@item DCSDFS
Dynamic Channel Selection/Dynamic Frequency Selection (HiperLAN/2, WLAN), "DCS/DFS"

@item DCT
Data Collection Terminator (BTX)

@item DCT
Defect-and-Change-Management (CICS, IBM)

@item DCT
Discrete Cosine Transformation (MPEG, JPEG)

@item DCTN
Defense Commercial Telephone Network (mil., USA, network)

@item DCU
Data Cache Unit (CPU, POWER)

@item DCUO
DC Universe Online (MMORPG)

@item DD
Dansk Dataforening (org., Denmark)

@item DD
Data Dictionary (SA, CASE, DB)

@item DD
Depacketization Delay

@item DD
Double Density [disks] (FDD)

@item DDA
Domain Defined Attribute (Domain)

@item DDA
Dynamic Data Authentication (EMV, cryptography)

@item DDBAC
Data-Design HBCI Banking Application Components (HBCI)

@item DDBMS
Distributed DataBase Management System (DBMS, DB)

@item DDC
Device Color Characterization (XCMS)

@item DDC
Display Data Channel (VESA)

@item DDC2B
Device Data Channel [standard], level 2B (DDC)

@item DDCD
Double Density Compact Disk (CD, Sony)

@item DDCDR
Double Density Compact Disk - Read (Sony, CD), "DDCD-R"

@item DDCDRW
Double Density Compact Disk - Read Write (Sony, CD), "DDCD-RW"

@item DDCMP
Digital Data Communication Message Protocol

@item DDCS2
Distributed Database Connection Services /2 (IBM, DB, DRDA), "DDCS/2"

@item DDD
Data Display Debugger (GNU)

@item DDD
Domain Driven Design (MDA)

@item DDDS
Dynamic Delegation Discovery System (ENUM, RFC 3401/3402/3403/3404/3405)

@item DDE
DatenenDEinrichtung

@item DDE
Dynamic Data Exchange

@item DDEP
Dynamic Data Execution Prevention (DEP)

@item DDES
Digital Data Exchange System (ANSI)

@item DDF
Data Decryption Field (cryptography)

@item DDI
Device Dependent Interface

@item DDI
Device Driver Interface

@item DDIMM
Dual [RAS] Dual Inline Memory Module (DIMM, RAS), "D-DIMM"

@item DDK
Device Development / Driver Kit (MS)

@item DDL
Data Definition Language

@item DDL
Document Description Language

@item DDM
Direct Drive Monitor

@item DDM
Distributed Data Management (IBM, CCS)

@item DDML
Display Driver Management Layer

@item DDN
Defense Data Network (USA, network, mil.)

@item DDNS
Distributed Domain Naming Service (TCP/IP)

@item DDNS
Dynamic Domain Name Service (OS/2, IBM)

@item DDO
Dynamic Drive Overlay (HDD, Ontrack)

@item DDOS
Distributed Denial Of Service [attack], "DDoS"

@item DDP
Datagram Delivery Protocol (AppleTalk)

@item DDP
Distributed Data Processing

@item DDR
Double Data Rate (SDR, QDR, ODR)

@item DDR
Dynamic Desktop Router (Cogent)

@item DDRAID
Distributed Data RAID (GFS, RAID, HDD), "DDRaid"

@item DDRS
Defense Data Repository System (mil., USA)

@item DDRSDRAM
Double Data Rate Synchronous Dynamic Random Access Memory (DRAM, RAM, IC), "DDR-SDRAM"

@item DDRSRAM
Double Data Rate Static Random Access Memory (RAM, IC)

@item DDS
Digital Data Service / System

@item DDS
Digital Data Storage (Sony, HP, DAT, ISO, ANSI, ECMA, Streamer)

@item DDS
Direct Digital Sampling (CD-RW, SCSI)

@item DDS
Distributed Directory Service (DCE)

@item DDSA
Digital Data Service Adapter

@item DDSDC
Digital Data Storage - Data Compression (DDS, DCLZ), "DDS-DC"

@item DDSS
Double Dynamic Suspension System (Asus, CD-ROM)

@item DDT
Dynamic Debugging Tool (DEC, CP/M)

@item DDU
Dialog Data Unit (BTX)

@item DDV
DatenDirektVerbindung (DTAG)

@item DDV
DES-DES-Verfahren (cryptography, HBCI)

@item DDV
Dialog Data Validation

@item DDVS
Daimler-benz DatenVerbundSystem (MBAG)

@item DDVT
Dynamic Dispatch Virtual Tables

@item DDWG
Digital Display Working Group (org., LCD)

@item DDX
Distributed Data eXchange

@item DE
DatenElement (HBCI)

@item DEA
Deterministischer Endlicher Automat

@item DEBI
DMA Extended Bus Interface (Acorn, DMA)

@item DEC
Digital Equipment Corporation (manufacturer)

@item DECIX
DEutscher Commercial Internet eXchange (Internet), "DE-CIX"

@item DECNET
Digital Equipment Corporation NETwork (DEC)

@item DECS
Domino Enterprise Connection Services (Lotus)

@item DECT
Digital European Cordless Telecommunications (telecommunication)

@item DECUS
Digital Equipment Computer Users Society (org., DEC, user group)

@item DEE
DatenEndEinrichtung

@item DEEP
Dynamical ExaScale Entry Platform (Europe)

@item DEG
DatenElementGruppen (HBCI)

@item DELNI
Digital Ethernet Local Network Interconnect (ethernet)

@item DELQA
Digital Ethernet Lowpower Q-bus network Adapter (ethernet)

@item DELTA
Developing European Learning through Technology Advance

@item DELUA
Digital Ethernet Lowpower Unibus network Adapter (ethernet)

@item DELUG
DEutsche Linux User Group (org., user group, Linux)

@item DEMARC
Distributed Enterprise Management ARChitecture (Banyan, VINES), "DeMarc"

@item DEMPR
Digital Ethernet Multi-Port Repeater (ethernet)

@item DEMUDI
DEbian MUltimedia DIstribution (Debian, Linux), "DeMuDi"

@item DEN
Directory Enabled Networking (MS)

@item DEN
Document Enabled Networking (Novell, Xerox)

@item DENIC
DEutsches Network Information Center, (org., Internet), "DE-NIC"

@item DENIM
Directory-Enabled Net Infrastructure Model (Novell)

@item DEP
Data Execution Prevention (MS, Windows, XP, SP2)

@item DEPCA
Digital Ethernet Personal Computer-bus Adapter (ethernet)

@item DEQNA
Digital Ethernet Q-bus Network Adapter (ethernet)

@item DER
Distinguished Encoding Rules

@item DERAT
Data cache Effective to Real Address Translation [table] (Power4, IBM, CPU, ERAT)

@item DEREP
Digital Ethernet REPeater (ethernet)

@item DES
Data Encryption Standard (cryptography, NIST, IBM)

@item DES
Destination End System

@item DESCBC
Data Encryption Standard/Cipher Block Chaining (DES), "DES/CBC"

@item DESE
[PPP] Data Encryption Standard Encryption protocol (PPP, RFC 1969)

@item DESIRE
DEsign by Simulation and REndering om parallel architectures [project] (ESPRIT)

@item DESP
Data Element Standardization Program

@item DESPR
Digital Ethernet Single Port Repeater (ethernet)

@item DESRT
DEStek [group] Real Time (OS, Destek Group), "DES RT"

@item DESTA
Digital Ethernet thin-wire STation Adapter (ethernet)

@item DESX
Data Encryption Standard eXtended (DES, cryptography)

@item DET
Directory Entry Table (Novell, Netware)

@item DETEBERKOM
DEutsche TElekom BERliner KOMmunikationssystem, "DeTeBerkom" 

@item DEUNA
Digital Ethernet Unibus Network Adapter (ethernet)

@item DEVFS
DEVice File System (Linux, DRI), "DevFS"

@item DEVIL
Developer's Image Library (OpenIL), "DevIL"

@item DEXA
[conference on] Database and EXpert systems Applications

@item DF
Direction Flag (assembler)

@item DF
Disk Free (Unix)

@item DFCL
Debian Free Content License (Debian, Linux)

@item DFD
Data Flow Diagram / DatenFlussDiagramm (CASE, SA)

@item DFD
Deutsches FernerkundungsDatenzentrum (org.)

@item DFDSM
Data Facility Distributed Storage Management (IBM)

@item DFG
Deutsche ForschungsGemeinschaft (org.)

@item DFI
Digital Facility Interface

@item DFKI
Deutsches Forschungszentrum fuer Kuenstliche Intelligenz (org., KI, AI)

@item DFM
Dynamic Frequency Management (PDA)

@item DFN
Deutsches ForschungsNetz [e.V.] (org., ISP)

@item DFNCERT
Deutsches ForschungsNetz Computer Emergency Response Team (DFN, Internet), "DFN CERT"

@item DFP
Data Facility Product

@item DFP
Digital Flat Panel [group / port] (LCD, org., Compaq, Acer, Fujitsu, ATI, Matrox, Samsung, ...)

@item DFP
Distributed Functional Plane (IN)

@item DFPP
Digital Flat Panel Port (LCD, DFP)

@item DFS
Deniable File System (FS)

@item DFS
Direct File System (Novell, Oracle)

@item DFS
Distributed File System (DCE)

@item DFS
Dynamic Frequency Selection (WLAN)

@item DFS
Dynamic Frequency Selection (WLAN)

@item DFSA
Direct File System Access

@item DFSG
Debian Free Software Guidelines (Linux, Debian)

@item DFT
Discrete Fourier Transformation

@item DFT
Distributed Function Terminal (IBM)

@item DFT
Drive Fitness Test (IBM, IDE, HDD)

@item DFU
Data File Utility (IBM, ADT)

@item DFUE
DatenFernUEbertragung

@item DFV
DatenFernVerarbeitung

@item DGA
Direct Graphics Access (XAA, X-Windows)

@item DGCC
DISA Global Control Center (DISA)

@item DGD
Deutsche Gesellschaft fuer Dokumentation [e.v.] (org.)

@item DGEMM
Double precision GEneral Matrix Multiply (GEMM, BLAS)

@item DGIS
Direct Graphics Interface Standard

@item DGP
Dissimilar Gateway Protocol

@item DGPS
Differential Global Positioning System (GPS)

@item DGS
Display GhostScript (GNU, GNUStep, PS)

@item DGSA
Defense Goal Security Architecture (mil., USA)

@item DGUX
Data General / UniX (Unix), "DG/UX" 

@item DHCF
Distributed Host Command Facility (IBM, CCS)

@item DHCP
Dynamic Host Configuration Protocol (TCP/IP, IETF, RFC 2131)

@item DHES
Direct Heat Exhaust System

@item DHIS
Distributed Heterogeneous Information Systems

@item DHT
Distribution Hash Table (P2P)

@item DHTML
Dynamic HyperText Markup Language (HTML)

@item DHWG
Digital Home Working Group (org.)

@item DI
Destination Index [register] (CPU, Intel, assembler)

@item DIA
Deutsche Informatik Akademie (org.)

@item DIA
Document Interchange Architecture (IBM, CCS)

@item DIACAP
Department of defense Information Assurance Certification and Accreditation Process

@item DIAMOND
Development and Integration of Accurate Mathematical Operations in Numerical Data-processing (ESPRIT)

@item DIANE
DIrect Access Network for Europe

@item DIAS
Digital Information Archiving System (IBM, Netherlands)

@item DIB
Defense Information Base (mil., USA)

@item DIB
Device Independent Bitmap (MS, Windows)

@item DIB
Director Interface Board (Airbus, A380, CIDS)

@item DIB
Directory Information Base (X.500, DS)

@item DIB
DOS Info Block (BIOS, DOS)

@item DIB
Dual Independent Bus [architecture] (PC)

@item DIBL
Drain Induced Barrier Lowering (IC, MOSFET)

@item DIC
Digital Interface Controller

@item DICE
Delivering Information in a Cellular Environment (SNI, Internet)

@item DICF
Dictionary InterChange Format (DICT)

@item DICOM
Digital Imaging and COmmunications in Medicine

@item DID
Digital Image Design

@item DIESEL
Dumb Interpretatively Evaluated String Expression Language (carCAD)

@item DIF
Directory Interoperability Forum (org., IBM, Lotus, Novell, Oracle, ...)

@item DIF
Document Interchange Format

@item DIFMOS
Double Injection Floating Gate MOS

@item DIFS
Distributed Coordination Function - InterFrame Space (MAC, 802.11a, DCF, IFS)

@item DIGI
Deutsche InteressenGemeinschaft Internet [e.v.] (org., ISP)

@item DII
Defense Information Infrastructure (mil., USA, DISA)

@item DII
Dynamic Invocation Interface

@item DIICC
Defense Information Infrastructure Control Concept (mil., USA)

@item DIICOE
Defense Info Infrastructure Common Operating Environment (DISA, mil., USA), "DII COE"

@item DIL
Dual InLine

@item DILA
Digital Direct Drive Image Light Amplifier (JVC, CMOS, LCOS, HDTV), "D-ILA"

@item DIME
Desktop Integrated Media Environment (COSE)

@item DIME
DIrect Memory Execute (AGP)

@item DIMM
Dual Inline Memory Module (IC)

@item DIMSS
DSN Integrated Management Support System (DSN, mil., USA)

@item DIN
Deutsches Institut fuer Normung (org.)

@item DINAH
Desktop INterface to AUTODIN Host (carDIN, mil., USA)

@item DINI
Deutsche Initiative fuer Netzwerkinformation Org., Germany

@item DINO
Deutsches InterNet Organisationssystem (WWW, Uni Goettingen, Germany)

@item DIO
Direct Input Output (I/O, HDD, SCSI)

@item DIP
Dial-up Internet Protocol (Linux)

@item DIP
Dual In-line Package (IC, DRAM)

@item DIPM
Device Initiated Power Management

@item DIRMU
DIstributed and Reconfigurable MUltiprocessor (MP)

@item DIS
Defense Information System (mil., USA)

@item DIS
Digital Identification Signal (HDLC)

@item DIS
Draft International Standard (ISO)

@item DISA
Data Interchange Standards Association (org.)

@item DISA
Defense Information Systems Agency (org., mil., USA)

@item DISAIS
DISA Information System (mil., USA), "DISA-IS"

@item DISANET
DISA Information Network (mil., USA, DISA, network), "DISANet"

@item DISC
Defense Information System Council (mil., USA)

@item DISK
Deutschsprachige Internationale SAS-benutzer Konferenz

@item DISN
Defense Information Systems Network (mil., USA)

@item DISNET
Defense Integrated Secure Network (network, mil., USA, predecessor, DSNET)

@item DISNNT
Defense Information Systems Network - Near Term (DISN, mil., USA), "DISN-NT"

@item DISOSS
DIStributed Office Support System (IBM, MVS)

@item DISP
Directory Information Shadowing Protocol

@item DISP
Draft International Standardized Profiles (ISO)

@item DISP
Dutch Independent Shareware Programmer (org., Netherlands), "D.I.S.P."

@item DISSP
Defense Information System Security Program (mil., USA)

@item DIT
Directory Information Tree (X.500, LDAP)

@item DITA
Darwin Information Typing Architecture (XML, IBM, OASIS)

@item DITCO
Defense Information Technology Contracting Office (org., mil., DISA, USA)

@item DITSCAP
Department of defense Information Technology Security Certification and Accreditation Process (DIACAP)

@item DITU
Data Interception Technology Unit

@item DIU
Digital Interface Unit

@item DIVE
Direct Interface Video Extensions (IBM, MMPM/2)

@item DIVX
DIgital Video eXpress (DVD), "Divx"

@item DIX
DEC, Intel, Xerox (ethernet, DEC, Intel, Xerox)

@item DJGCC
DJ's GNU C Compiler (GNU, DOS, GCC)

@item DJGPP
DJ's GNU Programming Platform (GNU, DOS, GPP)

@item DKE
Deutsche Kommission Elektrotechnik, elektronik, informationstechnik (org., DIN, VDE)

@item DKIM
Domain Keys Identified Mail (Domain)

@item DKRZ
Deutsches KlimaRechenZentrum (org.)

@item DL
Distribution List

@item DL
Dual / Double Layer (DVD)

@item DLC
Data Link Control

@item DLCI
Data Link Connection Identifier (ATM)

@item DLD
Deutsche Linux Distribution (Linux)

@item DLE
Data Link Escape

@item DLG
Digital Line Graph

@item DLHP
Deutsche Linux Howto Project (Linux)

@item DLJ
Distro License for Java (JRE, Linux)

@item DLKL
??? (DB)

@item DLL
Delay / Digitally Locked Loop (GDR-SDRAM)

@item DLL
Dynamic Link Library

@item DLL
Dynamic Link Loader (BS2000)

@item DLM
Distributed Lock Manager (Linux, RedHat, GFS)

@item DLMZB
Determine Left Most Zero Byte (IBM, PowerPC)

@item DLNA
Digital Living Network Alliance (org.)

@item DLP
Digital Light Processing (TI)

@item DLP
Discrete Logarithmic Problem

@item DLPI
Data Link Provider Interface (X/Open)

@item DLR
Dynamic Language Runtime (MS)

@item DLR
Dynamic Link Routine

@item DLS
DOS LAN Services (IBM, LAN Server)

@item DLS
DownLoadable Sounds

@item DLSW
Data Link SWitching (APPN, MPTN, RFC 1795, SNA, NETBIOS), "DLSw"

@item DLT
Digital Line Tape (DEC, Streamer)

@item DM
Delta Modulation

@item DM
DeMilitarisierte zone (Firewall)

@item DM
Development Machine (Corel)

@item DM
Device Mapper (Linux)

@item DM
Disconnect Mode (LAPB)

@item DMA
Direct Memory Access (DMA)

@item DMAC
Direct Memory Access Controller

@item DMAP
DECT Multimeda Access Protocol (DECT)

@item DMAP
Digital Media Access Protocol (Apple)

@item DMB
Digital Multimedia Broadcasting (DTAG, Blaupunkt, DAB, MPEG)

@item DMC
Desktop Multimedia Conferencing

@item DMCA
Digital Millennium Copyright Act (USA, DRM)

@item DMD
Device Manager Driver (OS/2)

@item DMD
Differential Mode Delay (Gigabit-, ethernet)

@item DMD
Digital Mars D [compiler]

@item DMD
Digital Micromirror Device (IC, DLP, TI)

@item DMD
Digital Multilayer Disk

@item DMD
Directory Management Domain (OSI, DS)

@item DMDAC
Dual MAC Dual Attached Concentrator (FDDI, DAC)

@item DMDD
Distributed Multiplexing Distributed Demultiplexing

@item DMDF
Distributed Management Data Facility (DCE, DME)

@item DME
Direct Memory Execution

@item DME
Distributed Management Environment (OSF)

@item DMERT
Duplex Multiple Environment, Real Time (OS, MERT)

@item DMF
Digest Message Format (Internet, RFC 1153)

@item DMF
Distribution Media Format [diskette] (FDD)

@item DMFC
Direct Methanol Fuel Cell

@item DMI
Definition of Management Information (OSI)

@item DMI
Desktop Management Interface (DTMF, DMI, BIOS)

@item DMI
Digital Multiplexed Interface

@item DML
Data Manipulation Language

@item DML
Data Manipulation Logic

@item DML
Distributed Mode Loudspeaker (audio)

@item DMMV
Deutscher MultiMedia Verband (org.)

@item DMOS
Diffusion Metal Oxide Semiconductor (IC)

@item DMP
Designated Mailers Protocol (SPAM)

@item DMP
Dot Matrix Printer

@item DMS
Data Management System

@item DMS
Data Management System (ESA, Venus-Express)

@item DMS
Defense Message System (mil., USA)

@item DMS
Digital Multiplexed System

@item DMS
Disk Monitor System (OS, IBM)

@item DMS
Distributed Media Services (COSE)

@item DMS
Document Management System

@item DMS
Document Management System (CMS)

@item DMSC
Drive Motor Speed Control

@item DMSCMS
Display Management System/Conversional Monitor System, "DMS/CMS" 

@item DMSIG
Defense Message System Implementation Group (org., DMS, mil., USA)

@item DMSP
Distributed Mail System Protocol (Internet)

@item DMSTWG
Defense Message System Transition Working Group (org., DMS, mil., USA)

@item DMT
Discrete Monitor Timings (VESA)

@item DMT
Discrete Multitone Technology (ADSL, Amati Communications, ANSI)

@item DMTF
Desktop Management Task Force

@item DMTF
Distributed Management Task Force

@item DMTU
Default Maximum Transmission Unit (MTU), "D-MTU"

@item DMU
Data Management Unit (ZFS)

@item DMU
Data Manipulation Unit

@item DMU
Digital Mock-Up

@item DMV
Daten- und MedienVerlag

@item DMV
Deutsche Mathematiker-Vereinigung (org.)

@item DMX
Distributed Multihead X (X-Windows)

@item DMZ
DeMilitarized Zone (LAN, Internet)

@item DN
Distinguished Name (X.500, LDAP)

@item DN
Distribution Network

@item DNA
Digital Network Architecture (DEC)

@item DNA
Direct Network Attach (Xyratex, RAID)

@item DNA
Distributed Network Architecture (NCR)

@item DNAE
DatenNetz-AnschlussEinrichtung (DTAG)

@item DNAT
Dynamic Network Address Translation

@item DNB
Dedicated Network Bus (Intel, MCH, CSA)

@item DNC
Direct Numerical Control (CNC)

@item DNC
Dynamic Network Controller

@item DNCMPE
Direct Numerical Control / ??? (CNC), "DNC/MPE"

@item DNCP
[PPP] DECNet phase iv Control Protocol (RFC 1762, DECNET, PPP)

@item DNCRI
Division of Networking and Communication Research and Infrastructure

@item DND
Den Norske Dataforening (org., Norway)

@item DNHR
Dynamic Non Hierarchical Routing

@item DNI
De.Newusers.Info (Usenet)

@item DNI
DECnet Network Interface

@item DNIC
Data Network Identification Code (X.121)

@item DNP
Distributed Network Protocol

@item DNQ
De.Newusers.Questions (Usenet)

@item DNR
Digital Noise Reduction

@item DNS
Domain Name System (Internet, RFC 1034/1035, DNS)

@item DNSO
Defense Network Systems Organization (org., USA, mil.)

@item DNSO
Domain Name Supporting Organization (org., ICANN)

@item DNSRR
Domain Name Service Round Robbing (DNS)

@item DNSTAN
Digitale NebenSTellenANlagen (DTAG), "DNStAn"

@item DNUG
Deutsche Notes User Group [e.v.] (org., user group, Lotus)

@item DNX
Departmental Network eXchange [bridging router] (SNA, SDLC, Proteon)

@item DO
Distributed Objects (NeXT)

@item DOAG
Deutsche Oracle AnwenderGruppe [e.V.] (Oracle, user group, org.)

@item DOAM
Distributed Office Applications Model (ISO, IEC, DIS 10031-1 f.)

@item DOAP
Description of a Project (XML)

@item DOC
De.Org.CCC (Usenet, CCC)

@item DOCC
DISA Operations Control Complex (DISA, mil., USA)

@item DOCSIS
Data Over Cable System Interface Specification (DOCSIS)

@item DOCSISOSS
DOCSIS Operations Suport Services (DOCSIS), "DOCSIS-OSS"

@item DODISS
Department Of Defense Index of Specifications and Standards (mil., USA)

@item DOE
Depends On Experience

@item DOE
Distributed Objects Everywhere (Sun)

@item DOI
Digital Object Identifier (IDF)

@item DOM
Disk On Module

@item DOM
Document Object Model (MS, Java)

@item DOM
Document Object Module (HTML, XML, API)

@item DOMAIN
Distributed Operating Multi Access Interactive Network (Apollo, DOMAIN)

@item DOME
Distributed Object Management Environment (ORB)

@item DOMF
Distributed Object Management Facility (Sun)

@item DOOM
Decentralised Object Orientated Machine

@item DOP
Directory Operational binding management Protocol

@item DOPE
Dartmouth Oversimplified Programming Experiment

@item DOS
Denial Of Service [attack], "DoS"

@item DOS
Disk Operating System (OS, IBM, MS, ..., PC, Apple, RCA Spectra 70)

@item DOS15
Disk Operating System - 15 (OS, DEC, PDP 15), "DOS-15"

@item DOS360
Disk ??? Operating System / 360 (OS, IBM S/360), "DOS/360"

@item DOSS
Dedicated Office Systems and Services

@item DOSVS
Disk Operating System / Virtual Storage (OS, IBM S/370), "DOS/VS"

@item DOSVSE
Disk ??? Operating System / Virtual Storage Extended (OS, IBM 43XX, DOS/VS, VSE), "DOS/VSE"

@item DOT
Digital Only Token

@item DOT
Dynamic Overclocking Technology (FSB, MCI), "D.O.T."

@item DOT
Dynamic Overclocking Tool (graphic, MSI), "D.O.T."

@item DOV
Data Over Voice [MODEM]

@item DOW
Direct OverWrite (MO, ...)

@item DP
[RAID] Double Parity (RAID, Network Appliance, HP)

@item DP
Data Processing

@item DP
Detection Point (IN)

@item DP
Draft Proposal (ISO)

@item DPA
Distributed Password Authentication

@item DPB
Drive Parameter Block (DOS, BIOS, FDD, HDD)

@item DPBO
Downstream Power Back Off (DSLAM)

@item DPC
Database Promotion Center (org., Japan, DB)

@item DPC
Deferred Procedure Call (MS, Windows)

@item DPC
Dots Per Centimeter (DPI)

@item DPCL
[Linux] Dynamic Probe Class Library (Linux)

@item DPCM
Differential Pulse Code Modulation (PCM)

@item DPCX
Distributed Processing Control eXecutive (IBM)

@item DPD
Dead Peer Detection (Internet, Firewall)

@item DPD
Differential Phase Detection

@item DPE
Distributed Processing Environment (IN)

@item DPF
Discrete Packet Format (Exabyte, VXA, Streamer)

@item DPG
Deutsche Physikalische Gesellschaft (org.)

@item DPI
[SNMP] Distributed Program Interface (SNMP, RFC 1228)

@item DPI
[SNMP] Distributed Protocol Interface (SNMP, RFC 1592)

@item DPI
Data Processing Installation

@item DPI
Dots Per Inch (DPC)

@item DPL
Debian Project Leader (Linux, Debian)

@item DPL
Descriptor Privilege Level (OS/2, NT)

@item DPM
Defects Per Million

@item DPM
Dynamic Power Management (AMD, GPU)

@item DPMA
Data Processing Management Association (org.)

@item DPMA
Demand Priority Access Method

@item DPMI
DOS Protected Mode Interface (DOS, MS, Intel)

@item DPMS
Display Power Management Signalling [standard] (VESA)

@item DPMS
DOS Protected Mode Services (Novell, DOS)

@item DPN
Data Packet Network (Nortel)

@item DPN
Data Processing Node (MODEM)

@item DPN
Deutsches Provider Network (ISP)

@item DPNPH
Data Packet Network-Packet Handler, "DPN-PH" 

@item DPNSS
Digital Private Network Signaling System (British Telecom)

@item DPOE
DOCSIS Provisioning Over EPON (DOCSIS, EPON), "DPoE"

@item DPOF
Digital / Direct Print Order Format (printing)

@item DPP
Data Parallel Processor (ATI)

@item DPP
Distributed Parallel Processing

@item DPQ
Data Processing Quality

@item DPRL
Digital Property Rights Language (Xerox)

@item DPS
Display PostScript (NeXT, GUI, NextStep, DPS)

@item DPS
Distributed Path Selection (FC)

@item DPS
Dual Power System (Gigabyte)

@item DPSE
Display PostScript Engine (DPS, NextStep, OpenStep, Apple, Rhapsody)

@item DPSK
Differential Phase Shift Keying (telecommunication)

@item DPT
Distributed Processing Technology (manufacturer)

@item DPT
Drive Parameter Table

@item DPT
Dynamic Packet Transport (Cisco)

@item DPV
DatenPaketVermittlung[srechner]

@item DPV
Delegated Path Validation (cryptography)

@item DPWS
Devices Profile for Web Services (WWW)

@item DQDB
Distributed Queue Dual Bus (ISO, IEC, IS 8802/6, IEEE 802.6)

@item DQL
Database Query Language (DB)

@item DQP
Distributed Query Processing (OGSA-DAI, grid)

@item DQP
Distributed Queueing Protocol

@item DQS
Distributed Queueing System (Cluster)

@item DR
Designated Router (PIM, Multicast)

@item DR
Developer Release (Linux, Apple, ...)

@item DR
Digital Research (manufacturer)

@item DR
Dynamic Reconfiguration (Solaris, Sun)

@item DRACO
DECT Radio Communications Controller (DECT, Hagenuk, University of Manchester)

@item DRAM
Dynamic Random Access Memory (RAM, IC)

@item DRB
Distributed RuBy (Ruby), "DRb"

@item DRB
DRAM Row Boundary [register] (DRAM, PCI)

@item DRC
Design Rule Check (CAD, LVS)

@item DRCS
Distributed Revision Control System (DVCS)

@item DRD
Data Reading Device

@item DRDA
Distributed Relational Database Architecture (IBM, DB)

@item DRDAAS
Distributed Relational Database Architecture Application Server (IBM, DB), "DRDA AS"

@item DRDOS
Digital Research Disk Operating System (DR, OS), "DR-DOS"

@item DRE
Direct Recording Electronic

@item DRE
Distributed Real-time and Embedded [systems]

@item DREN
Defense Research and Engineering Network (network)

@item DRF
Data Recovery Field (cryptography)

@item DRG
Developer Relations Group (MS)

@item DRI
Defense Research Internet (ARPANET, successorr, network)

@item DRI
Direct Rendering Infrastructure (XFree86)

@item DRIM
DResden Identity Management

@item DRIP
Designated Relays Inquiry Protocol (SPAM)

@item DRL
Document Revocation List (TCPA)

@item DRL
Dynamically Reconfigurable Logic (RL)

@item DRM
Destination Release Mechanism (DQDB)

@item DRM
Digital Radio Mondiale

@item DRM
Digital Rights Management (MS, DRM)

@item DRMU
Digital Remote Measurement Unit

@item DRP
DECnet Routing Protocol (DEC)

@item DRP
Dynamic Resource Pool (Solaris, Sun)

@item DRPM
Dynamic Rotations Per Minute (HDD)

@item DRS
Data Retrieval and Storage

@item DRS
Development Requirement Specification

@item DRS
Double-Ring-with-Star [topology]

@item DRSN
Defense Red Switch Network [hopefully no traffic ever] (network, mil. USA)

@item DS
[Netweaver] Developer Studio

@item DS
Data Segment [register] (CPU, Intel, assembler)

@item DS
Data Structure (Typo3)

@item DS
Deutschsprachige Shareware (org.)

@item DS
Digital Services [level]

@item DS
Directory Service (OSI, ISO, DP 9594)

@item DS
Distribution Services (SNA)

@item DS
Distribution System (WLAN)

@item DS
Double Sided [disks] (FDD)

@item DS0
Digital Signal level 0 (ISDN, T1), "DS-0"

@item DS1
Digital Signal level 1 (ISDN, T1), "DS-1"

@item DS1E1
Digital Signal level 1/European 1 (RFC 1406), "DS1/E1"

@item DS2
Digital Signal level 2, "DS-2"

@item DS3
Digital Signal level 3 (T3), "DS-3"

@item DS3E3
Digital Signal level 3/European 3 (RFC 1407), "DS3/E3"

@item DSA
Data Service Adapter

@item DSA
Debian Security Announcement (Linux, Debian)

@item DSA
Debian System Administration (Linux, Debian)

@item DSA
Digital Signature Algorithm (cryptography, NIST)

@item DSA
Digital Storage Architecture

@item DSA
Directory System Agent (X.500, DSA)

@item DSA
Distributed Systems Architecture (Bull)

@item DSA
Dynamic Scalable Architecture (DB, Informix)

@item DSAG
Deutsche SAP AnwenderGruppe (SAP, user group)

@item DSAP
Destination link Service Access Point (SAP, LLC)

@item DSAT
Deep Shit Alert Table (Apple, MACOS)

@item DSBAM
Double-SideBand Amplitude Module

@item DSBL
Distributed Server Boycott List (SPAM)

@item DSC
DECT Standard Cipher (DECT, cryptography)

@item DSC
Desired State Configuration (MS, Windows)

@item DSC
Document Structuring Conventions (Adobe)

@item DSCQS
Double Stimulus Continuous Quality Scale (ITU-R BT.500-7)

@item DSD
Data Structure Diagram (CASE)

@item DSD
Direct Stream Digital (Sony, Philips, SACD)

@item DSDC
Data Segment Descriptor Cache [register] (DS, Intel, CPU)

@item DSDL
Document Schema Definition Language (DB)

@item DSDT
Differentiated System Description Table (ACPI)

@item DSE
Data Switching Equipment (X.25, CCITT)

@item DSE
Distributed Systems Environment (Honeywell, Bull)

@item DSEA
DataStation Emulation Adapter (IBM, AS/400, ...)

@item DSEE
DOMAIN Software Engineering Environment (Apollo, CM, DOMAIN)

@item DSH
Desperately Seeking Help (slang, Usenet)

@item DSI
Defense Simulation Internet (network, mil., USA)

@item DSI
Dial Services Interface [API] (API, IBM)

@item DSI
Digital Speech Interpolation (VOFR)

@item DSI
Dynamic Skeleton Interface (CORBA, ORB, OA)

@item DSI
Dynamic Systems Initiative (MS, MCF)

@item DSID
Destination Signaling IDentifier

@item DSIMM
Dual [RAS] Single Inline Memory Module (IC), "D-SIMM"

@item DSL
Dataset and Snapshot Layer (ZFS)

@item DSL
Dialogue Scripting Language (DCE, UIL)

@item DSL
Digital Subscriber Line (DSL)

@item DSL
Digital system Specification Language (HDL)

@item DSL
Distributed Service Logic (IN)

@item DSL
Domain Specific Language

@item DSLAM
Digital Subscriber Line Access Multiplexer (DSL, ADSL)

@item DSLCP
Dynamically Switched Link Control Protocol (RFC 1307)

@item DSM
[TWAIN] Data Source Manager (MS, Windows)

@item DSM
Digital Standard MUMPS (MUMPS, DEC)

@item DSM
Domain Specific Modeling

@item DSM
Dynamic Spectrum Management

@item DSMCC
Digital Media Storage - Command and Control (DVB), "DSM-CC"

@item DSML
Directory Services Markup Language (OASIS)

@item DSMN
Directory Service Manager for Netware (MS, Windows NT, FPNW)

@item DSN
Data Source Names (ODBC, DB)

@item DSN
Defense Switched Network (mil., USA)

@item DSN
Delivery Status Notification

@item DSN
Developer Support News (IBM, OS/2)

@item DSN
Distributed Systems Network (HP)

@item DSNET
Defense Secure NETwork (mil., USA)

@item DSO
Dynamic Shared Object

@item DSOM
Distributed System Object Model (IBM)

@item DSP
Digital Signal Processing / Processor (audio, video, RL, DSP)

@item DSP
Direct Socket Protocol (Infiniband)

@item DSP
Directory System Protocol (X.500, DS)

@item DSP
Document Services for Printing (Xerox), "DS/P"

@item DSP
Domain Specific Part (NSAP, IDL. Domain)

@item DSR
Data Set Ready (MODEM, RS-232)

@item DSR
Device Status Report

@item DSR
Digital Signal Richtfunk Mil., Germany

@item DSRI
Digital Standard Relational Interface

@item DSRS
Defense Software Repository System (mil., USA)

@item DSS
Decision Support System (IM)

@item DSS
Defense Switched Services (mil., USA)

@item DSS
Digital Signature Standard (NIST, cryptography)

@item DSS
Directory and Security Services (DCE, IBM, LAN)

@item DSS
Distributed Security Service (DCE)

@item DSS2
[setup] Digital Subscriber Signaling #2

@item DSSCS
Defense Special Security Communications System (mil., USA)

@item DSSI
Digital Storage Systems Interconnect (VAX, DEC)

@item DSSS
Direct Sequence Spread Spectrum (WLAN)

@item DSSSL
[standard] Document Style Semantics and Specification Language (DTD, ISO, IEC, DIS 10179)

@item DST
Daylight Saving Time (TZ)

@item DSTN
Double SuperTwisted Nematic (LCD)

@item DSU
Data Secure Unix (Unix, OS, UCLA)

@item DSU
Digital Service Unit (ATM)

@item DSU
Digital Storage Unit

@item DSU
Distribution Service Unit (IBM, SNADS)

@item DSV
Digital Signal Verbindung Mil., Germany

@item DSVD
Digital Simultaneous Voice and Data (MODEM)

@item DT
Display Terminal

@item DT
Distributed graphical user interface Toolkit (IBM, GUI, VM/ESA)

@item DTA
Direct Tape Access (Seagate)

@item DTA
Disk Transfer Area (DOS)

@item DTAG
Deutsche Telekom AG Germany, ISP

@item DTAM
Document Transfer, Access and Manipulation (CCITT, T.400, ODIF)

@item DTAP
Direct Transfer Application Part (MS, MM, MTP)

@item DTAZV
DatenTraegeraustausch, belegloser AuslandsZahlungsVerkehr (banking)

@item DTC
Design Time Controls (MS)

@item DTC
DeskTop Conferencing

@item DTC
Distributed Transaction Coordinator (MS, SQL Server, DB)

@item DTCSA
Digital Transition Content Security Act (USA)

@item DTD
Document Type Definition (SGML, XML. HTML, DTD)

@item DTE
Data Terminal Equipment (X.25, CCITT)

@item DTE
DatenTransferEinrichtung

@item DTE
Domain and Type Enforcement (TE)

@item DTH
DialogTestHilfe (BS2000)

@item DTI
Digital Technology International

@item DTI
Document Technologies, Inc. (company, USA)

@item DTK
Deception ToolKit

@item DTLB
Dual Translation Lookaside Buffer (CPU)

@item DTLS
Datagram Transport Layer Security (UDP)

@item DTMF
DeskTop Management task Force (Intel)

@item DTMF
Dual Tone Multi Frequency

@item DTML
Document Template Markup Language (ZOPE)

@item DTMP
DCPS Management Panel (DCPS)

@item DTMS
Document Transfer and Manipulation Services (CCITT, T.400)

@item DTOS
Distributed Trusted Operating System (OS, DTE)

@item DTP
DeskTop Publishing

@item DTP
Distributed Transaction Processing (X/Open, OLTP)

@item DTP
Document Transfer Profile (SPAC, ODA, DAP, predecessor)

@item DTR
Data Terminal Ready (MODEM, RS-232)

@item DTR
DeskTop Replacement [notebook]

@item DTR
DeskTop Reproduction (DTP)

@item DTR
Document Filing and Retrieval (DOAM, ISO, IEC, DIS 10166-1 f.)

@item DTR
Draft Technical Report

@item DTRT
Do The Right Thing (slang, Usenet, IRC)

@item DTS
Digital Theatre Sound (audio)

@item DTS
Digital Thermal Sensor (Intel, IC, CPU)

@item DTS
Direct To SOM

@item DTS
Distributed Time Server

@item DTS
Distributed Time Service (DCE)

@item DTSES
Digital Theatre Sound - Extended Surround (audio), "DTS-ES"

@item DTSS
Dartmouth Time-Sharing System (OS)

@item DTT
Dual Transformer Technology (Tangan)

@item DTU
Demand Transmission Unit

@item DU
Disk Used (Unix)

@item DU
Distribution Unit (MS, MSIE)

@item DUA
Directory User Agent (X.500, DS)

@item DUEE
DatenUEbertragungsEinrichtung

@item DUEE
DatenUEbertragungsEinrichtung (DTAG)

@item DUMP
Dial-Up Network Profile (Bluetooth, SPP, DUN)

@item DUN
Dial Up Networking (Bluetooth, ...)

@item DUNDI
Distributed Universal Number DIscovery (VoiP), "DUNDi"

@item DUOW
Distributed Unit Of Work (DRDA, IBM), "DUoW"

@item DUP
Distribution Unit Profile (MS, OSD, DU, MSIE)

@item DV
DatenVerarbeitung

@item DV
Digital Video

@item DVA
Data Virtual Address (ZFS)

@item DVA
DatenVerarbeitungsAnlage

@item DVA
Dynamic Vibration Absorber (CD, DVD, Samsung)

@item DVB
Digital Video Broadcasting (Europe, DVB)

@item DVBC
Digital Video Broadcasting - Cable (DVB), "DVB-C"

@item DVBH
Digital Video Broadcasting - Handheld (DVB), "DVB-H"

@item DVBNIP
Digital Video Broadcasting - ? (DVB), "DVB-NIP"

@item DVBRC
Digital Video Broadcasting - ? (DVB), "DVB-RC"

@item DVBRCGSM
Digital Video Broadcasting - ? (DVB), "DVB-RCGSM"

@item DVBRCT
Digital Video Broadcasting - ? (DVB), "DVB-RCT"

@item DVBS
Digital Video Broadcasting - Satellite (DVB), "DVB-S"

@item DVBT
Digital Video Broadcasting - Terrestic (DVB), "DVB-T"

@item DVC
Digital Video Compression (video)

@item DVCS
Distributed / Decentralized Version Control System (DRCS)

@item DVD
Deutsche Vereinigung fuer Datenschutz [e.V.] (org.)

@item DVD
Digital Versatile Disk (CD, MPEG, DVD)

@item DVD
Digital Video Disk [old term] (DVD)

@item DVDCCA
DVD Copy Control Association (DVD, org.), "DVD CCA"

@item DVDMRW
Digital Versatile Disk + Mount rainier ReWritable (DVD, DVD+RW, MS), "DVD+MRW"

@item DVDR
Digital Versatile Disk - Recordable (DVD), "DVD-R"

@item DVDR
Digital Versatile Disk + Recordable (DVD), "DVD+R"

@item DVDRA
Digital Versatile Disk - Read (Authoring) (DVD-R, DVD), "DVD-R(A)"

@item DVDRAM
Digital Versatile Disk Random Access Memory (DVD), "DVD-RAM"

@item DVDRG
Digital Versatile Disk - Read (General use) (DVD-R, DVD), "DVD-R(G)"

@item DVDROM
Digital Versatile Disk Read Only Memory (DVD, ROM), "DVD-ROM"

@item DVDRW
Digital Versatile Disk - ReWritable (DVD), "DVD-RW"

@item DVDRW
Digital Versatile Disk + ReWritable (PC-RW, DVD, Sony, Philips, HP, Mitsubishi, Ricoh, Yamaha), "DVD+RW"

@item DVI
DeVice Independent

@item DVI
Digital Video Interactive [old term] (LCD, Intel, IBM, Lotus, HP, Compaq, ...)

@item DVI
Digital Visual Interface (DVD, video)

@item DVID
Digital Video Interactive - Digital (LCD), "DVI-D"

@item DVID
Digital Video Interactive - Integrated (LCD), "DVI-I"

@item DVID
Dynamic - Voltage IDentification (Intel, CPU), "D-VID"

@item DVL
Digital Video Link

@item DVM
Dynamic Visual Mode (NEC, Mitsubishi, LCD)

@item DVM
Dynamic Voltage Management (PDA)

@item DVMA
Direct Virtual Memory Access

@item DVMRP
Distance Vector Multicast Routing Protocol (IP, Multicast)

@item DVMT
Dynamic Video Memory Technology (Intel)

@item DVPT
Deutscher Verbandes fuer Post und Telekommunikation (org.)

@item DVR
??? (DTP, Truevision)

@item DVS
DatenVerwaltungsSystem (BS2000)

@item DVS
Digital Video Systems (manufacturer)

@item DVST
DatenVermittlungsSTelle (DTAG)

@item DVSTP
DatenVermittlungsSTelle mit Paketvermittlung (DTAG), "DVST-P"

@item DVT
Deutscher Verband Technisch-wissenschaftlicher vereine (org.)

@item DVX
Digital Voice eXchange

@item DWANGO
Dialup Wide-Area Network Game Organization (IVS Corporation)

@item DWDM
Dense Wavelength Division Multiplexing [protocol]

@item DWF
Drawing Web Format (carCAD)

@item DWH
Data WareHouse (DB)

@item DWH
DISA Western Hemisphere (DISA, mil., USA)

@item DWIM
Do What I Mean (telecommunication, Usenet, IRC)

@item DWM
Diskless Workstation Management (AIX, IBM)

@item DWMT
Discrete Wavelet MultiTone [modulation]

@item DWS
Delphi Web Script (Delphi, Borland, WWW)

@item DWS
Digital World Services (ISP)

@item DWT
Discrete Wavelet Transformation

@item DXA
Directory eXchange Agent

@item DXI
Data eXchange Interface

@item DXJ
Datex J (DTAG), "DxJ"

@item DXJVST
Datex J VermittlungsSTelle (DTAG), "DxJ VSt

@item DXL
Domino XML Language (XML, Lotus, DTD)

@item DXS
Directory eXchange Server

@item DXVA
DirectX Video Acceleration (MS, Windows)

@end table

