@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item C128
Commodore 128 [computer] (Commodore)

@item C2IS
Command and Control Information Systems (mil., USA)

@item C3I
Command, Control, Communications and Intelligence (mil., USA)

@item C3IIS
Command, Control, Communications and Intelligence Information Systems (mil., USA), "C3I/IS"

@item C4
Command, Control, Communications and Computers (mil., USA)

@item C4I
Command, Control, Communications, Computers and Intelligence (mil., USA)

@item C64
Commodore 64 [computer] (Commodore)

@item CA
Cell Arrival (ATM)

@item CA
Certification Authority (cryptography, PKI)

@item CA
Channel Adapter (Infiniband)

@item CA
Computer Animation

@item CA
Computer Associates (manufacturer)

@item CAAD
Computer Aided Architectural Design

@item CABAC
Context Based Adaptive Binary Arithmetic Coding (AVC)

@item CABS
Carrier Access Billing System

@item CABS
Computer Aided Business Simulation

@item CAC
Cantilver Array Chip (IBM, HDD, MEMS)

@item CAC
Channel Access Code (Bluetooth)

@item CAC
Computer Aided Crime

@item CAC
Connection Admission Control (UNI, ATM)

@item CACEAS
Computer-Assisted Circuit Engineering and Allocating System

@item CACTIS
Community Automated Counter-Terrorism Intelligence System (mil., USA)

@item CAD
Computer Aided Design (CIM)

@item CAD
Computer Aided Dispatch / Drafting

@item CADE
Computer Aided Document Engineering (Microstar)

@item CADR
Client Authenticated DNS Request (DNS, Internet)

@item CADS
Computer-Assisted Display System

@item CAE
Client Application Enabler (IBM, DB)

@item CAE
Common Application Environment (X/Open)

@item CAE
Computer Aided Education

@item CAE
Computer Aided Engineering (CIM)

@item CAI
Computer Aided Inspection (CIM)

@item CAI
Computer Aided Instruction

@item CAIP
Computer Analysis of Images and Patterns (Konferenz)

@item CAIS
Common APSE Interface Specification (APSE, API)

@item CAIT
Center for the Application of Information Technology (org., USA)

@item CAIT
Central Academy of Information Technology (org., MITI)

@item CAL
Client Access License (Lotus, MS)

@item CAL
Computer Aided Logistics

@item CAL
Computer Assisted Learning

@item CAL
Conversational Algebraic Language (JOSS)

@item CALEA
Communications Assistance Law Enforcement Act (USA)

@item CALS
Computer aided Acquisition and Logistics Support

@item CALS
Continuous Acquisition and Life-cycle Support

@item CAM
Common Access Method (SCSI)

@item CAM
Computer Aided Manufacturing

@item CAM
Conditional Access Modul (DVB, CI)

@item CAM
Content Addressable Memory (ethernet, Switch, IC)

@item CAMAC
Computer Automated Measurement And Control

@item CAMEL
Customized Applications for Mobile network Enhanced Logic (UMTS)

@item CAML
Categorical Abstract Machine Language (INRIA), "Caml"

@item CAML
Collaborative Application Markup Language (MS, XML)

@item CAMM
Computer Assisted Material Management

@item CAMP
Cygwin Apache MySQL PHP (Cygwin, Apache, SQL, PHP)

@item CAN
Complete Area Networks (SNI)

@item CAN
Controller Area Network [bus] (CAN)

@item CAO
Client Activated Object (SAO)

@item CAO
Computer Aided Office

@item CAO
Control Area Operator (EMS)

@item CAP
Carrierless Amplitude Phase [modulation] (ADSL, AT&T)

@item CAP
Common Alerting Protocol (XML, OASIS)

@item CAP
Communications-electronics Accommodation Program

@item CAP
Component Approval Process

@item CAP
Computer Aided Planning (CIM)

@item CAP
Computer Aided Publishing

@item CAP
Consistency, Availability, Partition tolerance

@item CAPE
Computer Applications in Production and Engineering (conference, IFIP)

@item CAPEC
Common Attack Pattern Enumeration and Classification

@item CAPI
Coherent Accelerator Processor Interface (NVidia)

@item CAPI
Communication Application Program Interface (ISDN, API)

@item CAPI
Cryptography Application Programming Interface (cryptography, API)

@item CAPP
Computer Aided Process Planning

@item CAPPEAL
Controlled Access Protection Profile / Evaluation Assurance Level, "CAPP/EAL"

@item CAPSL
CAnnon Printing System Language (Canon), "CaPSL"

@item CAPT
Cannon Advanced Printing Technology

@item CAPTCHA
Completely Automated Public Turing test to tell Computers from Humans Apart (AI)

@item CAPWAP
Control and Provisioning of Wireless Access Points (WAP)

@item CAQ
Computer Aided Quality [control]

@item CAR
Central Access Routing (RND)

@item CAR
Computer Aided Retrieval

@item CAR
Computer Assisted Radiology

@item CAR
Contents of the Address Register (IBM, ELISP, CDR)

@item CARCAS
Computer Aided aRchiving and Change Accounting System

@item CARD
Candidate Access Router Discovery (RFC 4066)

@item CARDS
Central Archive for Reusable Defense Software (mil., USA)

@item CARDVM
Card Virtual Machine (Java, Sun), "CardVM"

@item CARE
Computer Assistance Resource Exchange

@item CARLOS
Computer Aided Real Language Orthographic System

@item CARP
Common Address Redundancy Protocol (BSD)

@item CAS
Code Access Security (VSTO, .NET, MS)

@item CAS
Column Address Strobe (IC, DRAM)

@item CAS
Communicating Applications Specification (FAX, Intel, DCA)

@item CAS
Computer Aided Selling

@item CAS
Computer Aided Styling

@item CAS
Computer Algebra System

@item CAS
Computerized Autodial System

@item CAS
Content Addressed Storage (EMC)

@item CASE
Common Application Service Element (ISO, OSI)

@item CASE
Computer Aided Software Engineering

@item CASH
Computer Aided Service Handling (Ashton-Tate), "C.A.S.H."

@item CASID
Condition Access System IDentification (DVB, CAT)

@item CAST
Carlisle Adams and Stafford Tavares (cryptography)

@item CAST
Computer Aided Software Testing

@item CAT
Central Alaska Time [-1000] (TZ)

@item CAT
Common Authentication Technology (IETF, RFC 1511)

@item CAT
Computer Aided Technology (fair)

@item CAT
Computer Aided Telephony

@item CAT
Computer Aided Testing

@item CAT
Condition Access Table (DVB)

@item CATI
Computer Aided Telephone Interviewing

@item CATIA
Computer Aided Three-Dimensional Interactive Application (CAD)

@item CATIS
Computer-Assisted Tactical Information System (mil., USA)

@item CATNIP
Common ArchiTecture for Next generation Internet Protocol (IPNG, RFC 1707)

@item CATOSL
Computer Associates - Trusted Open Source License (CA), "CA-TOSL"

@item CATS
CodeWarrior Analysis Tools

@item CAUCE
Coalition Against Unsolicited Commercial Email (org., Internet, spam, UCE)

@item CAV
Constant Angular Velocity (CD, HDD, MOD)

@item CAVE
Cave for Automated Virtual Environment (VR)

@item CAVLC
Context-Adaptive Variable Length Coding (AVC)

@item CAVO
Computer Associates - Visual Objects (CA, DB), "CA-VO"

@item CBASIC
Commercial Beginners All purpose Symbolic Instruction Code (BASIC)

@item CBC
Cipher Block Chaining [mode] (DES, DESE, RC5, cryptography)

@item CBCMAC
Cipher Block Chaining of Message Authentication Code (CBC, MAC, cryptography, WLAN), "CBC-MAC"

@item CBCP
CallBack Control Protocol

@item CBCS
Computer Based Conversation System (BBS)

@item CBDF
Character Bitmap Distribution Format (Adobe)

@item CBDS
Connectionless Broadband Data Service (Europe)

@item CBDTPA
Consumer Broadband and Digital Television Promotion Act (USA, DRM)

@item CBE
Certified Banyan Engineer (Banyan, VINES)

@item CBEFF
Common Biometric Exchange Format Framework (NIST, ISO 19785)

@item CBEMA
Computer & Business Equipment Manufacturers Association (org.)

@item CBF
Code Behind Form (MS, Access, DB)

@item CBGA
Ceramic Ball and Grid Array (IC, CPU)

@item CBIOS
Compatibility Basic Input Output System (IBM, BIOS)

@item CBMS
Connectionless Broadband Data Service

@item CBQ
Class Based Queueing

@item CBR
Constant Bit Rate (ATM, VBR, ABR, UBR, QOS, BIT)

@item CBS
Certified Banyan Specialist (Banyan, VINES)

@item CBS
Component Based Setup (MS, Windows)

@item CBSR
Candidate BootStrap Router (PIM, BSR, Multicast), "C-BSR"

@item CBT
Canon Buffer Transmission (Fax)

@item CBT
Computer-Based Training

@item CBT
Core Based Tree [multicast protocol] (IP, RFC 1949/2189, ST, Multicast)

@item CBT
Cursor Backward Tabulation (CFT)

@item CBU
Capacity BackUp (IBM, zSeries)

@item CBX
Computerized Branch eXchange (PBX)

@item CC
Carbon Copy

@item CC
Common Criteria [for IT Security Evaluation] (CC)

@item CC
Continuity Cell (ATM)

@item CC
Country Code (MS-ISDN, GSM, mobile-systems)

@item CC
Cross Connector

@item CCA
Cisco Clean Access (Cisco)

@item CCA
Clear Channel Assessment (WLAN)

@item CCAF
Call Control Agent Function (IN)

@item CCAP
Converged Cable Access Platform (DOCSIS)

@item CCC
Cablelabs Client Configuration (DHCP)

@item CCC
Catalyst Control Center (ATI, Windows)

@item CCC
Chaos Computer Club (org.)

@item CCC
Computer Control Center

@item CCC
Cube Connected Cycles (MP)

@item CCCA
Campus Computer Communication Association (org., USA)

@item CCCH
Common Control CHannel (GSM, mobile-systems)

@item CCCI
Center for Cyber Communities Initiative (org., Japan)

@item CCD
Charge Coupled Device

@item CCDCOE
Cooperative Cyber Defence Centre of Excellence (org., NATO)

@item CCE
[visual basic] Control Creation Edition (VB, ActiveX, MS)

@item CCE
Connection Control Entity

@item CCETT
Centre Commun d'Etudes de Telediffusion et Telecommunications (org., France)

@item CCF
Campus Computing Facilities (org.)

@item CCF
Capsulated Color Filter (NEC)

@item CCF
Central Computer Facility

@item CCF
Connection Control Function (IN)

@item CCF
Controller Configuration Facility

@item CCFL
Cold Cathode Fluorescent Lamp (LCD)

@item CCFT
Cold Cathode Fluorescent Tube (LCD, Display)

@item CCI
Cache Coherent Interconnect

@item CCIA
Computer & Communication Industry Association (org.)

@item CCIRN
Coordinating Committee of International Networks (org.)

@item CCIS
Common Channel Interoffice Signaling (AT&T)

@item CCITT
Comite Consultatif International Telegraphique et Telephonique (org., ITU, predecessor)

@item CCL
Cerberus Central Limited (manufacturer)

@item CCM
Change and Configuration Management

@item CCM
CORBA Component Model (CORBA)

@item CCM
Counter with CBC-MAC (cryptography, CBC, MAC, RFC 3610)

@item CCMDB
Change and Configuration Management DataBase (IBM, Tivoli)

@item CCMP
Counter mode CBC MAC Protocol (CBC, MAC, cryptography, WLAN)

@item CCNC
Common Channel Network Controller

@item CCNC
Computer / Communications Network Center

@item CCNUMA
Cache-Coherent Non Uniform Memory Access (SMP, NUMA), "cc-NUMA"

@item CCP
[PPP] Compression Control Protocol (PPP, RFC 1962)

@item CCP
Command Console Processor (CP/M)

@item CCP
Communications Control Program (OS, IBM)

@item CCP
Compact Communication Products (TPS)

@item CCPP
Composite Capability / Preference Profiles (W3C, RDF), "CC/PP"

@item CCR
Commitment, Concurrency and Recovery (OSI)

@item CCR
Current Cell Rate (ATM)

@item CCRA
Common Criteria Recognition Arrangement (CC)

@item CCRMA
Center for Computer Research in Music and Acoustics (org., Stanford, UK)

@item CCS
[Conference on] Computer and Communications Security

@item CCS
Cambridge Cybernetic Society (org.)

@item CCS
Cluster Configuration System (GFS)

@item CCS
Coded Character Set (CCS, Unicode)

@item CCS
Common Channel Signaling (IN)

@item CCS
Common Command Set (SCSI)

@item CCS
Common Communications Support (IBM, SAA)

@item CCS
Communications-Computer Systems, "C-CS"

@item CCS
Computerized Charging System

@item CCS
Cyprus Computer Society (Org, Zypern)

@item CCS7
Common Channel signaling System 7 (IN, DTAG, CCITT)

@item CCSID
Coded Character Set IDentification (IBM)

@item CCSY
Cooperative Computing System Program (HP)

@item CCT
China Coast Time [+0800] (TZ)

@item CCTA
Central Computer and Telecommunications Agency (org., UK, predecessor, OGC)

@item CCTLD
Country Code Top Level Domain (Internet, ICANN), "ccTLD"

@item CCU
Cache Control Unit (Wyse)

@item CCU
Customer Control Unit

@item CCV
C-bit Coding Violation [error event] (DS3/E3, BIT)

@item CCW
COM Callable Wrapper (MS, COM, Java)

@item CD
Carrier Detect (MODEM, RS-232)

@item CD
Change Directory (DOS, Unix, OS/2)

@item CD
Committee Draft (ISO)

@item CD
Compact Disk (CD)

@item CDA
Combined dynamic Data Authentication (EMV, cryptography)

@item CDA
Communications Decency Act (Internet, USA)

@item CDA
Compound Document Architecture (DEC)

@item CDATA
Character DATA (DTD, PCDATA)

@item CDB
Command Descriptor Block

@item CDBS
Connectionless Data Bearer Service

@item CDBX
Computerized Digital Branch eXchange (PBX)

@item CDC
Connected Device Configuration (JVM)

@item CDC
Control Data Corporation (manufacturer)

@item CDC
Cult of the Dead Cow (org.), "cDc"

@item CDD
Component Design Document

@item CDDA
Compact Disk - Digital Audio (CD, Digital audio), "CD-DA" 

@item CDDI
Copper Distributed Data Interface (FDDI, UTP)

@item CDE
Certified Directory Engineer (Novell, Netware)

@item CDE
Common Desktop Environment (Unix)

@item CDE
Compact Disk - Erasable (CD), "CD-E" 

@item CDE
Cooperative Development Environment (Oracle)

@item CDEF
Control DEfinition Functions (Apple, MDEF)

@item CDF
Channel Definition Format (MS, Internet, XML)

@item CDF
Compound Document Framework (IBM, OLE)

@item CDFS
Compact Disk File System (CD, OS/2, IBM)

@item CDG
Compact Disk + Graphics (CD), "CD+G" 

@item CDI
Compact Disk - Interactive (CD), "CD-I" 

@item CDIF
CASE Data Interchange Format (CASE)

@item CDK
Control Development Toolkit (MS, VB)

@item CDM
Compressed Data Mode

@item CDM
Conceptional Data Model (DB, PDM, Powerdesigner)

@item CDMA
Code Division Multiple Access (telecommunication, mobile-systems)

@item CDMIDI
Compact Disk + Musical Instruments Digital Interface (CD, MIDI), "CD+MIDI" 

@item CDMO
Compact Disk - Magneto Optical (CD), "CD-MO" 

@item CDMRW
Compact Disk - Mount Rainier Washington (CD-RW, CD), "CD-MRW"

@item CDMS
Command and Data Management System (ESA, Venus-Express)

@item CDMS
Communication Driver Maintenance System (ISDN, HST)

@item CDMU
Command and Data Management Unit (ESA, Venus-Express, CDMS)

@item CDN
Content Delivery Network (Internet)

@item CDNC
Chinese Domain Name Consortium (org., Internet)

@item CDO
Collaboration Data Objects (WSH, MS)

@item CDO
Common Data Objects (MS, ASP)

@item CDPC
Cellular Digital Packet Data

@item CDPD
Cellular Digital Packet Data (mobile-systems)

@item CDPN
Context Dependent Path Names (CDSL, NFS, GFS)

@item CDR
Compact Disk - Recordable (CD), "CD-R" 

@item CDR
Contents of the Decrement Register (IBM, ELISP, CAR)

@item CDRA
Character Data Representation Architecture

@item CDRAM
Cached Dynamic Random Access Memory (RAM, DRAM, IC)

@item CDRM
Cross Domain Resource Manager (VTAM, SSCP, IBM)

@item CDROM
Compact Disk - Read Only Memory (CD, ROM), "CD-ROM" 

@item CDROMXA
Compact Disk - ROM / eXtended Architecture (CD, MPC, ROM), "CD-ROM/XA" 

@item CDRW
Compact Disk - ReWritable (CD), "CD-RW"

@item CDS
Cell Directory Service (DCE)

@item CDS
Class Data Sharing (Java)

@item CDS
Current Directory Structure (BIOS. DOS)

@item CDSA
Common Data Security Architecture (HP, cryptography)

@item CDSG
Cultural Diversity Steering Group (ISSS)

@item CDSL
Context Dependent Symbolic Links (CDPN, NFS, GFS)

@item CDSS
Creative Decision Stimulation Systems (AI, DSS)

@item CDT
Cambridge Display Technology (manufacturer)

@item CDT
Cell Delay Tolerance (ATN)

@item CDT
Central Daylight Time [-0500] (TZ, CST, USA)

@item CDT
Compressed Domain Transcoder (DVD)

@item CDTV
Commodore Dynamic Total Vision (Commodore)

@item CDV
Cell Delay Variation (UNI, ATM, QOS)

@item CDVT
Cell Delay Variation Tolerance (UNI, ATM, CDV)

@item CDWO
Compact Disk - Write Once (CD), "CD-WO" 

@item CE
Communaute / Comunique Europeenne (Europe)

@item CE
Communications-Electronics, "C-E"

@item CE
Compact Edition (MS, Windows)

@item CE
Connection Endpoint (UNI)

@item CEARCH
Cisco Educational ARCHive (Cisco, WWW)

@item CEBIT
welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"

@item CEC
Consumer Electronics Control [protocol]

@item CECI
CICS Enhanced Command Interpreter (IBM, CICS)

@item CECMG
Central Europe Computer Measurement Group (org., Europe), "cecmg"

@item CEDA
CICS Enhanced resource Definition online Application (CICS, IBM)

@item CEDF
CICS Execution Diagnostic Facility (CICS, IBM)

@item CEDR
[Microsoft Windows] Compact Edition Driver Repository (MS, Windows, CE)

@item CEE
[Linux] Consumer Electronics Edition (MontaVista, Linux, PDA)

@item CEECEB
Central and Eastern European Countries EDIFACT Board (org., EDIFACT), "CEEC/EB"

@item CEFACT
CEntre for Facilitation of procedures and practices in Administration, Commerce and Transport

@item CEG
Continuous Edge Graphics (Grafik, IC)

@item CEI
Connection Endpoint Identifier (UNI)

@item CELL
CIP/Ethernet Library for Linux (Linux, ethernet, CIP, PLC)

@item CELP
Card Edge Low Profile [socket]

@item CELP
Code Excited Linear Prediction

@item CEM
Common [IT Security] Evaluation Methodology (CC)

@item CEM
Contract Equipment Manufacturer

@item CEMT
CICS Enhanced Master Terminal transaction (CICS, IBM)

@item CEN
Comite Europeen de Normalisation (org., Europe, Brussels)

@item CENELEC
Comite Europeen de Normalisation ELECtrotechnique (org., CEN, Europe)

@item CENTR
Council of European National Top level Domain Registries (org., TLD)

@item CEPAC
CMOS-Ein-Platinen-Allzweck-Computer (IC, CMOS, C'T)

@item CEPIS
Council of European Professional Informatics Societies (org., Europe)

@item CEPT
Conference of European Postal and Telecommunications administrations (org., CCITT, conference, Europe)

@item CER
Cell Error Ratio (ATM)

@item CERFNET
California Educational and Research Federation NETwork (network), "CERFNet"

@item CERN
Conseil Europeenne pour la Recherche Nucleaire (org., Europe, Geneva)

@item CERT
Computer Emergency Response Team (DARPA, CMU, Internet)

@item CES
C-bit Errored Seconds (DS3/E3, BIT)

@item CES
Character Encoding Scheme (CSS, Unicode)

@item CES
Circuit Emulation Service

@item CES
Consumer Electronics Show (fair, USA)

@item CESAR
Central Employment Search And Retrieval (WWW)

@item CESG
Communications-Electronics Security Group (org., UK, GCHQ)

@item CET
Central European Time [+0100] (TZ, MET)

@item CET
Centro de Estudes de Telecomunicoes (org., Portugal)

@item CF
Carry Flag (assembler)

@item CF
Compact Flash [card]

@item CF
Compact Framework (MS, .NET, PocketPC)

@item CFA
Center for Architecture (org., JIEO, DISA)

@item CFA
Code Fields Address (Forth)

@item CFB
Cipher FeedBack [mode] (cryptography, DES)

@item CFC
ColdFusion Component (WWW, HTTPD)

@item CFD
Call For Discussion (Internet)

@item CFD
Computational Fluid Dynamics [applications]

@item CFE
Center for Engineering (org., JIEO, DISA)

@item CFF
Compact Font Format (Adobe)

@item CFI
CAD Framework Initiative (org., CAD)

@item CFM
Clock From Master (CTM, Rambus)

@item CFM
Code Fragment Manager (Apple)

@item CFM
ConFiguration Management (FDDI, SMT)

@item CFMC
Committee to Fight Microsoft Corporation (org., MS)

@item CFML
Cold Fusion Markup Language

@item CFP
Call For Papers

@item CFP
Computers, Freedom & Privacy [conference]

@item CFP
Contention Free Period (PCF, MAC)

@item CFQ
Complete Fair Queueing (Linux)

@item CFS
Center for Standards (org., JIEO, DISA)

@item CFS
Cryptographic FileSystem (Linux, cryptography)

@item CFT
Call For Testers

@item CFT
Cusor Forward Tabulation (CBT)

@item CFV
Call For Vote (Internet, Usenet), "CfV"

@item CFWS
Comments / Folding White Space (RFC 1822)

@item CG
C for Graphics (Nvidia, MS), "Cg"

@item CGA
Colour Graphics Adapter

@item CGA
Graphics Communications Association (org.)

@item CGARI
Graphics Communications Association Research Institute (org., CGA)

@item CGATS
Committee for Graphics Arts Technologies Standards (org., ANSI)

@item CGDC
Computer (???) Game Developers' Conference

@item CGE
Carrier Grade Edition (Linux, MontaVista, CGL)

@item CGEMM
Complex single precision GEneral Matrix Multiply (GEMM, BLAS)

@item CGH
Computer Generated Holography

@item CGI
Common Gateway Interface (WWW)

@item CGI
Computer Generated Imagery

@item CGI
Computer Graphics Interface

@item CGI
Computer Graphics International (Konferenz)

@item CGL
Carrier Grade Linux (Linux, OSDL)

@item CGM
Computer Graphics Metafile (ISO 8632)

@item CGMS
Copy Generation Management System (CD)

@item CGMSA
Content Generation Management System - Analog (WPE), "CGMS-A"

@item CGRM
Computer Graphics Reference Model (ISO, IEC, ISO/IEC 11072)

@item CGS
Continuous Grain Silicon [technology] (Sharp, LCD)

@item CGVDI
Computer Graphic Virtual Device Interface, "CG-VDI"

@item CHAID
CHisquard Automatic Interaction Detector / Detection (SPSS)

@item CHAP
[PPP] Challenge Handshake Authentication Protocol (PPP, RFC 1334/1994)

@item CHCP
CHange Code Page (DOS)

@item CHDL
Computer Hardware Description Language (HDL)

@item CHES
Cryptographic Hardware and Embedded Systems [conference]

@item CHEST
Computers in Higher Education Software Team (org., UK)

@item CHILL
CCITT HIgh Level programming Language (CCITT)

@item CHRP
Common Hardware Reference Platform (AIM)

@item CHS
Cylinder Head Sectors (HDD, BIOS)

@item CHSM
C Hardware Specific Module (NEST, MLID, Novell)

@item CHV
Card Holder Value [aka PIN] (ICC, PIN)

@item CI
Check In (RCS)

@item CI
Coded Information

@item CI
Common Interface (DVB)

@item CI
Component Interface (DMI)

@item CI
Configuration Item (CM)

@item CI
Congestion Indicator

@item CIA
CAN In Automation (org., CAN), "CiA"

@item CIAC
Computer Incident Advisory Capability (org., LLNL, Internet)

@item CIB
Collective Intelligent Brick (IBM, HDD)

@item CIB
Computer Integrated Business

@item CIC
Carrier Identification Code

@item CIC
Certified IT Consultant (BVSI)

@item CIC
Coordination and Information Center (CSNET)

@item CICA
Center of Innovative Computer Applications (org.)

@item CICS
Customer Information Control System (IBM, CICS, Z/OS, OS/390, VSE/ESA)

@item CICSESA
Customer Information Control System/Enterprise Systems Architecture (IBM, CICS), "CICS/ESA"

@item CICSTS
Customer Information Control System / Transaction Server (IBM, VSE/ESA), "CICS/TS"

@item CICSVS
Customer Information Control System / Virtual Storage (IBM, CICS), "CICS/VS"

@item CID
Configuration - Installation - Distribution (IBM)

@item CIDF
Common Intrusion Detection Framework (CIDF, IDS)

@item CIDR
Classless Internet Domain Routing [protocol] (RFC 1519)

@item CIDS
Cabin Intercommunication Data System (Airbus, A380, TCP/IP)

@item CIE
Commission Internationale de l'Eclairage (org.)

@item CIF
Common Intermediate Format [352x288] (video)

@item CIFS
Common Internet File System (TCP/IP)

@item CIIRC
China Internet Illegal Information Reporting Center (China, org.)

@item CIL
Common Intermediation Language (CLI)

@item CIL
Computer Integration Laboratories (org., Apple, IBM, Novell, Sun, ...)

@item CILABS
Component Integration LABoratorieS (org.,, OpenDoc, Apple, IBM, Adobe, ...), CILabs

@item CIM
Cisco Interactive Mentor (Cisco)

@item CIM
Common Information Model (DMTF, XML, DMI, SAN, WBEM)

@item CIM
Computer Integrated Manufacturing

@item CIMOM
CIM Object Model (CIM, WBEM)

@item CIMOS
CIncinnati Milacron Operating System (OS), "CiMOS"

@item CIO
Cisco Information Online (Cisco, WWW)

@item CIP
Carrier Identification Parameter

@item CIP
Classical IP over ATM (IP, ATM, IETF)

@item CIP
Common Industrial Protocol (ODVA)

@item CIP
Common ISDN Profile (Bluetooth, CAPI, ISDN)

@item CIP
Computer Integrated Processing

@item CIP
Computer-Investitions-Programm

@item CIPA
Camera & Imaging Products Association (org.)

@item CIPA
Children's Internet Protection Act (Internet, USA, COPA)

@item CIQ
Customer Information Quality (OASIS, TC)

@item CIR
Committed Information Rate (ATM)

@item CIRAS
(Conference on] Computational Intelligence, Robotics and Autonomous Systems

@item CIRC
Cross Interleaved Reed-solomon Code (CD)

@item CIRCIT
Centre for International Research on Communication and Information Technology (org., Australia)

@item CIS
Card Information Structure / Space (PCMCIA)

@item CIS
Command Information System (mil., USA)

@item CIS
Compuserve Information Systems (network)

@item CIS
Contact Image Sensor

@item CISA
Certified Information Systems Auditor (ISACA)

@item CISC
Complex Instruction Set Computer (CPU)

@item CISE
Computer and Information Science Directorate (org., NSF)

@item CISKA
[3D] Campus-InformationsSystem KArlsruhe (Uni Karlsruhe, Germany, VRML)

@item CISM
Certified Information Security Manager (ISACA)

@item CISO
Certified Information Security Officer (ISTA)

@item CISPR
Comite International Special des Perturbations Radioelectriques (org.)

@item CISRAM
Cybernetics & Intelligent Systems - Robotics, Automation & Mechatronics (IEEE, conference), "CIS-RAM"

@item CISRT
Chinese Internet Security Response Team (org., China)

@item CISS
Center for Information Systems Security (org., JIEO, DISA, mil., USA)

@item CISS
Confirmation Interactive Site Server [technology]

@item CISSP
Certified Information Systems Security Professional (ISC2)

@item CIT
Center for Information Technology (org., USA)

@item CIT
Computer Integrated Telephony

@item CIT
Computer Intergrated Tooling

@item CITED
Copyright In Transmitted Electronic Documents (ESPRIT)

@item CIU
Core Interface Unit (Power4, IBM, IC)

@item CIU
Customer Initiated Upgrade (IBM, zSeries)

@item CIU
Customer-Initiated Upgrade [switch] ??? (IBM)

@item CIVIC
Cyclone Integrated Video Interfaces Controller (Apple)

@item CIX
Commercial Internet eXchange (ISP)

@item CJK
Chinese - Japanese - Korean [encoding]

@item CKOA
Cygwin Keeper of Acronyms (Cygwin, OLOCA)

@item CKRM
Class-based Kernel Resource Manager / Management

@item CL
Column Address Strobe Latency (CAS, IC)

@item CL
ConnectionLess (CO)

@item CL
Control Language (IBM, OS/400)

@item CL
Conversion Layer (HiperLAN/2, UMTS)

@item CLASS
Centralized Local Area Selective Signaling

@item CLASS
Custom Local Area Signaling Service

@item CLDC
Connected Limited Device Configuration (KVM, CDC, Java, JSR-139)

@item CLE
Certified Linux Engineer (Novell, Linux)

@item CLE
Certified Lotus Engineer (Lotus)

@item CLEC
Competitive Local Exchange Carrier

@item CLI
Call Level Interface (DB, SAG, X/Open, Oracle, Informix, MS, ...)

@item CLI
Class LIbrary (CLI)

@item CLI
CLear Interrupt (assembler)

@item CLI
Clearly Less Intimidating (slang, Cygwin)

@item CLI
Command Line Interpreter / Interface (OS)

@item CLI
Common Language Infrastructure (MS, .NET, ECMA, CLI)

@item CLIC
Chemnitzer LInux Cluster (Linux, Chemnitz), "CLiC"

@item CLIC
Computer Liability Insurance Coverage

@item CLID
Calling Line IDentification

@item CLIM
Common LISP Interface Manager (CLOS, LISP)

@item CLIW
Configurable Long Instruction Word (IC, CPU)

@item CLL
ConnectionLess Layer (UNI, NNI, ATM)

@item CLNAP
Connectionless Network Access Protocol (UNI, NNI, ATM)

@item CLNP
ConnectionLess Network Protocol (OSI, ISO 8473)

@item CLNS
ConnectionLess Network Service

@item CLOS
Common LISP Object System (LISP)

@item CLP
Cell Loss Priority (UNI, ATM, CLR)

@item CLP
Cumulative Licensing Program (Adobe)

@item CLR
Cell Loss Ratio (UNI, ATM, QOS)

@item CLR
Common Language Runtime (MS, CLI, .NET)

@item CLS
Card Loading Signal

@item CLS
Common Language Specification (OOP, CLR, MS, .NET, CLS)

@item CLSF
ConnectionLess Service Function

@item CLSID
CLasS IDentifier (COM)

@item CLTP
ConnectionLess Transport Protocol (OSI)

@item CLUG
Chemnitzer Linux User Group (Chemnitz, user group, Linux)

@item CLUT
Color LookUp Table (VGA)

@item CLV
Constant Linear Velocity (CD, MOD)

@item CLX
Class Library for cross platform (Delphi, Windows, Linux)

@item CM
Compatibility Mode (PARISC, NM)

@item CM
Configuration Management

@item CM
Configuration Manager (BIOS, PNP)

@item CM
Connection Management (RR, MM, GSM, mobile-systems)

@item CM2
Communication Manager /2 (IBM), "CM/2"

@item CM5
Connection Machine 5 (TMC)

@item CMAS
Cambridge Multiple Access System (OS)

@item CMC
Common Messaging Calls [interface] (XAPIA)

@item CMC
Complement Carry Flag (assembler)

@item CMC
Computer Mediated Communications [studies centre] (org., USA)

@item CMDS
Cambridge Model Distributed System (OS)

@item CME
Component Management Entity

@item CME
Core Managed Environment (Phoenix, MBR), "cME"

@item CMGA
Community of Massive Gaming Agents Internet, Germany, DTAG

@item CMGS
Cyan Magenta Gelb Schwarz (color system, DTP)

@item CMI
Coded Mark Inversion

@item CMI
Connection Manager Interface (IBM, SNA)

@item CMIA
China Medical Informatics Association (org., China)

@item CMIIW
Correct Me If I'm Wrong (slang, Usenet, IRC)

@item CMIP
Common Management Information Protocol (OSI, ISO, DP 9506, X.700)

@item CMIS
Common Management Information Service (OSI)

@item CMISE
Common Management Information Service Element (CMIS)

@item CMM
Color Management Method (DTP, ICM)

@item CMMI
Capability Maturity Model Integration

@item CMMU
Cache/Memory Management Unit

@item CMO
Chi Mei Optoelectronic (manufacturer)

@item CMOL
CMIP Over LLC (OSI, LLC)

@item CMOS
Complementary-symmetry Metal-Oxide Semiconductor (IC)

@item CMOT
CMIP Over TCP (OSI, RFC 1189, CMIP, TCP)

@item CMP
Chip MultiProcessing (IBM, HP, Sun)

@item CMP
Container-Managed Persistence (Java, EJB, BMP)

@item CMP
Cooperative Marketing Partner (DEC)

@item CMR
Cell Misinsertion Rate (ATM)

@item CMS
[Cambridge] / Conversational Monitor System (IBM, OS, VM, VME, VM/ESA, Z/VM)

@item CMS
Chip Multiprocessor System

@item CMS
Code Management System (DEC, CM)

@item CMS
Color Management System

@item CMS
Content Management Software / System

@item CMS
Cryptographic Message Syntax (cryptography, RFC 2630)

@item CMSS
???

@item CMT
Connection ManagemenT (FDDI)

@item CMTS
Cable MODEM Termination System (DOCSIS, MODEM)

@item CMU
Carnegie-Mellon-University (org.)

@item CMX
Communications Manager uniX (Unix)

@item CMY
Cyan Magenta Yellow (color system, DTP)

@item CMYK
Cyan Magenta Yellow blacK (color system, DTP)

@item CN
Communications Network

@item CN
Congestion Notification (IEE 802.1Qau, DCB)

@item CN
Connection Management (mobile-systems)

@item CN
Coordination Message (ISO 9646-3, TTCN)

@item CN
Copy Network

@item CN
Corporate Network

@item CNA
Certified Novell Administrator (Novell, Netware)

@item CNA
Communication Network Architecture (SEL)

@item CNA
Communications Network Application

@item CNA
CVE Numbering Authorities (CVE)

@item CNBC
Center for Neural Basis of Cognition (org., CMU, AI)

@item CNC
Communications Network Control

@item CNC
Computerized Numerical Control

@item CND
Caldera Network Desktop (Linux)

@item CND
Caller Number Delivery (MODEM)

@item CNE
Certified Netware Engineer (Novell, Netware)

@item CNE
Corporate Network Edition (eBlaster)

@item CNEPA
Certified Netware Engineers Professional Association (org., Netware)

@item CNET
Centre Nationale d'Etudes des Telecommunications (org., France)

@item CNI
Certified Netware Instructor (Novell, Netware)

@item CNI
Coalition for Networked Information (org.)

@item CNI
Common Network Interface

@item CNIDIR
Coalition for Networked Information DIRectories (Internet)

@item CNIL
Commission Nationale de l'Informatique et des Libertes (org., France)

@item CNM
Communications Network Management

@item CNM
Customer Network Management

@item CNMA
Communications Network for Manufacturing Applications

@item CNMS
Cylink Network Management System

@item CNNIC
China interNet Network Information Center (org., Internet, China)

@item CNP
Corporate Network Products (TPS)

@item CNPS
Computer Noise Prevention System

@item CNR
Communications and Network Riser

@item CNRCVUUCP
Compressed News ReCeive Via UUCP

@item CNS
Certified Novell Salesperson (Novell, Netware)

@item CNS
Complimentary Network Service

@item CNS
Compuserve Network Services (CIS)

@item CNTFET
Carbon Nano-Tube Field Effect Transistor

@item CO
Check Out (RCS)

@item CO
Connection Oriented (CL)

@item COA
Certificate of Authenticity (MS, Windows, XP)

@item COACH
Component based Open source ArCHitecture for distributed systems (CORBA)

@item COAS
Caldera Open Administration System (Linux)

@item COAST
Cache On A STick (Intel)

@item COAST
Computer Operations, Audit and Security Technology (org.)

@item COBOL
COmmon Business Orientated Language

@item COBRA
COmmunication technology: Basic Research and Applications (org., Netherlands)

@item COBRA
COmmunication technology: Basic Research and Applications

@item COBWEB
COntent-Based image retrieval on the WEB (WWW, ESPRIT)

@item COCA
Cost Of Cracking Adjustment (cryptography)

@item COCOT
Customer Owned Coin Operated Telephone

@item COD
Capacity On Demand (IBM, zSeries), "CoD"

@item COD
Connection Oriented Data

@item CODASYSL
Conference On DAta Systems Languages (Konferenz)

@item CODCF
Central Office Data Connecting Facility

@item CODE
Client/server Open Development Environment (Powersoft)

@item CODE
COlor Depth Enhancement (ATI)

@item CODEC
COder - DECoder

@item COE
Central Office Equipment

@item COE
Common Operating Environment [certification] (DISA, mil.)

@item COEES
COE Engineering System (COE)

@item COFDM
Coded Orthogonal Frequency Division Multiplexing (Digital audio, DAB)

@item COFEE
Computer Online Forensic Evidence Extractor (MS)

@item COFF
Common Object File Format (Unix)

@item COICA
Combating Online Infringement and Counterfeits Act

@item COIPX
Connection Orientated Internet Packet eXchange (Novell, Netware, IPX), "CO-IPX"

@item COL
Caldera Open Linux (Caldera, Linux)

@item COLD
Computer Output on LaserDisk

@item COLIBRI
COprozessor fuer LISP auf der Basis von RISC (RISC)

@item COLLADA
COLLAborative Design Activity (XML, 3D)

@item COM
Component Object Model (OLE, OLE2, OCX, ActiveX, MS)

@item COM
Computer Output on Microfilm

@item COM
Continuation of Message

@item COMA
Cache Only Memory Architecture (SMP)

@item COMAL
COMmon Algorithmic Language

@item COMDEX
COMputer Dealer's EXposition (fair)

@item COMIC
COnversational Multimodal Interaction with Computers [project] (Europe)

@item COMPARTS
COMputergestuetztes PARtner-TeilebestandsSystem (MBAG)

@item COMPTIA
COMPuting Technology Industry Association (org.)

@item COMTECH
COMputer TECHnologies (fair)

@item CONCERT
Communications for North Carolina Education, Research and Technology (network)

@item CONCISE
COSINE Network's Central Information Service for Europe (COSINE, network)

@item CONLAN
CONsensus LANguage (HDL)

@item CONS
Connection Oriented Networking Service

@item CONTAC
Central Office NeTwork ACcess

@item COOL
COBOL Object Orientated Language (OOP, COBOL)

@item COOP
Concurrent Object Orientated Programming (OOP)

@item COP
Character-Oriented Protocol

@item COPA
Child Online Protection Act (Internet, USA, CIPA)

@item COPP
Certified Output Protection Protocol (MS, RSA, WPE)

@item COPS
Common Open Policy Service protocol (RFC 2748)

@item COPS
Computer Oracle and Password System (Unix)

@item COPSPR
Common Open Policy Service for Policy Provisioning (COPS, RFC 3084), "COPS-PR"

@item CORAN
Communication ORiented Application aNalysis

@item CORBA
Common Object Request Broker Architecture (OMG)

@item CORDIS
COmmunity Research and Development Information Service (Europe)

@item COS
Card Operating System (OS, ICC)

@item COS
Cassette Operating System (OS)

@item COS
Class of Service

@item COS
Clip On Socket (CPU)

@item COS
Commercial Operating System (OS, DEC, PDP 11)

@item COS
Concurrent Operating System (OS, UNIVAC 9200, UNIVAC 9300)

@item COS
Corporation for Open Systems (org., OSI, user group)

@item COS
Cray Operating System (OS, Cray)

@item COSA
COmputerunterstuetzte SAchbearbeitung

@item COSA
COmputing in der Sozialen Arbeit (Org, Koeln, Germany)

@item COSE
Common Open Software Environment (HP, Sun, IBM, SCO, USL, Univel)

@item COSINE
Cooperation for OSI Networking in Europe (org.)

@item COSMOS
COmputer System for Mainframe OperationS

@item COSS
Common Object Services Specification

@item COST
COpenhagen SGML Tool (SGML), "CoST"

@item COT
Central Office Terminal

@item COTP
Connection-Oriented Transport Protocol (OSI, ISO 8073)

@item COTS
Commercial Off The Shelf (CC)

@item COTS
Connection-Oriented Transport [layer] Service

@item COW
Character Orientated Windows (MS, SAA, UI)

@item COW
Chrome Object Wrapper (Mozilla)

@item COW
Copy On Write

@item CP
Connection Processor

@item CP
Contention Period (DCF, MAC)

@item CP
Control Point (IBM, SNA)

@item CP
Control Program (IBM, OS, VM/ESA, VM)

@item CP
Coordination Point (ISO 9646-3, TTCN)

@item CPA
Collaboration Partner Agreement (CPPA, ebXML)

@item CPA
Collaboration Protocol Agreements (ebXML)

@item CPAN
Comprehensive PERL Archive Network (PERL)

@item CPC
Central Processing Complex

@item CPC
Cost Per Copy

@item CPCI
Compact Peripheral Component Interconnect (PCI), "cPCI"

@item CPCM
Content Protection Copyright Management (DVB, CPTWG)

@item CPCS
Common Part Convergence Sublayer (ATM)

@item CPDP
Cellular Digital Packet Data

@item CPE
Common Platform Enumeration (URI, NIST)

@item CPE
Continuing Professional Education

@item CPE
Customer Premises Equipment (ACS)

@item CPF
Control Program Facility (OS, IBM, S/38)

@item CPGA
Ceramic Pin Grid Array (IC, CPU)

@item CPH
Cost Per Hour

@item CPI
Characters Per Inch

@item CPI
Common Part Indicator (ATM)

@item CPI
Common Programming Interface (IBM, SAA)

@item CPI
Computer Private branch exchange Interface

@item CPI
Cost Per Instruction

@item CPIC
Common Programming Interface for Communications (IBM, SAA, API), "CPI/C"

@item CPIO
CoPy In/Out (Unix)

@item CPIRR
Common Programming Interface Resource Recovery (IBM, SAA)

@item CPL
Combined Programming Language (DEC, PL/1)

@item CPL
Common Public License (IBM, IPL)

@item CPL
Control Panel Applet (MS, Windows, XP)

@item CPL
Conversational Programming Language (DEC)

@item CPLB
Cache Protection Lookaside Buffer (Blackfin)

@item CPLD
Complex Programmable Logic Device (PLD, IC, RL)

@item CPM
Communication Processor Module (Motorola)

@item CPM
Control Program for Microcomputers (OS, DR), "CP/M"

@item CPM
Cost Per Minute

@item CPM
Critical Path Method

@item CPMS
Central Point Management Services (Central Point)

@item CPN
Calling Party Number

@item CPN
Compuserve Packet Network (network)

@item CPN
Customer Premises Network

@item CPNET
Control Program / NETwork (CP/M, OS), "CP/NET"

@item CPNOS
Control Program / ??? (CP/NET, CP/M, OS), "CP/NOS"

@item CPODA
Contention Priority Orientated Demand Assignment (MAC, PODA)

@item CPOL
Code Project Open License

@item CPP
Collaboration Partner Profile (CPPA, ebXML)

@item CPP
Collaboration Protocol Profiles (ebXML)

@item CPPA
Collaboration Partner Profile and Agreement (ebXML, XML)

@item CPPM
Content Protection for Pre-recorded Media (CPRM)

@item CPPS
Card / Paper tape Programming System (OS, IBM)

@item CPR
CPU Parameter Recall (Asus), "C.P.R."

@item CPRM
Content Protection for Recordable Media (CPPM)

@item CPS
Central Processing System

@item CPS
Characters Per Second

@item CPS
Cyber-Physical System

@item CPSI
Configurable PostScript Interpreter

@item CPSR
Computer Professionals for Social Responsibility (org., USA)

@item CPTWG
Copyright Protection Technical Working Group (DVB, WG)

@item CPU
Central Processing Unit

@item CPUID
Central Processing Unit IDentifier (CPU)

@item CPW
Cross-Platform Windowing [library] (OpenGL)

@item CQL
Cassandra Query Language

@item CR
Carriage Return (ASCII)

@item CR
Challenge-Response (SPAM)

@item CRAFT
Cray Research Adaptive FORTRAN (Cray, MPP, FORTRAN)

@item CRAM
Cache RAM (RAM)

@item CRAM
Card Random Access Memory (RAM, IC)

@item CRAS
Cable Repair Administrative System

@item CRC
Cyclic Redundancy Check[sum]

@item CRCG
[Fraunhofer] Center for Research in Computer Graphics (org., USA)

@item CRCG
Common Routing Connection Group

@item CRD
Color Rendering Dictionary (PS)

@item CREN
Corporation for Research and Educational Networking (network)

@item CRESTA
Collaborative Research into Exascale Systemware, Tools and Applications (Europe)

@item CRET
Color - Resolution Enhancement Technology (HP), "C-REt"

@item CRFVC
Connection Related Function Virtual Channel (UPC, UNI), "CRF(VC)"

@item CRFVP
Connection Related Function Virtual Path (UPC, UNI), "CRF(VP)"

@item CRI
Cray Research, Inc. (manufacturer)

@item CRIME
Compression Ratio Info-leak Made Easy (HTTPS)

@item CRIMM
Continuity Rambus Inline Memory Module (RIMM, IC, Rambus)

@item CRIN
Centre de Recherche en Informatique de Nancy (org., France)

@item CRISC
Complex-Reduced Instruction Set Computer

@item CRISP
Complex-Reduced Instruction Set Processor

@item CRISP
Cross Registry Internet Service Protocol (Internet, RFC 3707)

@item CRJE
Conversational Remote Job Entry (RJE)

@item CRL
Certificate Revocation List (cryptography)

@item CRL
Compile-time Reconfigurable Logic (RL)

@item CRLF
Carriage Return - Line Feed (ASCII, DOS)

@item CRM
Customer Relationship Management

@item CRML
Customer Relationships Markup Language (xCRL, predecessor)

@item CRP
Candidate Rendezvous Point (PIM, RP, Multicast), "C-RP"

@item CRP
Common Reference Platform (PowerPC)

@item CRPC
Center for Research on Parallel Computation (STC)

@item CRS
Cell Relay Service (UNI, ATM)

@item CRS
CMOS Reload Switch (CMOS, Gigabyte), "C.R.S."

@item CRT
Cathode Ray Tube

@item CRT
Computer Technology Research [corporation] (provider)

@item CRTC
Cathode Ray Tube Controller (EGA, VGA, MCGA)

@item CRTM
Core Root of Trust for Management (TCPA)

@item CS
Carrier Selection

@item CS
Chip Select (IC)

@item CS
Client/Server, "C/S" 

@item CS
Code Segment [register] (CPU, Intel, assembler)

@item CS
Coding Scheme (GPRS, mobile-systems)

@item CS
Computer Science

@item CS
Controlled Slip [error event] (DS1/E1)

@item CS
Convergence Sublayer (ATM)

@item CS1
Capability Set 1 (IN), "CS-1"

@item CS2
Capability Set 2 (IN)

@item CSA
Callpath Service Architecture (IBM, CTI)

@item CSA
Client Service Agent

@item CSA
Communication Streaming Architecture (Intel, MCH, DNB)

@item CSA
Configuration Status Accounting

@item CSAPI
Common Speller Application Program Interface (API)

@item CSC
Computer Sciences Corporation (provider)

@item CSCC
Concurrent SuperComputing Consortium (org.)

@item CSCD
Caldera Systems Curriculum Developers (Caldera)

@item CSCSI
Canadian Society for the Computational Studies of Intelligence (org., Canada, AI)

@item CSCW
Computer Supported Cooperative Work

@item CSD
Certified Scrum Developer (Scrum)

@item CSD
Control flow Specification Diagram (CASE)

@item CSD
Corrective Service Diskettes (IBM)

@item CSD
Customer Specific Dictionaries

@item CSDC
Circuit Switched Digital Capability

@item CSDC
Code Segment Descriptor Cache [register] (CS, Intel, CPU)

@item CSE
Client-Server Environment

@item CSEIA
[conference on] Computer Support for Environmental Impact Assessment (IFIP, conference)

@item CSEL
Cable SELect (EIDE, HD)

@item CSELT
Centro Studi E Laboratori Telecomunicazioni [s.p.a.] (org., Italy)

@item CSEM
Centre Suisse d'Electronique et de Microtecnique (org., Switzerland)

@item CSES
C-bit Severely Errored Seconds (DS3/E3, BIT)

@item CSG
Constructive Solid Geometry (CAD, CAM)

@item CSH
C SHell (Unix, BSD, Shell)

@item CSH
Complementary Software House (DEC)

@item CSI
Code Sequence Identification [technology] (Lavasoft, Ad-Aware)

@item CSI
Common Secure Interoperability (CORBA)

@item CSI
Common System Interface (Intel, Xeon)

@item CSI
CompuServe Incorporated (ISP)

@item CSI
Convergence Sublayer Indication (ATM)

@item CSIC
Customer Specific Integrated Circuit (IC, RL)

@item CSID
Caller Station IDentification (Fax)

@item CSIDS
Central command/Southern command Integrated Data System (mil., USA)

@item CSII
Center for Systems Interoperability and Integration (org., ???)

@item CSIP
Chipset Stable Image Program

@item CSIP
Commercial Stable Image Platform (AMD)

@item CSIRO
Commonwealth Scientific and Industrial Research Organization (org., UK)

@item CSIS
Central Schengen Information Systen (SIS, Europe, Strasbourg)

@item CSKI
Ceska Spolecnost pro Kybernetiku a Informatiku (org., Tschechien)

@item CSL
Callable Services Library (IBM, VM/ESA, CMS)

@item CSL
Computer SoLutions [software gmbh] (Haendler)

@item CSLIP
Compressed [headers] Serial Line Internet Protocol (SLIP, IP)

@item CSM
Certified Scrum Master (Scrum)

@item CSM
Cluster System Management (IBM)

@item CSM
Compatibility Support Module (UEFI)

@item CSMA
Carrier Sense Multiple Access

@item CSMACA
Carrier Sense Multiple Access with Collision Avoidance, "CSMA/CA" 

@item CSMACD
Carrier Sense Multiple Access with Collision Detection (IEEE 802.3, ethernet, CSMA/CD), "CSMA/CD"

@item CSMS
C Specific Media Support (NEST, MLID, Novell)

@item CSMUX
Circuit Switching MUltipleXer (FDDI), "CS-MUX"

@item CSN
Card Select Number (PNP)

@item CSNET
Computer + Science NETwork (USA, network, BITNET)

@item CSP
Centro Supercacolo Piemonte (org., Italy, HPC)

@item CSP
Chip Scale Package (IC)

@item CSP
Cloud Service Provider

@item CSP
Communicating Sequential Processes

@item CSP
Content Security Policy (Mozilla, Firefox)

@item CSP
Cross System Product (IBM)

@item CSPDN
Circuit Switched Public Data Network (IN)

@item CSPDU
Convergence Sublayer Protocol Data Unit (ATM, PDU), "CS PDU"

@item CSPO
Certified Scrum Product Owner (Scrum)

@item CSPP
Computer Systems Policy Project [group] (org., USA. manufacturer)

@item CSR
Cell misSequenced Ratio (ATM)

@item CSR
Cell Switch Router (Toshiba)

@item CSR
Certificate Signing Request (SSL)

@item CSRAM
Clock Synchronous Random Access Memory (RAM, IC)

@item CSRC
Computing Science Research Center (org., Berkeley, BSD)

@item CSRF
Cross Site Request Forgery (WWW, Internet)

@item CSRG
Computer Systems Research Group (org., Unix, BSD)

@item CSS
Cascading Style Sheets (HTML, XML, WWW, JavaScript)

@item CSS
Computer Sub System

@item CSS
Content Scrambling System (DVD, Matsushita, IBM)

@item CSS
Controlled Slip Seconds (DS1/E1)

@item CSS
Customer Switching System

@item CST
Central Standard Time [-0600] (TZ, CDT, USA)

@item CSTA
Computer Supported Telecommunications Applications (ECMA, CTI)

@item CSTB
Computer Science and Technology Board (org., NRC)

@item CSTC
Computer Security Technology Center (org., CIAC)

@item CSTO
Computing Systems Technology Office (org., ARPA)

@item CSTR
Centre for Speech Technology Research

@item CSTS
Computer Supported Telecommunications Standard

@item CSU
Channel Service Unit (ATM)

@item CSUNET
California State University NETwork (network, USA)

@item CSV
Client SMTP Validation (SMTP, SPAM)

@item CSV
Comma Separated Values

@item CT
[magazin fuer] Computer Technik, "c't" 

@item CT
Chipcard Terminal (ICC, CT)

@item CT
Chips & Technologies (manufacturer), "C&T"

@item CT
Clackamas Technology (Intel, Pentium, CPU)

@item CTAN
Comprehensive Tex Archive Network (TeX, FTP)

@item CTAPI
Chipcard Terminal Application Program Interface (ICC, CT, API), "CT-API"

@item CTB
Communication ToolBox (Apple)

@item CTC
Convolutional Turbo Coding (WIMAX, 802.16e)

@item CTCA
Channel To Channel Adapter (IBM, System/370)

@item CTCP
Client To Client Protocol (IRC)

@item CTCPEC
Canadian Trusted Computer Product Evaluation Criteria (Canada)

@item CTD
Cell Transfer Delay (UNI, ATM, QOS)

@item CTDW
Cygwin Technical Documentation Writer (Cygwin)

@item CTE
Compliance Test and Evaluation, "CT & E"

@item CTEA
Copyright Term Extension Act (USA, DRM)

@item CTEC
Certified Technical Education Center (MS)

@item CTERM
Command TERMinal (DEC)

@item CTI
Computer Telephony Integration

@item CTM
Clock To Master (CFM, Rambus)

@item CTM
Close To Metal (AMD, 3D)

@item CTM
Communication Trunk of Medium range Mil., Germany

@item CTOS
Cassette Tape Operating System (OS, Datapoint)

@item CTP
Community Technology Preview

@item CTP
Cordless Telephony Profile (Bluetooth)

@item CTR
[columbia university] Center for Telecommunications Research (org., USA)

@item CTR
Common Technical Regulations (Europe)

@item CTRON
Central TRON (TRON)

@item CTS
Cipher Text Stealing [mode] (cryptography)

@item CTS
Clear To Send (MODEM, RS-232)

@item CTS
Common Type System (OOP, CLR, MS, .NET, CLS)

@item CTS
Compatibility Test Suite (Sun, J2EE)

@item CTS
Conformance Testing Service (OSTC)

@item CTS
Cut-Through-Switch (FC, PMC-Sierra)

@item CTSM
C Topology Specific Module (NEST, MLID, Novell)

@item CTSS
Compatible Time Sharing System (Unix, predecessor, OS, MIT)

@item CTSS
Cray TimeSharing System (OS, Cray, LLNL)

@item CTT
Cartridge Tape Transport

@item CTT
Character Translation Table

@item CTTC
Cartridge Tape Transport Controller

@item CTV
Cell Tolerance Variation (ATM)

@item CTY
Console teleTYpe

@item CU
Call Up (Unix)

@item CU
see you (slang, Usenet, IRC)

@item CUA
Common User Application

@item CUCUG
Champaign-Urbana Computer Users Group (org., user group)

@item CUD
Color Universal Design (Eizo, LCD)

@item CUDA
Compute Unified Device Architecture (Nvidia, 3D)

@item CUI
Character User Interface (UI)

@item CUI
Common User Interface (AMS, UI)

@item CUL
Computer Und Lernen (org.)

@item CUL
see you Later (slang, Usenet, IRC)

@item CUP
Competitive UPgrade (MS)

@item CUPS
Common Unix Printing System (Unix, printing)

@item CUSI
Configurable Unified Search Interface (WWW)

@item CUSP
Commonly Used System Program (DEC)

@item CUT
Control Unit Terminal

@item CUU
ComputerUnterstuetzte Unterweisung

@item CVD
Chemical Vapor Deposition

@item CVE
Common Vulnerabilities and Exposures

@item CVF
Compressed Volume File (DOS)

@item CVIA
Computer Virus Industry Association (org., USA)

@item CVN
CounterVandalism Network (Wikia, VSTF)

@item CVS
Computer Vision Syndrome

@item CVS
Concurrent Versions System (Unix)

@item CVSD
Continuous Variable Delta Modulation (telecommunication)

@item CVSELP
Codex Vector Sum Excited Linear Prediction [algorithm] (Motorola, VOFR)

@item CVSS
Common Vulnerability Scoring System (NIAC)

@item CVW
MITRE Collaborative Virtual Workspace license

@item CWE
Common Weakness Enumeration

@item CWI
Centrum voor Wiskunde en Informatica (org., Netherlands)

@item CWIS
Campus Wide Information System

@item CWMI
Common Warehousing Metadata Interchange (DB, DWH)

@item CWP
Current Workspace Pointer (SPARC, CPU)

@item CWT
Character Width Table

@item CXFS
Clustered eXtended File System (SGI, RAID, XFS)

@item CXI
Common X-windows Interface (Unix)

@item CXML
Commerce eXtensible Markup Language (XML), "cXML"

@item CXTP
ConteXt Transfer Protocol (RFC 4067)

@item CYBOX
CYBer Observable eXpression, "CybOX"

@item CYMK
Cyan, Yellow, Magenta, blacK (color system)

@end table

