@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item F2C
FORTRAN to C [converter]

@item F2F
Frequency - Double Frequency

@item F2FS
Flash-Friendly File System (Linux, Samsung, FS), "F2fs"

@item FA
FernmeldeAmt (DTAG)

@item FAA
Flow Admission Acknowledge [message] (LFAP)

@item FABS
Fast Access Btree Structure

@item FAC
Final Assembly Code (IMEI, GSM, mobile-systems)

@item FACCH
Fast Associated Control CHannel (GSM, DCCH, mobile-systems)

@item FACE
Framed Access Command Environment (Unix, SVR4)

@item FACS
Firmware ACPI Control Structure (ACPI)

@item FADOS
Fast Amsterdam Distributed (???) Operating System (OS, FAMP)

@item FADT
Fixed ACPI Description Table (ACPI)

@item FADU
File Access Data Unit (FTAM)

@item FAE
Field Application Engineer

@item FAG
FernmeldeAnlagenGesetz telecommunication, Germany

@item FAI
Fully Automatic Installation

@item FAID
Flash Authority Identification Data (EEPROM)

@item FAIS
Finnish Artificial Intelligence Society (org., Finland, AI)

@item FAL
File Access Listener (DEC, DNA)

@item FAME
FORMEX Applied to Multilingualism in Europe (SGML, Europe)

@item FAMOS
Floating gate Avalanche injection Metal Oxide Semiconductor (IC)

@item FAMP
Fast Amsterdam MultiProcessor

@item FANP
Flow Attribute Notification Protocol (Toshiba, RFC 2129)

@item FAP
Flight Attendant Panel (Airbus, A380, CIDS, LCD)

@item FAPI
Family Application Programmer Interface (DOS, VDM, API)

@item FAQ
Frequently Asked Questions (slang, Usenet)

@item FAR
False Acception Rate

@item FAR
Fixed Alternative Routing (SNI)

@item FAR
Flow Admission Request [message] (LFAP)

@item FARE
Film Automatic Retouching and Enhancement (Canon, Scanner)

@item FARNET
Federation of American Research NETworks (network)

@item FAS
Flow Admission Service

@item FASMI
Fast Analysis of Shared Multidimensional Information (OLAP)

@item FAST
Fast ARM Solutions Toolkit (ARM, Palm, PDA)

@item FAST
First Application System Test

@item FAST
Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.)

@item FAT
File Allocation Table (DOS)

@item FATA
Fibre-Attached Technology Adapted (HP, SATA, HDD)

@item FAU
Flow Admission Update [message] (LFAP)

@item FAU
Friedrich-Alexander-Universitaet (org., Erlangen, Germany, Nuernberg, Germany)

@item FAW
Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm)

@item FAXP
FAX Profile (Bluetooth, SPP), "FaxP"

@item FB
Fiber optic Backbone

@item FBAS
FarbBild-AustastSystem / Farb-Bild-Austast-Synchron-signal (video)

@item FBDIMM
Fully Buffered Dual Inline Memory Module (DIMM, IC, RAM), "FB-DIMM"

@item FBL
Frame Burst error Length (CD)

@item FBM
Flexible Buffer Management (QMS)

@item FBPP
Federal Biometeric Protection Profile (NIAP)

@item FBS
Flexible Bandwidth Service (ATM, SDH)

@item FC
Federal Criteria [for information technology security] (NIST, USA)

@item FC
Feedback Control

@item FC
Fibre Channel (FC)

@item FC
Frame Control (FDDI, Token Ring)

@item FCA
Flow Control Ack (DLSW)

@item FCAL
Fibre Channel - Arbitrated Loop, "FC-AL" 

@item FCAPS
Fault, Configuration, Accounting, Performance, Security [management areas]

@item FCB
File Control Block (DOS)

@item FCBB
Fibre Channel BackBone (FCP), "FC-BB"

@item FCBS
File Control BlockS (DOS)

@item FCC
Fast Communication Controller (SCC, MCC)

@item FCC
Federal Communications Commission (org., USA)

@item FCC
Forward Carbon Copy (telecommunication)

@item FCCH
Frequency Correction CHannel (GSM, mobile-systems)

@item FCCN
Fundacao para a Computacao Cientifica Nacional (org., Portugal)

@item FCD
Floating Car Data

@item FCDAE
Fibre Channel Disk Array Enclosure (FC), "FC-DAE"

@item FCFS
First Come, First Served

@item FCGC
Flight Control and Guidance Computer (Airbus, A380)

@item FCGS4
Fibre Channel Generic Service 4 (FC, SAN, ANSI), "FC-GS-4"

@item FCH
Frame Control Channel (HiperLAN/2)

@item FCI
Fibre Channel Interface

@item FCI
Flow Control Indicator (DLSW)

@item FCI
Forward Cache Identifier (CATNIP)

@item FCIA
Fibre Channel Industry Association (org.)

@item FCIP
Fibre Channel over Internet Protocol (SAN, FC, IP)

@item FCL
Framework Class Library (MS, .NET)

@item FCMI
Fibre Channel Methodology for Interconnects (FC, SAN, ANSI), "FC-MI"

@item FCO
Flow Control Operator Bits (DLSW, BIT)

@item FCOE
Fibre Channel Over Ethernet, "FCoE"

@item FCOS
Flip Chip on Substrate

@item FCP
[SCSI-3] Fibre Channel Protocol (SAM)

@item FCPGA
Flip Chip Pin Grid Array (IC, CPU), "FC-PGA"

@item FCPH
Fibre Channel PHysical and signaling interface (SAM), "FC-PH"

@item FCR
Flow Change Request [message] (LFAP)

@item FCS
Fast Circuit Switching

@item FCS
First Customer Ship (IBM)

@item FCS
Frame Check Sequence (FDDI, Token Ring)

@item FCS
Frame Check Sum (MODEM)

@item FCSAN
Fibre Channel Storage Area Network (FC, SAN)

@item FCSC
Flight Control Secondary Computer (Airbus, A380)

@item FDA
FORTRAN Design Aid (FORTRAN)

@item FDAD
Functional Data ADministrator

@item FDC
Floppy Disk Controller (FDD)

@item FDCC
Federal Desktop Core Configuration (NVD, SCAP)

@item FDCT
Fast Discrete Cosine Transformation (DCT)

@item FDD
Floppy Disk Drive

@item FDD
Frequency Division Duplex (mobile-systems)

@item FDDI
Fiber Distributed Data Interface (ANSI, ISO 8314)

@item FDDITPPMD
FDDI Twisted Pair-Physical layer, Medium Dependent, "FDDI TP-PMD" 

@item FDE
Full Duplex Ethernet (ethernet)

@item FDES
Full Duplex EtherSwitch (Kalpana)

@item FDI
[fachverband der ] Fuehrungskraefte der Druckindustrie und Informationsverarbeitung (org.)

@item FDIS
Final Draft International Standard (MPEG)

@item FDL
File Definition Language

@item FDL
Free Documentation License (GNU)

@item FDM
Frequency Division Multiplexing (FDM)

@item FDMA
Frequency Division Multiple Access (mobile-systems)

@item FDMI
Flat Display Mounting Interface (VESA, MIS)

@item FDO
Functional Device Object

@item FDSN
Federation of Digital Seismograph Networks (org.)

@item FDT
Formal Description Technique

@item FDTDMA
Frequency Division/Time Division Multiple Access (mobile-systems, GSM), "FD/TDMA"

@item FDX
Full DupleX

@item FE
Focus Error (DVD)

@item FE
Forschung und Entwicklung, "F&E"

@item FE
Functional Entity (IN)

@item FEA
Functional Entity Action (IN, UNI)

@item FEAL
Fast Data Encipherment Algorithm (DES, cryptography)

@item FEAST
Fast Data Enciphering Algorithm (cryptography)

@item FEBE
Far End Block Error (SONET)

@item FEC
Forward Error Correction (GSM, mobile-systems)

@item FECN
Forward Explicit Congestion Notification (ATM)

@item FEDRAMP
FEDeral Risk and Authorization Management Program (USA), "FedRAMP"

@item FEFCO
???

@item FEIT
Fujitsu Enhanced Imaging Technology (Fujitsu)

@item FEK
File Encryption Key (cryptography)

@item FEM
Finite Elemente Methode

@item FEN
Free-net Erlangen/Nuernberg

@item FEP
Firewall Enhancement Protocol (RFC 3093)

@item FEP
Flight Envelope Protection (Airbus, A380)

@item FEP
Front End Processor

@item FER
Forward Error Correction (satellite)

@item FERF
Far End Receive Failure (UNI, ATM, SONET, OAM)

@item FESI
Federacion Espanola de Sociedades de Informatica (org., Spain)

@item FET
Field Effect Transistor

@item FF
Form(ular) Feed

@item FFAPI
File Format API (MS, API)

@item FFC
Fully Formed Character [printer]

@item FFDC
First Failure Data Capture

@item FFDT
FDDI Full Duplexing Technology (FDDI)

@item FFFS
Failsafe Flash File System (FS, Flash), "F3S"

@item FFII
Foerderverein fuer Freie Informationelle Infrastruktur (org.)

@item FFOL
FDDI Follow-On-LAN

@item FFS
Fallback Fault-tolerant Server (IBM, OS/2)

@item FFS
Fast File System (Unix, Amiga, Commodore)

@item FFS
Fast Filing System (BSD, Unix)

@item FFS
Flexible Fertigungs-Systeme

@item FFST2
First Failure Support Technology /2 (IBM), "FFST/2"

@item FFT
Final Form Text

@item FGA
Future Graphics Adapter (Spea)

@item FGCS
Fifth Generation Computer Systems [project] (ICOT)

@item FGPP
Fine Grained Password Policy (AD)

@item FGREP
Fixed Global Regular Expression Print (Unix, GREP)

@item FHGS
FreeHand Graphics Studio (Macromedia, DTP)

@item FHS
File system Hierarchy Standard (Linux, LSB)

@item FHSS
Frequency Hopping Spread Spectrum (WLAN)

@item FIA
Fiberoptic Industry Association (org.)

@item FIB
Forwarding Information Base (router, LAN, Internet)

@item FIBU
FInanzBUchhaltung

@item FIC
First International Computer [inc.] (manufacturer)

@item FICS
Free Internet Chess Server

@item FID
File IDentifier (APDU)

@item FID
File Identifier Descriptor (UDF, CD-R)

@item FIDO
Fast IDentity Online (org.)

@item FIDO
FIlter Device Object, "FiDO"

@item FIF
Fractal Interchange Format

@item FIFF
Forum Informatikerinnen Fuer den Frieden (org.)

@item FIFO
First In First Out (CPU)

@item FIG
Forth Interest Group (org., Forth)

@item FIGLET
Frank, Ian and Glenn's LETters (ASCII, fonts)

@item FILE
Free Internet Lexicon and Encyclopedia (WWW, DICT)

@item FILO
First In Last Out

@item FIMAS
Financial Institution Message Authentication Standard (banking, ANSI)

@item FINTS
FINancial Transaction Services (banking, HBCI), "FinTS"

@item FIOC
Frame Input/Output Controller

@item FIP
Facility Interface Processor

@item FIP
Factory Instrumentation Protocol

@item FIP
Fluorescent Indicator Panel

@item FIPA
Foundation for Intelligent Physical Agents (org., Agents)

@item FIPS
Federal Information Processing Standard (NIST, USA)

@item FIQ
Fast Interrupt reQuest (ARM, RISC)

@item FIR
Fast IRDA (IRDA)

@item FIR
Finite Impulse Response (DSP)

@item FIRE
Flexible Intelligent Routing Engine (3Com)

@item FIRE
Future Internet Research and Experimentation (Europe, CORDIS)

@item FIRMR
Federal Information Resources Management Regulations (USA)

@item FIRP
Federal Internet Requirements Panel (Internet, USA)

@item FIRS
Federated Internet Registry Service (LDAP, Internet)

@item FIRST
ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik (org., GMD, Berlin, Germany)

@item FIRST
Forum of Incident Response and SecuriTy (org., NIST)

@item FIS
FachInformationsSystem

@item FIS
FuehrungsInformationsSysteme

@item FISH
FIle transfer with a SHell, "FiSH"

@item FISMA
Federal Information Security Management Act (USA)

@item FIT
Failures In Time

@item FIT
Fraunhofer institut fuer angewandte InformationsTechnik (org.)

@item FITS
Functional Interpolating Transformation System

@item FITUG
Foerderverein Informationstechnik und Gesellschaft [e.V.] (org.)

@item FIU
Fingerprint Identification Unit (Sony)

@item FIZ
FachInformationsZentrum karlsruhe Org., Germany

@item FK
Foundation Kit (NextStep, OpenStep, Apple, Rhapsody)

@item FKS
Fernmelde-Klein-Steckverbindung (Westernstecker)

@item FL
Fiber optic Link

@item FLAC
Free Lossless Audio CODEC (CODEC, audio)

@item FLACC
Full Level Algol Checkout Compiler

@item FLAME
FLexible API for Module-based Environments (RL, API)

@item FLASK
FLux Advanced Security Kernel (DTOS)

@item FLC
Ferroelectric Liquid Crystal

@item FLEA
Four Letter Extended Acronym

@item FLEXIP
FLEXible Internet Protocol (Novell, Netware), "FLeX/IP"

@item FLIM
Faithful Library about Internet Message (EMACS, GNU)

@item FLOPS
FLoating-point Operations Per Second (CPU)

@item FLOWR
For, Let, Order by, Where, Return [principle] (DB, XML)

@item FLP
Fast Link Pulse (ethernet, LAN, NLP)

@item FLS
???

@item FM
Frequenz-Modulation

@item FMA
Federated Management Architecture (Java)

@item FMA
Fused Multiply Add [operation]

@item FMB
Flexible MotherBoard [design]

@item FMM
Flash Memory Manager (Intel)

@item FMO
Flexible Macroblock Ordering (AVC, video)

@item FMS
FernMeldeSystem

@item FMS
FORTRAN Monitor System (OS, IBM 709)

@item FMSB
Flip Mount Super Back-plate (Scythe), F.M.S.B.

@item FMTEYEWTK
Far More Than Everything You Ever Wanted To Know (slang, PERL)

@item FNC
Federal Networking Council (org., USA)

@item FNI
FachNormenausschuss Informationsverarbeitung [1962-1987] (DIN, NI, predecessor)

@item FO
Fiber Optic

@item FOA
Fiber Optic Association (org.)

@item FOAF
Friend Of A Friend [vocabulary] (RDF)

@item FOC
Fiber Optic Cable / Communications

@item FOCAL
FOrmula CALculator

@item FOCS
[symposium on] Foundations Of Computer Science (Konferenz)

@item FOD
Flexible Optical Disk (OD)

@item FODA
Formal specification of ODA document structures (ODA, ISO)

@item FODO
[international conference on] Foundations Of Data Organization and algorithms (conference, INRIA)

@item FOEBUD
[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBuD"

@item FOIRL
Fiber Optic InterRepeater Link (OWG)

@item FOKUS
Forschungszentrum fuer Offene KommUnikationsSysteme (org., GMD, Berlin, Germany)

@item FOLDOC
Free OnLine Dictionary Of Computing (WWW, UK)

@item FOLED
Flexible Organic Light Emitting Display (OLED)

@item FOMA
Freedom Of Multimedia Access (Japan, mobile-systems)

@item FOMAU
Fiber Optic MAU (ethernet, MAU)

@item FON
Fiber Optics Network

@item FOO
Friends Of O'reilly [meeting]

@item FOOBAR
FTP Operation Over Big Address Records (RFC 1639, FTP)

@item FOOT
Forum for Object Oriented Technology (CERN, OOP)

@item FOP
Feature Orientated Programming

@item FOP
Formatting Object Processor (Apache, XSL-FO)

@item FORMEX
FORMalised EXchange of electronic publications (SGML, Europe)

@item FORML
Formal Object Role Modelling Language

@item FORTRAN
FORmula TRANslation

@item FORTWIHR
FORschungsverbund fuer Technisch-WIssenschaftliches HochleistungsRechnen (org., Bavaria)

@item FORWISS
bayerisches FORschungszentrum fuer WISsensbasierte Systeme (org., KI)

@item FOSI
Format Output Specification Instance (SGML, CALS)

@item FOSS
Free and Open Source Software

@item FOSSFA
Free Software and Open Source Foundation for Africa (org., Africa)

@item FOSSIL
Fido Opus Seadog Standard Interface Layer

@item FOT
Fiber Optic Transceiver

@item FOTA
Firmware Over The Air

@item FOTE
Follow-on Operational Test and Evaluation, "FOT & E"

@item FOUC
Flash Of Unstyled Content (CSS)

@item FOURCC
FOUR Character Code (RIFF, TIFF, VFW, DivX)

@item FOV
Field Of View (VRML)

@item FOX
Field Operational X.500

@item FPA
Fast Packet Adaption (FPS, FPR)

@item FPA
Floating Point Accelerator

@item FPAA
Field Programmable ALU Array (IC, ALU, RL)

@item FPBGA
Fine Pitch Ball Grid Array (IC, CPU)

@item FPC
Floating Point Coprocessor

@item FPD
Flat Panel Display

@item FPDI
Flat Panel Display Interface (VESA)

@item FPDU
FTAM Protocol Data Unit (PDU)

@item FPE
Floating Point Engine

@item FPFA
Field Programmable Function Array

@item FPGA
Field Programmable Gate Array (RL)

@item FPI
Flux Changes per Inch (HDD)

@item FPI
Formal Public Identifier (DTD, SGML, SI)

@item FPI
Functional Process Improvement

@item FPK
Fast Packet Keying (WLAN, WEP, RSA, cryptography)

@item FPLA
Field Programmable Logic Array

@item FPLMTS
Future Public Land Mobile Telecommunications System (IN, mobile-systems)

@item FPM
Fast Page Mode [DRAM] (RAM, DRAM)

@item FPM
Fast Page Mode [ram] (RAM, DRAM, IC)

@item FPMDRAM
Fast Page Mode DRAM (RAM, DRAM, IC), "FPM-DRAM"

@item FPMPMI
Flat Panel Monitor Physical Mounting Interface [standard] [old term] (LCD, VESA, FDMI)

@item FPNW
File and Print service for NetWare (MS, Windows NT, DSMN)

@item FPODA
Fixed Priority Orientated Demand Assignment (MAC, PODA)

@item FPP
Fast-Parallel-Port

@item FPP
Floating Point Processor

@item FPP
FORTRAN Pre-Processor (FORTRAN)

@item FPP
Full Packaged Product (MS)

@item FPR
Fast Packet Relay (FPS, FPA)

@item FPR
Film Patterned Retarder (LCD)

@item FPR
Floating Point Register (FPU)

@item FPS
Fast Packet Switching (X.25, Datex-J)

@item FPS
First Person Shooter [game]

@item FPS
Frames Per Second

@item FPSE
Free PlayStation Emulator, "FPSe"

@item FPSE
FrontPage Server Extensions (Microsoft, IIS)

@item FPU
Floating Point Unit (CPU)

@item FQDN
Fully Qualified Domain Name (Internet)

@item FRAD
Frame Relay Access Device

@item FRAM
Ferroelectric Random Access Memory (RAM, IC)

@item FRC
Frame Rate Control (PDP)

@item FRD
Functional Requirements Description

@item FRF
Floatingpoint Register File (DEC, Alpha, CPU)

@item FRICC
Federal Research Internet Coordinating Committee (org.)

@item FRL
Frame Representation Language (AI)

@item FRMR
FRaMe Reject (HDLC, LAPB, SDLC)

@item FROM
Factory Read Only Memory (ROM)

@item FRR
False Rejection Rate

@item FRR
Functional Recovery Routine

@item FRS
Flexible Route Selection

@item FRS
Frame Relay Service (ATM, UNI)

@item FS
File System (LVM)

@item FS
Forward Secrecy (cryptography, PFS)

@item FS
Frame Status (FDDI, Token Ring)

@item FSAG
Free Software Association of Germany (org.)

@item FSB
For Small Business (Novell)

@item FSB
Front Side Bus

@item FSC
Fujitsu Siemens Computer (manufacturer)

@item FSCK
File System Consistency checK (Unix)

@item FSD
File System Driver

@item FSF
Free Software Foundation (org., GNU)

@item FSFE
Free Software Foundation Europe (org., FSF)

@item FSG
Free Standards Group (org.)

@item FSH
File System Hierarchy (Linux, LSB)

@item FSIP
Full Scale InPut (FSOP)

@item FSK
Frequency Shift Keying (telecommunication)

@item FSM
Finite State Machine (TTCN, ...)

@item FSM
Freiwillige Selbstkontrolle Multimedia Org., Germany

@item FSMGDOS
Font Scaling Manager - Graphics Device Operating System (OS, Atari), "FSM-GDOS"

@item FSMO
Flexible Single Master Operations (AD)

@item FSO
[scripting runtime library] File System Objects (MS, WSH)

@item FSOP
Full Scale OutPut (FSIP)

@item FSOS
Free Standing Operating System (OS)

@item FSP
File Slurping Protocol

@item FSPF
Fibre channel Shortest Path First

@item FSRM
File Server Resource Manager (AD)

@item FSRTL
File System RunTime Library

@item FSS
Fair Share Scheduler (Solaris, Sun)

@item FSS
Fast System Switch (Unix)

@item FSSUTF
FileSystem Safe UCS Transformation Format (UCS, Unicode), "FSS-UTF"

@item FST
Flat Square Technology (Hitachi)

@item FSTN
Film SuperTwisted Nematic (LCD)

@item FSTP
Foiled Shielded Twisted Pair [cable] (STP, TP), "F/STP"

@item FSU
Free Software Union (org.)

@item FSV
Flexible Sender Validation (SPAM)

@item FSVO
For Some Value Of (slang, Usenet, IRC)

@item FT1
Fractional T1 (ISDN, T1, DS-0, DS-1)

@item FTA
Floptical Technology Association (3M u.a.)

@item FTAM
File Transfer, Access and Management (GOSIP, ISO 8571/8572)

@item FTBFS
Fails To Build From Source (Linux, Debian, slang)

@item FTC
Federal Trade Commission (org., USA)

@item FTE
[DCOM] For The Enterprise (DCOM, SAG)

@item FTL
Flash Translation Layer

@item FTM
File Transfer Manager (PDA, Casio)

@item FTN
Fido Technology Network (FidoNet)

@item FTNA
File Transfer Access and Management

@item FTNEA
File Transfer NEtwork Architecure (SNI)

@item FTOS
File Transfer Open Systems

@item FTOS
File Transfer OSI Support

@item FTP
File Transfer Protocol (Internet, RFC 959)

@item FTP
Foiled Twisted Pair [cable] (UTP, TP)

@item FTPD
File Transfer Protocol DAEMON (FTP)

@item FTR
Full Text Retrieval

@item FTS
Fidonet Technical Standard

@item FTS2000
Federal Telecommunications Services - 2000 (USA), "FTS-2000"

@item FTSC
Federal Telecommunications Standards Committee (org., USA)

@item FTSC
Fidonet Technical Standard Conference (Konferenz)

@item FTTC
Fiber To The Curb

@item FTTH
Fibre To The Home (FTTN)

@item FTTLA
Fiber To The Last Amplifier

@item FTTN
Fibre To The Node (FTTH)

@item FTZ
FernmeldeTechnische Zentralamt / Zulassung (DTAG, ZZF, predecessor)

@item FUA
Flow Update Acknowledge [message] (LFAP)

@item FUB
Freie Universitaet Berlin (org.)

@item FUBAB
Fouled / Fucked Up Beyond All Belief (slang, Usenet, IRC)

@item FUBAR
Failed UniBus Address Register (VAX)

@item FUBAR
Fouled / Fucked Up Beyond All Recognition / Repair (slang, Usenet, IRC)

@item FUD
Fear, Uncertainty & Doubt (slang, IBM)

@item FUHD
Full Ultra HD [7680x4320] (HD)

@item FUN
Flow Update Notification [message] (LFAP)

@item FUNI
Frame User Network Interface

@item FUSE
Filesystem in USErspace (Linux)

@item FUSSP
Final Ultimate Solution to the SPAM Problem (SPAM)

@item FUEV
Fernmeldeanlagen-UEberwachungsVerordnung

@item FVD
Forward Versatile Disc (China, WMV)

@item FWH
FirmWare Hub (BIOS, Intel)

@item FWIW
For What It's Worth (slang, Usenet, IRC)

@item FWS
Folding White Space (RFC 1822)

@item FWT
Fast Wavelet Transformation

@item FXO
Foreign eXchange Office (FXS)

@item FXS
Foreign Exchange System / Subscriber (FXO)

@item FXU
FiXed point Unit (POWER, CPU)

@item FYI
For Your Information (slang, Usenet, IRC)

@item FZA
??? [compression]

@item FZI
ForschungsZentrum Informatik (org., Uni Karlsruhe, Germany)

@end table

