@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item RA
Real Address (Power4, IBM, CPU)

@item RA
Registration Authority (PKI, ITU, cryptography)

@item RA
Remote Access (BBS)

@item RABF
Redundant Accumulative Backhitchless Flush (IBM, Streamer)

@item RAC
Random Access Channel (HiperLAN/2)

@item RAC
Real Application Cluster (Oracle)

@item RACE
Research and technology development in Advanced Communications technologies in Europe (Europe, predecessor, CORDIS)

@item RACE
Rowbased ASCII Compatible Encoding (ASCII, Internet, VeriSign/NSI)

@item RACER
Renamed Abox and Concept Expression Reasoner

@item RACF
Resource Access Control Facility (IBM, MVS/ESA)

@item RACH
Random Access CHannel (GSM, CCCH, mobile-systems)

@item RAD
Rapid Access Disk

@item RAD
Rapid Application Development [toolkit] (Delphi, Borland)

@item RAD
Research And Development [data communications] (manufacturer)

@item RADIUS
Remote Authentication Dial-In User Service (RFC 2865)

@item RADSL
Rate Adaptive Digital Subscriber Line (ADSL)

@item RAFF
Rotary Acceleration Feed Forward (WD, HDD)

@item RAI
Remote Alarm Indication (DS3/E3)

@item RAID
Redundant Array of Independent / Inexpensive Disks (HDD, RAID)

@item RAIDIOS
RAID I/O Steering (Intel, RAID)

@item RAII
Resource Acquisition Is Initialization

@item RAIR
Random Access Information Retrieval

@item RAL
ReichsAusschuss fuer Lieferbedingungen (IEC 12119)

@item RAL
Rutherford Appleton Laboratory (org., UK)

@item RAM
Random Access Memory (RAM, IC)

@item RAM
Rarely Adequate Memory (slang)

@item RAM
Rate Adaptive Mode (DSL)

@item RAMDAC
Random Access Memory Digital to Analog Converter (RAM)

@item RAMIS
Rapid Access Management Information System

@item RAMP
Remote Access Maintenance Protocol

@item RAMPS
Reliability, Availability, Manageability, Performance and Scalability (DB)

@item RAMS
Record Archival Management System

@item RAN
Radio Access Network

@item RAND
Rural Area Network Design

@item RAP
[internet] Route Access Protocol (RFC 1476, Internet)

@item RAP
Remote Access Point

@item RAP
Rich Ajax Platform (RCP, Eclipse)

@item RAPID
Resource And Performance Interactive Display system

@item RAPS
Real Application on Parallel Systems

@item RARE
Reseaux Associes pour la Recherche Europeenne (org.)

@item RARP
Reverse Address Resolution Protocol (Internet, RFC 903)

@item RAS
Reliability, Availability and Serviceability (IBM)

@item RAS
Remote Access Software

@item RAS
Row Address Strobe (IC, DRAM)

@item RAT
Register Allocation Table (Intel, CPU)

@item RAT
Remote Access Tool

@item RAT
Remote Access Trojan

@item RATP
Reliable Asynchronous Transfer Protocol (RFC 916)

@item RATS
Radio-Amateur Telecommunications Society (org., USA)

@item RATS
Rough Auditing Tool for Security (WWW, CGI, PERL, PHP,...)

@item RAVE
Relational Advanced Visual Environment

@item RAW
Read-After-Write (WAW, WAR)

@item RBA
Relative Byte Address

@item RBAC
Role Based Access Control (SELinux)

@item RBBS
Remote Bulletin Board System (BBS)

@item RBF
Random Block Filemanager (OS-9)

@item RBH
Remote Bridge Hub

@item RBL
Realtime Blackhole / Block List (Internet, SPAM)

@item RBM
Realtime Batch Monitor (OS, Xerox)

@item RBMS
Remote Bridge Management Software

@item RBOC
Regional Bell Operating Company (USA)

@item RC
Reconfigurable Computer / Computing (RL)

@item RC
Region Co-ordinator (FidoNet)

@item RC
Release Candidate (MS)

@item RC
Return Code (REXX, ...)

@item RC
Routing Control

@item RC2
Rivest Cipher / Ron's Code 2 (cryptography)

@item RC4
Rivest Cipher / Ron's Code 4 (cryptography)

@item RC5
Rivest Cipher 5 (RFC 2040, cryptography)

@item RCAS
Reserve Component Automation System

@item RCC
Radio Common Carrier

@item RCC
Regional Control Center

@item RCC
Remote Cluster Controller

@item RCC
Routing Control Center

@item RCD
Receiver-Carrier Detector

@item RCE
Regional Code Enhancement (DVD)

@item RCE
Resident Command Extension (DOS)

@item RCF
Reader's Comment Form (IBM)

@item RCF
Remote Call-Forwarding

@item RCGI
Remote Common Gateway Interface (CGI, WWW, Novell)

@item RCL
Runtime Control Library

@item RCM
Remote Carrier Module

@item RCP
Remote Copy Program

@item RCP
Rich Client Platform (Eclipse, Java)

@item RCS
Reloadable Control Storage

@item RCS
Remote Connection Service (IBM, OS/2, LAN)

@item RCS
Resource Construction Set

@item RCS
Revision Control System (Unix, CM, GNU)

@item RCTC
Rewritable Consumer Time Code (video)

@item RCTL
Resistor-Capacitor-Transistor Logic

@item RCW
Runtime Callable Wrapper (.NET, COM, DLL)

@item RD
Receive Data (MODEM)

@item RD
Recursive Design (CASE)

@item RD
Remove Directory (DOS, OS/2)

@item RD
Research and Development, "R&D"

@item RD
Route Descriptor

@item RDA
Remote Database Access (ISO, OSI)

@item RDB
Receive Data Buffer

@item RDB
Relational DataBase (DB)

@item RDB
Rigid Disk Block (Amiga, Commodore)

@item RDBMS
Relational DataBase Management System (DBMS, DB)

@item RDBMSMIB
Relational DataBase Management System - Management Information Base (DB), "RDBMS-MIB" 

@item RDC
Remote Data Connector

@item RDD
Random Digital Dial

@item RDD
Replaceable Database Driver (Clipper, CA-VO, DB)

@item RDDL
Resource Directory Description Language (XHTML, XML)

@item RDE
Received Data Enable

@item RDE
Redundant Data Elimination (Falconstor, VTL)

@item RDE
Ruby Development Environment (Ruby, IDE)

@item RDES
Remote Data Entry System

@item RDF
Rate Decrease Factor

@item RDF
Record Definition Field

@item RDF
Resource Description Framework (XML, IBM, Netscape, MS, ..., WWW)

@item RDFS
Resource Description Framework Scheme (RDF)

@item RDH
RSA-DES-Hybridverschluesselung (cryptography, HBCI)

@item RDI
Remote Defect Identification / Indicator (UNI)

@item RDL
Relational Database Language (DB)

@item RDL
Remote Digital Loopback

@item RDLAP
Radio Data Link Access Protocol (MODACOM), "RD-LAP"

@item RDM
Relational Data Modeler

@item RDM
Reliably Delivered Message

@item RDMA
Remote Direct Memory Access (VI, Infiniband)

@item RDN
Relative Distinguished Name (X.500)

@item RDNCRC
Research Data Network Cooperative Research Centre (org., Australia)

@item RDO
Remote Data Objects (DB)

@item RDO
Resource Definition Online (CICS, IBM)

@item RDP
Reliable Datagram Protocol

@item RDP
Remote Desktop Protocol (MS)

@item RDP
Remote Display Protocol (MS, Windows NT, ASP)

@item RDQL
Resource Description Query Language (RDF, HP, Java)

@item RDR
Remote Data Recovery (Ontrack)

@item RDR
Request Data with Reply (Feldbus)

@item RDRAM
Rambus Dynamic Random Access Memory (RAM, IC, Rambus)

@item RDRN
Rapidly Deployable Radio Networks (USA, Uni Kansas)

@item RDS
Radio Digital System

@item RDS
Rapid Development System (DB, Informix)

@item RDS
Remote Data Services

@item RDSN
Region Digital Switched Network

@item RDT
Radio Digital Terminal

@item RDT
Restricted Data Transmissions

@item RDTP
[secure] Raw Data Transfer Protocol

@item RE
RAID Edition (WD, RAID)

@item RE
Recommendation Engine (OP, Oracle, DB)

@item RE
Research and Engineering, "R&E"

@item REACH
Research and Educational Applications of Computers in the Humanities

@item READ
Relative Element Address Designate (cryptography)

@item READSL
Reach Extended Asymmetric Digital Subscriber Line (ADSL, DSL), "RE ADSL"

@item REBOL
Relative Expression Based Object Language

@item REGEX
REGular EXpressions (GREP, EMACS, ...)

@item REGIS
REmote Graphics Instruction Set

@item REGTP
REGulierungsbehoerde fuer Telekommunikation und Post Org., Germany, "RegTP"

@item REHMUDI
REdHat MUltimedia Distribution (RedHat, Linux), "ReHMuDi"

@item REM
Remote Equipment Module

@item REM
Ring Error Monitor

@item REMIS
Real Estate Management Information System

@item REMOS
Resources Management On-Line System

@item REPL
Read Eval Print Loop

@item RES
Remote Entry Services

@item REST
REpresentational State Transfer (URL, AWS)

@item RESTENA
RESeau Teleinformatique de l'Education NAtionale et de la recherce (network, Luxembourg)

@item RET
Report Engine Technology (CA, DB)

@item RET
Resolution Enhancement Technology (HP), "REt"

@item RETM
Rare Earth / Transition Metal (MO), "RE/TM"

@item REXX
Restructured EXtended eXecutor [language] (IBM, SAA, ANSI)

@item RF
Radio Frequency (mobile-systems)

@item RFA
Request for Assistance (Internet)

@item RFB
Remote FrameBuffer [protocol]

@item RFC
Remote Function Call (SAP, CPIC)

@item RFC
Request For Change (PERL, ITIL)

@item RFC
Request For Comments (Internet, RFC)

@item RFD
Ready-For-Data

@item RFD
Report Fragmentation Done [bit] (CATNIP, BIT)

@item RFD
Request For Discussion (Internet, Usenet), "RfD"

@item RFE
Request For Enhancement (Internet)

@item RFI
Radio Frequency Interference

@item RFI
Remote File Inclusion

@item RFI
Request For Information (Internet)

@item RFIC
Radio Frequency Integrated Circuit (IC)

@item RFID
Radio Frequency IDentification (ANSI, NCITS)

@item RFMS
Remote File Management System

@item RFNM
Request For Next Message (IMP)

@item RFOG
Radio Frequency Over Glass (HFC, ANSI/SCTE 174 2010), "RFoG"

@item RFP
Request for Package (Linux, Debian)

@item RFP
Request For Proposal (Internet)

@item RFQ
Request for Quatation

@item RFS
Remote File Sharing (AT&T, Unix)

@item RFS
Remote File System

@item RFS
Remote Forensic Software

@item RFS
Request For Sponsor (Linux, Debian)

@item RFS
REXX File System (REXX, CICS, VSAM, IBM)

@item RFT
Request For Technology (OSF)

@item RFT
Revisable Form Text

@item RFTS
Remote File Transfer System (DDVS)

@item RGB
Rot Gruen Blau / Red Green Blue (color system, DTP)

@item RGBA
Red Green Blue Alpha-[byte] (color system, RGB)

@item RGBE
Red Green Blue Emerald (color system, photo, Sony)

@item RGMS
Rotated Grid MultiSampling (graphics)

@item RGP
Raster Graphics Processor

@item RGP
Remote Graphics Processor

@item RH
Request Header

@item RHCE
Red Hat Certified Engineer (RedHat, Linux)

@item RHCT
Red Hat Certified Technician (RedHat, Linux)

@item RHCX
Red Hat Certified eXaminer

@item RHEL
Red Hat Enterprise Linux (Linux, RedHat)

@item RHS
Right Hand Side (NGSCB, MS, Palladium)

@item RI
Reference Implementation (JCP)

@item RI
Ring Indicator (RS-232, MODEM)

@item RI
Routing Information

@item RIA
Rich Internet Application (WWW, Macromedia)

@item RIACS
Research Institute for Advanced Computer Science (org.)

@item RID
Relative IDentifier (AD, SID, ACL)

@item RIDE
Research Issues in Data Engineering (IEEE-CS)

@item RIE
Reactive Ion Etching (IC)

@item RIF
Requirements Interchange Format (HIS)

@item RIF
Routing Information Field (Token Ring)

@item RIFF
Resource Interchange File Format (MS, IBM, MM)

@item RIG
Related Interest Group

@item RIG
Rochester Intelligent Gateway (OS)

@item RII
Routing Information Indicator

@item RIM
Registry Information Model (ebXML)

@item RIM
Remote Installation and Maintenance

@item RIME
Relaynet International Message Exchange

@item RIML
Renderer Independent Markup Language (XML, Consensus)

@item RIMM
Rambus Inline Memory Module (Rambus, IC)

@item RINEX
Receiver INdependent EXchange [format] (GPS)

@item RIO
Redistributed Internet Objects (S3, VRML, Internet)

@item RIO
Remote Input/Output (Power4, IBM)

@item RIOCP
??? (OS), "RIO/CP "

@item RIP
Raster Image Processor (DTP)

@item RIP
Remote Imaging Protocol (BBS)

@item RIP
Return Instruction Pointer (CPU, RAM)

@item RIP
Routing Information Protocol (BSD, IGP, RFC 1721, IP)

@item RIPE
Reseaux IP Europeenne (Europenet)

@item RIPL
Remote Initial Program Load (IBM)

@item RIPNG
Routing Information Protocol Next Generation (RIP, IPV6, RFC 2080), "RIPng"

@item RIPS
Raster Image Processing Systems corporation (manufacturer)

@item RIR
Regional Internet Registry (Internet)

@item RIS
Remote Installation Service (MS, ADS)

@item RISC
Reduced Instruction Set Code (CPU)

@item RISC
Research Institute for Symbolic Computation (org., Austria)

@item RISCOS
RISC Operating System (MIPS, Acorn, OS), "RISC OS"

@item RISLU
Remote Integrated Services Line Unit

@item RISS
[StorageWorks] Reference Information Storage System (HP)

@item RITECH
Resolution Improvement TECHnology (Epson)

@item RITSEC
Regional Information Technology and Software Engineering Center

@item RJ45
Registered Jack 45 (cable)

@item RJE
Remote Job Entry (IBM, Internet, RFC 407)

@item RJEF
Remote Job Entry Function

@item RJP
Remote Job Processing

@item RKO
RootKey Operator (DNS)

@item RKRM
ROM Kernel Reference Manual (Amiga, Commodore)

@item RL
Real Life (telecommunication, Usenet, IRC)

@item RL
Reconfigurable Logic (RL)

@item RLC
Radio Link Control (GPRS, mobile-systems)

@item RLDRAM
Reduced-Latency Dynamic Random Access Memory (RAM, DRAM, IC)

@item RLE
Run-Length Encoded

@item RLIN
Research Libraries Information Network (network)

@item RLL
Run Length Limited [encoding]

@item RLM
Redundant Lock Manager (GFS)

@item RLN
Remote LAN Nodes (LAN)

@item RLP
Radio Link Protocol (GSM, mobile-systems)

@item RLP
Resource Location Protocol (Internet, RFC 887)

@item RLPR
Remote Line Printing Request (LPR, printing)

@item RLS
Read Link error Status (FCP)

@item RLS
Received Line Signal

@item RLSD
Received Line Signal Detector

@item RLSFB
Read Last Spool File Buffer (IBM, VM/ESA, CP)

@item RLT
Remote Line Test

@item RLV
RingLeitungsVerteiler

@item RM
Resource Management

@item RM
Retention Module

@item RMA
Remote Memory Access

@item RMAS
Remote Memory Administration System

@item RMATS
Remote Maintenance Administration and Traffic

@item RMC
Rambus Memory Controller (Rambus)

@item RMC
Rational Method Composer (RUP, IBM)

@item RMCOS
Ryan-McFarland COBOL (????) Operating System (OS, COBOL), "RM/COS"

@item RMCP
Remote Management Control Protocol

@item RMF
Resource Measurement Facility (IBM, MVS)

@item RMI
Remote Method Invocation (Java, API)

@item RMIC
Remote Memory In Cassette (IBM, Streamer, WORM, MIC), "R-MIC"

@item RMM
Ring Management Module (Token Ring)

@item RMODP
Reference Model - Open Distributed Processing (RUP), "RM-ODP"

@item RMON
Remote MONitoring

@item RMOS
Realtime Multitasking Operating System (SNI, OS)

@item RMS
Reason Maintenance System (AI)

@item RMS
Reliant Monitor Services (FSC)

@item RMS
Remote Monitoring System [bus]

@item RMS
Richard Matthew Stallman (FSF, EMACS)

@item RMS
Rights Management Services (MS, Windows, NGSCB)

@item RMT
Raw Magnetic Tape (Unix)

@item RMT
Reliable Multicast Transport (IETF, WG, Multicast)

@item RMT
REXXware Migration Tool (Simware, REXX)

@item RMT
Ring ManagemenT (FDDI, SMT)

@item RMX
Reverse Mail eXchange (DNS, SPAM)

@item RNA
Remote Network Access

@item RNC
Radio Network Controller (mobile-systems, UMTS, RAN)

@item RND
RAD Network Devices (RAD, manufacturer)

@item RNG
Random Number Generation

@item RNI
Raw Native Interface (MS, Java)

@item RNID
Request Node IDentification (FCP, SNIA, HBA, API)

@item RNM
Resistors Network Method (audio)

@item RNOC
Regional Network Operations Center

@item RNPRSFP
Read Next PRint Spool File Block (IBM, VM/ESA, CP)

@item RNPUFSB
Read Next PUnch Spool File Block (IBM, VM/ESA, CP)

@item RNR
Receive Not Ready (LAPB)

@item RNSB
Read Next Spool Buffer (IBM, VM/ESA, CP)

@item RNUI
Remote Network User Identification (Datex-P)

@item RO
Read-Only (I/O)

@item ROAMS
Reusable Object Access and Management System

@item ROC
RAID On a Chip (RAID)

@item ROC
Reconstruction Of Color (ICE, Scanner)

@item ROCF
Remote Object Class Factory

@item ROD
Rewritable Optical Disk (OD)

@item RODC
Read-Only Domain Controller (MS, AD)

@item ROFL
Roar Out From Laughing (slang, Usenet, IRC)

@item ROHC
RObust Header Compression (RFC 3095/3759, RTP, UDP, ESP)

@item ROHS
Restriction Of the use of certain Hazardous Substances in electrical and electronical equipment (Europe), "RoHS"

@item ROLAP
Relational OnLine Analytical Processing (OLAP, DB)

@item ROLC
Routing Over Large Clouds

@item ROM
Read Only Memory (ROM)

@item ROMB
RAID On MotherBoard (RAID)

@item ROMBIOS
Read-Only Memory - Basic Input Output System (ROM, BIOS), "ROM-BIOS"

@item ROMC
Required Operational Messaging Characteristics

@item ROMP
Research Office products division MultiProcessor (IBM, AIX)

@item ROP
Remote Operations Service (IBM, OS/2)

@item ROP
Return Orientated Programming

@item ROS
Read-Only Storage

@item ROS
Resident Operating System (OS)

@item ROSE
[CAE] Real-time Object-based Simulation Environment

@item ROSE
Remote Operations Service Element (OSI, RPC)

@item ROT
Running Object Table (MS, Windows)

@item ROTFL
Rolling On The Floor Laughing (slang, Usenet, IRC)

@item ROTFLBTC
Rolling On The Floor Laughing and Biting The Carpet (slang, Usenet, IRC)

@item ROTFLMAO
Rolling On The Floor Laughing My Ass Off (slang, Usenet, IRC)

@item RP
Rapid Prototyping (CNC, CAD)

@item RP
Relay Party (IRC)

@item RP
Rendezvous Point (PIM, Multicast)

@item RPA
Remote Phrase Authentication

@item RPC
Region Playback Control (DVD)

@item RPC
Remote Procedure Call (Sun, Xerox, OSF, ECMA, RFC 1831)

@item RPC2
Region code Playback Control phase 2 (DVD), "RPC-2"

@item RPCL
Remote Procedure Call Language (ONC, Sun)

@item RPCS
Refined Printing Command Stream (Ricoh)

@item RPDFP
Remote Physical Device Finger Printing (NAT, IP)

@item RPE
Remote Peripheral Equipment

@item RPELTP
Regular Pulse Excitation with Long-Term Prediction [loop] (LPC), "RPE-LTP"

@item RPF
Rendezvous Point Forwarding (PIM, MSDP, Multicast, RP)

@item RPF
RePeat active File (IBM, VM/ESA, CP)

@item RPF
Reverse Path Forwarding (PIM, Multicast)

@item RPG
Report Program Generator

@item RPG
Role Playing Game

@item RPL
Remote Program Load

@item RPL
Requested Privilege Level

@item RPL
Resident Programming Language

@item RPM
Radio Packet Modem (Motorola)

@item RPM
Redhat Package Manager (Linux)

@item RPM
Remote Port Module (Ascend)

@item RPN
Reverse Polish Notation

@item RPP
Relative Processor Performance (CPU, Cray)

@item RPS
Read Port Status (FCP)

@item RPS
Realtime Programming System (OS, IBM)

@item RQBE
Relational Query By Example (DB, QBE)

@item RR
Radio Resource management (MM, CM, GSM, mobile-systems)

@item RRAS
Routing and Remote Access Service (MS, Windows NT)

@item RRCM
Reservation Request Control Mechanism (DQDB)

@item RRDS
Relative Record Data Set (VSAM)

@item RRIP
Rock Ridge Interchange Protocol (CD, Unix)

@item RRO
Radial Run Out (DVD)

@item RROD
Red Ring Of Death (MS, Xbox)

@item RRP
Registry Registrar Protocol (VeriSign, RFC 2832/3632)

@item RRZE
Regionales RechenZentrum Erlangen (org.)

@item RRZN
Regionales RechenZentrum fuer Niedersachsen (org.)

@item RS
Recommended Standard

@item RS
Reconciliation Sublayer (10GE, OSI)

@item RS
Registry Service (DCE, ebXML, ...)

@item RSA
Random Scheduling Algorithm [protocol]

@item RSA
Reference System Architecture

@item RSA
Reusable Software Assets

@item RSA
Rivest, Shamir and Adleman (cryptography, RSA)

@item RSAC
Recreational Software Advisory Council (org.)

@item RSAP
Remote Service Access Point (SAP)

@item RSAT
Reliability and System Architecture Testing

@item RSAT
Remote Server Administration Tools (AD)

@item RSB
Remote view Service Board (FSC)

@item RSBAC
Rule Set Base Access Control (Linux)

@item RSCN
Registered State Change Notification (FCP)

@item RSCS
Remote Source Control System

@item RSCS
Remote Spooling Communications Subsystem (IBM, VM, NJE)

@item RSCT
Reliable Scalable Cluster Technology (IBM)

@item RSD
Really Simple Discoverability

@item RSDP
Root System Description Pointer (ACPI)

@item RSDT
Root System Description Table (ACPI)

@item RSE
Removable Storage Elements

@item RSE
Research and Systems Engineering

@item RSF
Remote Service Facility (IBM)

@item RSF
Remote Support Facility

@item RSF
ReStart active File (IBM, VM/ESA, CP)

@item RSFD
Retrieve Subsequent File Descriptor (IBM, VM/ESA, CP)

@item RSFDNPR
Retrieve Subsequent File Descriptor Not Previously Retrieved (IBM, VM/ESA, CP)

@item RSFQ
Rapid Single Flux Quantum [logic]

@item RSH
Remote SHell (Unix, BSD, Shell)

@item RSH
Restricted SHell (Unix, Shell)

@item RSI
Repetitive Strain Injury

@item RSIS
Relocateable Screen Interface Specification

@item RSLM
Remote Subscriber Line Module

@item RSM
Remote Switching Module

@item RSMMC
Reduced Size MultiMediaCard (MMC), "RS-MMC"

@item RSN
Real Soon Now (slang)

@item RSN
Robust Security Network (WLAN, cryptography)

@item RSP
Reality Signal Processor (Nintendo)

@item RSPC
Reed Solomon Product Code (SDD, CD), "RS-PC"

@item RSS
Rich / RDF Site Summary (XML, RDF)

@item RSSCP
Remote System Services Control Point (SSCP)

@item RST
Rapid Storage Technology

@item RST
Running Status Table (DVB)

@item RSTS
Resource Sharing Time Sharing (DEC)

@item RSTSE
Resource System Time Sharing/Enhanced (DEC), "RSTS/E"

@item RSU
Remote Software Update (IBDM, OS/2, ...)

@item RSU
Remote Switching Unit

@item RSVP
Resource reSerVation Protocol (IP, RFC 2205)

@item RSX
Realistic Sound eXperience (Intel, audio)

@item RSX11
Resource Sharing eXecutive - 11 (DEC, OS, PDP 11), "RSX-11"

@item RSX3D
Realistic Sound eXperience - 3D (Intel, audio, VRML), "RSX-3D"

@item RT
Register Transfer

@item RT
Remote Terminal

@item RT
Research and Technology, "R&T"

@item RT
Routing Type

@item RTA
Rapid Thermal Annealling (IC, MOSFET)

@item RTA
Real Time Adherence

@item RTA
Real-Time Accelerator

@item RTAM
Remote Teleprocessing Access Method

@item RTB
Read Tape Binary

@item RTBM
Real Time Bit Mapping (BIT)

@item RTC
Real Time Clock

@item RTC
Real-Time Command

@item RTCP
Real Time Control Protocol (RTP)

@item RTCS
Real Time Computer System

@item RTCU
Real Time Control Unit

@item RTD
Real Time Display

@item RTDAT
RealTime Deformation And Tessellation [engine] (3D, Shiny), "RT-DAT"

@item RTDHS
Real Time Data Handling System

@item RTE
Real Time Execution

@item RTE
Real Time Executive (OS, HP, HP 2000)

@item RTE
Remote Terminal Emulation

@item RTE
Run Time Environment

@item RTE6VM
Real Time Executive - 6 / Virtual Memory (OS, HP, RTE, HP 1000), "RTE-6/VM"

@item RTEMS
Real-Time Executive for Multiprocessor Systems (RTOS)

@item RTEX
Real Time EXecutive (OS, Interdata)

@item RTF
Rich Text Format

@item RTFF
Read The Fucking FAQ (slang, Usenet)

@item RTFM
Read The Flaming / Fucking Manual (slang, Usenet, IRC)

@item RTG
Real Time Gambling

@item RTG
Real Time Geometry (manufacturer)

@item RTG
Routing Table Generator

@item RTI
ReTurn from Interrupt

@item RTIN
Request Topology INformation (FCP, SNIA, HBA, API)

@item RTL
Real Time Language

@item RTL
Register Transfer Language (GCC)

@item RTL
Register Transfer Level

@item RTL
Resistor-Transistor Logic

@item RTL
RunTime Library

@item RTLINUX
Real-Time Linux (Linux)

@item RTM
Registered Transfer Module

@item RTM
Release To Manufacture / Market

@item RTM
Remote Test Module

@item RTMOS
Real Time Multiprogramming Operating System (OS, GE)

@item RTMP
Routing Table Maintenance Protocol (AppleTalk)

@item RTMS
Real Time Multiprogramming System (???) (OS)

@item RTOS
Real Time Operating System (OS, Interdata, Prime, ...)

@item RTOS16
Real Time Operating System - 16 (OS, Digico), "RTOS-16"

@item RTOS360
Real Time Operating System /360 (IBM, OS, S/360), "RTOS/360"

@item RTOSUH
Real Time Operating System - Universitaet Hannover (OS), "RTOS-UH"

@item RTP
Real Time Protocol (Internet, RFC 1889/1890, RTCP)

@item RTS
Real Time Strategy [game] (TBS)

@item RTS
Real Time System

@item RTS
Reliable Transfer Service (OSI)

@item RTS
Request To Send (MODEM, RS-232)

@item RTS
Residual Time Stamp

@item RTSE
Reliable Transfer Service Element (OSI)

@item RTSM
RealTime System Manager

@item RTSP
Real Time Streaming Protocol (TV, WWW, UDP, TCP/IP, RDP, Multicast, VoIP, RFC 2326)

@item RTT
Resonant Tunneling Transistor

@item RTT
Round-Trip Time

@item RTTI
Run-Time Type Identification (ANSI)

@item RTTM
Round-Trip Time Measurements (TCP, satellite)

@item RTTS
Real Time Task Scheduler (OS, August Systems)

@item RTTY
Radio Tele TYpe

@item RTU
Real Time Unix (Unix)

@item RTU
Remote Terminal Unit (ESA, Venus-Express)

@item RTUX
Real Time UniX (OS, Emerge Systems)

@item RTV
Real Time Video

@item RTVBR
RealTime Variable Bit Rate (VBR, ATM, BIT), "rt-VBR"

@item RTX
Real Time eXecutive (OS)

@item RTX16
Real Time eXecutive - 16 (OS, Honeywell, ...), "RTX-16"

@item RUA
Remote User Agent

@item RUAC
Remote User Access Centers

@item RUI
Reality User Interface

@item RUM
Real User Monitoring (WWW)

@item RUOW
Remote Unit Of Work (DRDA, IBM), "RUoW"

@item RUP
Rational Unified Process (IBM)

@item RUS
Rechenzentrum der Universitaet Stuttgart (org., Uni Stuttgart, Germany)

@item RUTE
RUTE Users Tutorial and Exposition (Unix), "R.U.T.E."

@item RVC
Ruby VSphere Console (VSAN), "RvC"

@item RVD
Remote Virtual Disk

@item RVPPIP
Rendez-Vous Protocol / Presence Information Protocol (IM), "RVP/PIP"

@item RW
Read/Write (I/O), "R/W"

@item RWCP
Real World Computing Partnership (org., Japan)

@item RWPPI
ReWritable Product Promotion Initiative (org., DVD-R, DVD-RW, DVD)

@item RWS
Remote WinSock (Windows, TCP/IP)

@item RWU
Remote Wake-Up (LAN)

@item RXR
Regular XML RDF (XML, RDF)

@item RZ
RechenZentrum

@item RZ
Return-to-Zero [recording]

@item RZG
RechenZentrum Garching

@item RZM
RootZone Maintainer (DNS)

@end table

