@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item V4L
Video 4 Linux (video, Linux)

@item VA
Virtual Acoustic

@item VA
Vulnerability Assessment (Firewall, TrendMicro)

@item VAAPI
Video Acceleration API (Intel)

@item VAC
Valve Anti Cheat [module/system]

@item VAC
Visual Age C++ (IBM)

@item VACP
View-based Access Control Protocol (SNMP, RFC 2575)

@item VACS
Visual Access Control System (SNI, CCD)

@item VAD
Value Added Driver

@item VAD
Voice Activity Detection (GSM, mobile-systems)

@item VADD
Value Added Disk Driver

@item VADD
VisualAge Developper Domain (IBM)

@item VAFC
VESA Advanced Feature Connector (VESA)

@item VAG
VRML Architecture Group (org., VRML)

@item VAGI
VESA Advanced Graphic Interface (VESA)

@item VAIO
Video Audio Integrated Operation (Sony)

@item VAJ
VisualAge for Java (Java, IBM)

@item VAM
Verband der Anbieter von Mobilfunkdiensten (org.)

@item VAMAS
Versailles project on Advanced Materials And Standards (ISO)

@item VAN
Value Added Network

@item VANS
Value Added Network Services

@item VAP
Value Added Process (Netware, NLM, predecessor)

@item VAPI
Virtual [ISDN] Application Programming Interface (ISDN, CAPI, API)

@item VAPI
Voyetra Applications Program Interface (API)

@item VAR
Value-Added Reseller

@item VAROS
VAriable Refraction Optical System (Canon)

@item VAS
Value Added Services

@item VASCAR
Visual Average Speed Computer And Recorder

@item VAST
Virtual Archive Storage Technology

@item VAT
[UDF] Virtual Allocation Table (UDF, CD-R)

@item VATM
Verband der Anbieter von Telekommunikations- und Mehrwertdiensten Org., telecommunication, Germany

@item VAX
Virtual Address eXtension (DEC, VAX)

@item VAXELN
Virtual Address eXtension ??? (OS)

@item VB
Visual BASIC (MS, BASIC, VB)

@item VBA
Visual BASIC for Applications (MS, BASIC, VB)

@item VBCCE
Visual Basic Control Creation Edition (VB, MS)

@item VBE
VGA standard BIOS Extensions (VESA, VGA, BIOS)

@item VBE
Visual BASIC Editor (MS, VB)

@item VBIDE
Visual BASIC Integrated Development Environment (MS, VB)

@item VBN
Vermittelndes Breitband-Netz

@item VBNS
Very highspeed Backbone Network Service (NSF, ATM), "vBNS"

@item VBO
Vertex Buffer Object (NVSG)

@item VBR
Variable Bit Rate (ATM, CBR, ABR, UBR, QOS, BIT)

@item VBRNRT
Variable Bit Rate - Non Real Time (VBR, ATM, BIT), "VBR-NRT"

@item VBRRT
Variable Bit Rate - Real Time (VBR, ATM, BIT), "VBR-RT"

@item VBS
Visual Basic Script (MS, BASIC, VB)

@item VBX
Visual Basic eXtensions (MS)

@item VC
Virtual Channel / Circuit (ATM)

@item VC
Virtual Console

@item VC
Visual c/c++ compiler (MS)

@item VCA
Voltage Controlled Amplifier (audio)

@item VCC
Virtual Channel Connection (ATM)

@item VCD
Video Compact Disk (CD)

@item VCEG
Video Coding Experts Group (org., ITU-T)

@item VCF
Voltage Controlled Filters

@item VCI
Video Cursor Interface (VESA)

@item VCI
Virtual Channel Identifier (ATM)

@item VCI
Virtual Connection Identifier (ATM)

@item VCL
Video Coding Layer (AVC)

@item VCL
Virtual Channel Link (UNI, ATM)

@item VCL
Visual Class Library (StarOffice)

@item VCL
Visual Component Library (Borland, Delphi)

@item VCM
Windows Conflict Manager (MS, Windows)

@item VCO
Voltage Controlled Oscillator

@item VCOS
Visible Caching Operating System (DSP)

@item VCP
Vector Control Processor

@item VCPI
Virtual Control Program Interface (DOS, Intel)

@item VCQ
Vibrant Colour Quality (Matrox)

@item VCRC
Variant Cyclic Redundancy Check (Infiniband), "V-CRC"

@item VCS
Virtual Circuit System

@item VCSA
, "vCSA"

@item VCSDRAM
Virtual Channel - Synchronous Dynamic Random Access Memory (RAM, DRAM, IC, NEC), "VC-SDRAM"

@item VCSEL
Vertical-Cavity Surface Emitting LASER

@item VCVS
Virtual Concurrent Version System (CVS), "vCVS"

@item VD
Virtual Data (grid)

@item VDAFS
Verband Deutscher Automobilhersteller FlaechenSchnittstelle (DIN, CIM)

@item VDASEDAS
Verband Deutscher Automobilhersteller / Standardisiertes Einheitliches DatenAustauschSystem (EDI), "VDA/SEDAS"

@item VDD
Virtual Display Driver

@item VDDM
Vista Display Driver Model (MS, Windows, Vista)

@item VDE
Verband Deutscher Elektrotechniker [e.v.] (org.)

@item VDGA
Virtual Dedicated Graphics Acceleration (VMware, vSGA), "vDGA"

@item VDI
Verein Deutscher Ingenieure (org.)

@item VDI
Video Device Interface (Intel)

@item VDI
Virtual Desktop Infrastructure (Sun)

@item VDI
Virtual Device Interface

@item VDIF
VESA Display Information File (VESA)

@item VDM
Virtual DOS Machine (OS/2, Windows NT, DOS)

@item VDMA
Virtual Direct Memory Access (DMA)

@item VDMAD
Virtual Direct Memory Access Device (VDMA, DMA)

@item VDOP
Vertical Dilution Of Precision (GPS)

@item VDPAU
Video Decode and Presentation API for Unix (Nvidia, API)

@item VDS
Virtual DMA Services (DMA)

@item VDSL
Very high data / bit rate Digital Subscriber Line (DSL, BIT)

@item VDSO
Virtual Dynamically linked Shared Objects

@item VDT
Video Display Terminal

@item VDU
Visual Display Unit

@item VDV
Vorbestellte DauerwaehlVerbindung (DTAG)

@item VE
Virtual Environment (VR)

@item VEBSN
Virtual European Seismic Network

@item VEC
Virtual Embedded Circuitry (IC)

@item VEG
Very Evil Grin (slang, Usenet, IRC)

@item VEIL
Video Encoded Invisible Light Technology (VEIL)

@item VEP
Visual Editor Project (GUI, Java, Eclipse)

@item VERA
Just playing around, huh?

@item VERNET
Virginia Educational Research NETwork (network, USA), "VERnet"

@item VERONICA
Very Easy Rodent-Orientated Netwide Index of Computerized Archives (Internet)

@item VERP
Variable Envelope Return Path (SMTP)

@item VES
Virtual Execution System (MS, CLR, .NET)

@item VESA
Video Electronics Standards Association (org.)

@item VEST
VAX Environment Software Translator (VAX, DEC)

@item VF
Vacuum Flourescent [technology]

@item VFAT
Virtual File Allocation Table (MS, Windows 95)

@item VFC
V. Fast Class (MODEM), "V.FC"

@item VFD
Vacuum Fluorescent Display

@item VFEA
VMEbus Futurebus+ Extended Architecture

@item VFIO
Virtual Function Input-Output (Linux, IO)

@item VFIR
Very Fast IRDA (IRDA)

@item VFS
Virtual File System [layer] (Unix, Linux, OSF/1)

@item VFS
Virtual Filesystem Switch (FreeBSD)

@item VFW
Video fuer Windows (MS), "VfW"

@item VG
Volume Group (LVM)

@item VGA
Video Graphics Array (IBM)

@item VGB
Virtual GameBoy

@item VGDA
Volume Group Descriptor Area (AIX, LVM, IBM)

@item VGF
100VoiceGrade anylan Forum (manufacturer)

@item VGI
Virtual Graphics Interface

@item VGPU
Virtual Graphics Processing Unit (GPU), "vGPU"

@item VHDCI
Very High Density Cable Interconnect (SCSI)

@item VHDL
VHSIC Hardware Description Language (ASIC)

@item VHF
Very High Frequency

@item VHLL
Very High Level Language

@item VHRCD
Very High Resolution Color Display

@item VHSIC
Very High Speed Integrated Circuit

@item VI
Virtual Interface (Compaq, Intel, MS, Infiniband)

@item VI
VIsual editor (Unix)

@item VIA
VAX Information Architecture (VAX, DEC)

@item VIA
Virtual Interface Architecture

@item VIAD
VESA Image Area Definition (VESA)

@item VIC
V.35 Interface Cable (cable)

@item VIC
Vendor Independent Calendaring (VIM)

@item VIC
Video Interface Controller (video, C64)

@item VICE
VersatIle Commodore Emulator

@item VICI
Visual Interface ConsortIum (org.)

@item VID
Voltage IDentification (CPU)

@item VIDIX
VIDeo interface for *niX (Unix, video)

@item VIDL
VIrus Description Language, "ViDL"

@item VIF
Virtual Interrupt Flag (Intel, CPU)

@item VIFA
Victoria Free-Net Association (org., USA)

@item VILE
VI Like EMACS (Unix, VI, EMACS)

@item VIM
Vendor Independent Messaging (Lotus, Borland, IBM, Novell, API)

@item VIM
VI Improved (VI, Unix)

@item VIMF
Vierer [kabel] In MetallFolie (VDE, SQ), "ViMF"

@item VINCE
Vendor Independent Network Control Entity

@item VINES
VIrtual NEtwork Software (Banyan, VINES, NOS)

@item VIO
Virtual Input/Output

@item VIOLA
Vertically Intergrated Optical Testbed for Large Applications (DFN)

@item VIOP
Variable Input/Output Port (I/O, Qualstar)

@item VIP
Virtual Internet Protocol [address] (IP)

@item VIP
Visual Information Projection [terminal] (Bull)

@item VIP
VLB - ISA - PCI [board] (VLB, ISA, PCI)

@item VIPNET
Voice Interactive Paging Network (network, MAN), "VIP-Net"

@item VIQR
VIetnamese Quoted-Readable [specification] (VISCII, RFC 1456)

@item VIR
Visual Information Retrieval (DB, Informix)

@item VIROS
VIRtual memory Operating System (DEC, OS)

@item VIRTUE
Virtual Team User Environment (VR, TUB)

@item VIS
Verlaessliche InformationsSysteme (GI)

@item VIS
Virtual Instruction Set (Sun, CPU)

@item VIS
Visual Interactive Simulation

@item VISCII
VIetnamese Standard Code for Information Interchange

@item VISYON
Variables Intelligentes Synchrones Optisches Netz (SNI, SDH)

@item VITAL
VHDL Initiative Toward ASIC Libraries (ASIC, VHDL)

@item VITC
Vertical Interval Time Code (video)

@item VK
VideoKonferenz

@item VKI
Variable Keyframe Interface (DivX, video)

@item VKI
Verteilte Kuenstliche Intelligenz (KI, DAI)

@item VL
Virtual Lane (Infiniband)

@item VLA
Volume Licence Agreement (Novell, Apple)

@item VLAN
Virtual Local Area Network (LAN, IEEE 802.1q/80210), vowlan

@item VLB
VESA Local Bus (VESA)

@item VLC
Variable Length Coding (AVC)

@item VLC
Video LAN Client (LAN, video, Mac, Dbox)

@item VLD
Variable Length Decoder (MPEG)

@item VLDB
Very Large DataBase (DB)

@item VLF
Very-Low-Frequency Band

@item VLF
Virtual Lookaside Facility (IBM)

@item VLIW
Very Long Instruction Word (CPU, IC)

@item VLK
Volume License product Key (MS)

@item VLM
Virtual Loadable Module (Novell, Netware)

@item VLM
Volume Logical Module (IBM, OS/2)

@item VLR
Visitor Location Register (LR, GSM, GPRS, mobile-systems)

@item VLSI
Very Large Scale Integration

@item VLSM
Variable Length Subnet Mask (Internet)

@item VM
Virtual Machine (IBM, OS, IBM 370, ESA, IBM 390)

@item VM
Virtual Memory (OSF)

@item VMA
Virtual Memory Address

@item VMA
VSphere Management Assistant (VSAN), "vMA"

@item VMB
Virtual Machine Boot (IBM, OS/2)

@item VMBR
Virtual Machine Based Rootkit

@item VMC
VESA Media Channel (VESA)

@item VMC
Virtual Machine Console (VMware)

@item VMCF
Virtual Machine Communications Facility (IBM, VM)

@item VMCMS
Virtual Machine / Conversational Monitoring System (IBM, VM), "VM/CMS" 

@item VMD
Virtual Manufacturing Device (MMS)

@item VME
Virtual Machine Environment (IBM, VM)

@item VME
Virtual Mobile Engine (Sony, PSP)

@item VMESA
Virtual Machine / Enterprise Systems Architecture (IBM, VM, ESA, CMS), "VM/ESA"

@item VML
Vector Markup Language (XML, MS, Macromedia, ..., PGML, SVG)

@item VMM
Virtual Machine / Memory Manager (IBM, VM)

@item VMM
Virtual Machine Monitor (VM)

@item VMOS
Vertical Metal Oxide Semiconductor (IC), "V-MOS"

@item VMP
Virtual MultiPorting (POWER, CPU)

@item VMS
Virtual Memory [operating] System (DEC, OS)

@item VMS
Voice Mail System (GMS)

@item VMS
Voice Management System

@item VMSP
Virtual Machine / System Product (IBM, VM), "VM/SP" 

@item VMT
Virtual Method Table

@item VMTP
Versatile Message Transaction Protocol (RFC 1045)

@item VMTSS
Virtual Machine Time-Sharing System (IBM)

@item VMU
Visual Memory Unit (Sega, Dreamcast)

@item VNA
Virtual Network Architecture (ATM)

@item VNA
Virtual Network Architecture (Ungermann-Bass)

@item VNC
Virtual Network Client

@item VNC
Virtual Network Computer

@item VNC
Virtual Network Computing (AT&T, Linux)

@item VNCA
VTAM Node Control Application (IBM, VTAM)

@item VNF
Virtual Network Feature

@item VNL
Via Net Loss plan

@item VNLF
Via Net Loss Factor

@item VNSM
VINES Network and Systems Management (Banyan, VINES)

@item VO
Virtual Organization (grid)

@item VOB
Video OBject [format] (DVD, video)

@item VOBS
Video OBject Set (VOB, DVD, video)

@item VOBU
Video OBject Units (ILVU, DVD, video)

@item VOD
Video On Demand

@item VOFR
Voice Over Frame Relay

@item VOI
Verband Optischer Informationssysteme (org.)

@item VOICE
Virtual OS/2 International Consumer Education (OS/2, user group, org.)

@item VOIP
Voice Over IP (IP, Internet, CTI), "VoIP"

@item VOL
Voice-Over-IP (IP, Internet)

@item VON
Voice On the Net [coalition] (USA, Internet)

@item VOODOO
Versions Of Outdated Documents Organized Orthogonally (Mac)

@item VOP
Voice Over Packet [processor] (Improv, IC), "VoP"

@item VORTEX
Varian Omnitasking Real Time EXecutive (???) (OS, Varian)

@item VOS
Virtual machine Operating System (OS, MTS)

@item VOS
Virtual Operating System (OS, Stratus)

@item VOWIP
Voice Over Wireless Internet Protocol (LAN, IP), "VoWIP"

@item VOWLAN
Voice Over WLAN (WLAN, LAN, IEEE 80211), "VoWLAN"

@item VP
Virtual Path (ATM)

@item VP
Virtual Processor (Amiga, AMIGADE)

@item VPA
VAX Performance Advisor (DEC, VMS, VAX)

@item VPC
Virtual Path Connection (ATM, VP)

@item VPC
Virtual Private Cloud

@item VPCC
Virtual PC Center (NEC, PC, TC)

@item VPCD
Videotex Presentation Control Element (BTX, VPDE)

@item VPCI
Virtual Path Connection Identifier (VP, ATM)

@item VPD
Virtual Product Development (CAD)

@item VPD
Vital Product Data

@item VPDE
Videotex Presentation Data Element (BTX)

@item VPDN
Virtual Private Data Network

@item VPE
Video Port Extensions (video)

@item VPFN
Virtual Page Frame Number (Linux, PFN)

@item VPI
Virtual Path Identifier (ATM, VP)

@item VPI
Virtual Private Internet (TradeWave)

@item VPICD
Virtual Programmable Interrupt Controller Device (PIC), "VpicD"

@item VPL
Virtual Path Link (UNI, ATM)

@item VPL
Visual Programming Languages

@item VPL
Voxel Public License

@item VPMI
Virtual Protected Mode Interface

@item VPN
Virtual Private Network

@item VPP
Value Purchase Plan (Adobe)

@item VPRT
Verband Privater Rundfunk und Telekommunikation Org., Germany

@item VPSD
VIA Platform Solutions Devision

@item VPSD
VIA Platform Solutions Division

@item VPT
Virtual Path Terminator (UNI, ATM)

@item VPU
Video Processing Unit

@item VPU
Visual Processing Unit (IC, SIMD, 3Dlabs)

@item VPUG
Ventura Publishing User Group (org., DTP, user group)

@item VPUML
Visual Paradigm for UML (UML, Eclipse), "VP-UML"

@item VQC
Vibrant Color Quality (Matrox)

@item VQEG
Video Quality Experts Group (video)

@item VQM
Visual Quality Metric (video)

@item VR
Virtual Reality

@item VR
Virtual Route (SNA, PSDN)

@item VR
Virtuelle Realitaet

@item VRAI
Virtual Reality Annual International [symposium] (IEEE, conference)

@item VRAM
VEIL Encoding Rights Assertion Mark (VEIL), "V-RAM"

@item VRAM
Volatile Random Access Memory (RAM, IC)

@item VRC
Vertical Redundancy Check

@item VRD
Virtual Retinal Display (VR)

@item VRG
Vertical Replacement Gate (IC, MOSFET)

@item VRI
[Nederlandse] Vereniging van Registerinformatic (org. Netherlands)

@item VRM
Vector Room Model

@item VRM
Virtual Resource Manager

@item VRM
Voltage Regulation Module (IC)

@item VRM
Voltage Regulator Modul (Iwill)

@item VRML
Virtual Reality Modeling Language (VR, ISO/IEC 14772, W3C)

@item VROOMM
Virtual Realtime Object Oriented Memory Manager (OOP)

@item VRRP
Virtual Router Redundancy Protocol (RFC 2338/3768)

@item VRS
Voice Response System

@item VRT
Vulnerability Research Team (Sourcefire)

@item VRTX
Versatile Real Time eXecutive (OS)

@item VS
VINES Security (Banyan, VINES)

@item VS1
Virtual System - 1 (IBM, OS, OS/VS-1), "VS-1"

@item VSA
Virtual Server Architecture

@item VSA
Visual Studio for Applications (MS)

@item VSA
Voodoo Scalable Architecture (3dfx)

@item VSAM
Virtual Sequential Access Method (SAM)

@item VSAM
Virtual Storage Access Method

@item VSAN
Virtual Storage Area Network (SAN, VMware)

@item VSAT
Very Small Aperture Terminal

@item VSC
VMware [GSX] Server Console (VMware)

@item VSCE
Videotex Service Control Element (BTX, VPDE)

@item VSD
Vendor Specific Driver

@item VSE
Virtual Storage Extended (IBM)

@item VSEA
Visual Studio Enterprise Architect [edition] (MS, XML)

@item VSED
Visual Studio Enterprise Developer [edition] (MS, XML)

@item VSEESA
Virtual Storage Extended/Enterprise Systems Architecture, "VSE/ESA" 

@item VSESP
Virtual Storage Extended/System Product (IBM), "VSE/SP"

@item VSGA
Virtual Shared Graphics Acceleration (VMware, vDGA), "vSGA"

@item VSI
Verband der SoftwareIndustrie deutschlands [e.v.] (org.)

@item VSI
Virtual Socket Interface alliance (org., ASIC, RL)

@item VSM
VideoSwitch Multiplexer

@item VSM
Virtual Storage Management

@item VSN
Volume Serial Number (BS2000)

@item VSO
Variable Speed Operation (VXA, Streamer)

@item VSP
Virtual Single Processor

@item VSR
Voice Storage and Retrieval

@item VSS
Visual Source Safe (VB, MS)

@item VSS
Voice Storage System

@item VSS
Volume Shadow copy Service (MS, Windows)

@item VST
VermittlungsSTelle (DTAG), "VSt"

@item VST
Virtual Studio Technology (Steinberg, audio)

@item VSTF
Volunteer Spam Task Force (Wikia, CVN)

@item VSTI
Virtual Studio Technology Instrument (VST), "VSTi"

@item VSTO
Visual Studio TOols for the microsoft office system (MS)

@item VSTS
Visual Studio Team System (MS)

@item VSU
Vertex/Scalability Unit (3Dlabs)

@item VSU
Video Service Unit

@item VT
Vanderpool Technology (Intel, Pentium, CPU)

@item VT
Virtual Terminal (DEC)

@item VT100
Virtual Terminal 100 (DEC), "VT-100"

@item VTAM
Virtual Telecommunications Access Method (IBM, SNA)

@item VTAME
Virtual Telecommunications Access Method Entry (VTAM)

@item VTD
Virtual Tape Device

@item VTI
Virtual Terminal Interface

@item VTK
Visualization ToolKit

@item VTL
Velocity Template Language (Apache, Java)

@item VTL
Virtual Tape Library

@item VTM
Verband der Telekommunikationsnetz- und Mehrwertdiensteanbieter (org.)

@item VTOC
Volume Table of Contents

@item VTOS
Virtual Technology Operating System (OS, Tandy, TRS-80)

@item VTP
Virtual Terminal Protocol

@item VTS
Video Teleconferencing System

@item VTS
Virtual Terminal Service (OSI)

@item VTSAPI
Voucher Trading System Application Programming Interface (API, RFC 4154), "VTS-API"

@item VU
Virtual User

@item VUD
Verband der Unterhaltungssoftwareindustrie Deutschlands (org.)

@item VUDA
VESA Unified Graphics Architecture (VESA)

@item VUE
Visual User Environment (HP)

@item VUI
Virtual User Interface (AMS, UI)

@item VUMA
VESA Unified Memory Architecture (VESA)

@item VUMASBE
VESA Unified Memory Architecture - System BIOS Extension (VESA), "VUMA-SBE"

@item VUP
VAX Units of Performance (VAX, DEC), "VUPs" 

@item VUP
Version UPgrade (MS)

@item VV
Virtuelle Verbindung

@item VVIDD
VESA Video Interface for Digital Displays (VESA, LCD)

@end table

