@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item S360
System /360 (IBM), "S/360"

@item S370
System /370 (IBM), "S/370"

@item S5
Simple Standards-based Slide Show System (XHTML, CSS, JavaScript)

@item SA
Security Associations (IPSec)

@item SA
Software Assurance (MS)

@item SA
Source [MAC] Address (SNA, Token Ring, ATM, FDDI, ...)

@item SA
Source Active (PIM, MSDP, Multicast)

@item SA
Spare Area (CD-MRW, DA)

@item SA
Storage Array

@item SA
Structured Analysis / Strukturierte Analyse (CASE)

@item SA
System Administrator

@item SA
Systems Analyst

@item SAA
Standard Application Architecture (IBM)

@item SAA
Standards Association of Australia (org., Australia)

@item SAAJ
SOAP with Attachments API for Java (SOAP, Java, API)

@item SAAL
Signalling ATM Adaptation Layer (ATM)

@item SAAS
Software As A Service, "SaaS"

@item SABB
Storage Array Building Block

@item SABM
Set Asynchronous Balanced Mode (LABM, LAPB, HDLC)

@item SABME
Set Asynchronous Balanced Mode Extension (SABM)

@item SABRE
Semi-Automatic Business Related Environment (OS, IBM 7090)

@item SAC
Service / Special Area Code

@item SAC
Single Attachment Concentrator (FDDI)

@item SAC
Spatial Audio Coding

@item SAC
Strict Avalanche Criterion (cryptography)

@item SACCH
Slow Associated Control CHannel (GSM, DCCH, mobile-systems)

@item SACD
Super Audio Compact Disk (CD, audio)

@item SACRED
Securely Available CREDential (RFC 3760)

@item SACT
SPARC Application Conformance Test (SI, SPARC)

@item SAD
Security Association Database (SA, IPSec)

@item SAD
Serial Analog Delay

@item SADF
Semi-Automatic Document Feeder

@item SADT
Structured Analysis and Design Techniques (SA)

@item SAF
Service Access Facilities (Unix)

@item SAFE
Security And Freedom through Encryption [law] (USA, cryptography)

@item SAFTE
SCSI Accessed Fault-Tolerant Enclose (SCSI, RAID, Intel, NStor), "SAF-TE"

@item SAG
SQL Access Group (org., manufacturer, DB)

@item SAGA
Standards und Architekturen fuer eGovernment Anwendungen (IDA)

@item SAGE
Semi-Automatic Ground Environment system (OS, IBM AN/FSQ7, mil.)

@item SAGE
Software Aided Group Environment (GSS, NUS)

@item SAHF
Store AH Into Flags (assembler)

@item SAIL
Stanford Artificial Intelligence Laboratory [language] (USA, AI)

@item SAIT
Samsung Advanced Institute of Technology (org., Samsung)

@item SAIT
Super Advanced Intelligent Tape (Sony, AIT, Streamer), "S-AIT"

@item SAL
Security Access List

@item SAL
Semware Applications Language (Semware)

@item SAL
SQL windows Application Language (SQL, Gupta)

@item SAL
Symbolic Assembly Language (assembler)

@item SAL
System Abstraction Layer

@item SALT
Script Application Language for Telix

@item SALT
Speech Application Language Tag (MS)

@item SALT
Suse Advanced Linux Technology (Suse, Linux)

@item SALU
Structured Assembly Language Utilities

@item SAM
SCSI-3 Architecture Model

@item SAM
Security Access Manager (MS, Windows, XP)

@item SAM
Security Accounts Manager

@item SAM
Sequential Access Method / Mode (SAM, DAM)

@item SAM
Sort And Merge

@item SAM
Standard Application Model (XTM)

@item SAM
Storage Application Model (Seagate)

@item SAM
Symantec Anti-virus for Macintosh (Apple)

@item SAM
System Activity Monitor

@item SAMATE
Software Assurance Metrics And Tool Evaluation (NIST)

@item SAMI
Synchronized Accessible Media Interchange (MS)

@item SAML
Security Assertion Markup Language (OASIS, cryptography)

@item SAN
Schulen ans Netz [e.v.] (org.)

@item SAN
Storage Area Network

@item SANDRA
System ANalyzer Diagnostic and Reporting Assistant

@item SANE
Scanner Access Now Easy (OSS)

@item SANE
Standard Apple Numeric Environment (Apple)

@item SANET
Slowak Academic NETwork (org., Network)

@item SAO
Server Activated Object

@item SAO
Session At Once (CD)

@item SAO
Source Address Omitted [flag] (CATNIP)

@item SAP
Service Access Point (OSI)

@item SAP
Service Advertising Protocol (Novell, Netware, IPX)

@item SAP
Session Announcement Protocol (Internet, RFC 2974)

@item SAP
SIM Access Protocol (mobile-systems, Bluethooth)

@item SAP
Symbolic Assembler Program (IBM, IBM 704)

@item SAP
SystemAnalyse und Programmentwicklung (manufacturer, predecessor)

@item SAP
Systems, Applications and Products [in data processing] [ag] (manufacturer)

@item SAQ
Service, Access, Quality (ISP, UK)

@item SAR
Segmentation And Reassembly

@item SAR
Store Address Register (IC)

@item SARAH
Standard Automated Remote-to-AUTODIN Host (AUTODIN, mil.)

@item SARPDU
Segmentation And Reassembly Protocol Data Unit (ATM, PDU), "SAR PDU"

@item SART
Structured Analysis / Real Time (SA, CASE), "SA/RT"

@item SARTS
Switched Access Remote Test System

@item SAS
Session Active Screen (IBM)

@item SAS
Simulation Automation System

@item SAS
Single Attachment Station (FDDI)

@item SAS
Statistical Analysis System

@item SASD
Sequential Access Storage Device

@item SASE
Specific Application Service Element (ISO, OSI, CASE)

@item SASI
Shugart Associates System Interface

@item SASL
Simple Authentication and Security Layer

@item SAST
South Australia Standard Time [+0930] (TZ)

@item SAT
SIM Application Toolkit (SIM, GSM)

@item SAT
Standard AUTODIN Terminal (AUTODIN, mil.)

@item SAT
Summed Area Table (3D, MIP)

@item SATA
Serial Advanced Technology Attachment (HDD, ATA, SATA)

@item SATAN
Security Administrator Tool for Analyzing Networks (Internet)

@item SATCOM
SATellite COMmunications

@item SATF
Shared Access Transport Facility

@item SAU
Secure Access Unit

@item SAX
Simple API for XML (API, XML)

@item SAX
SUSE Advanced X [configuration tool] (SUSE, Linux)

@item SB
Sound Blaster [audio card] (audio, Creative)

@item SB
System Builder [software] (MS)

@item SBA
SideBand Address [port / bus] (AGP)

@item SBA
Standards-Based Architectures

@item SBA
Synchronous Bandwidth Allocation (SMT, FDDI)

@item SBA
System For Business Automation

@item SBC
SCSI Block Commands (SAM)

@item SBC
Single Board Computer

@item SBC
Small Business Computer

@item SBC
Smart Bitrate Control (DivX, video, BIT)

@item SBCCS
Single Byte Command Code Set [protocol]

@item SBCL
Steel Bank Common LISP (LISP)

@item SBCS
Single Byte Character Set (ASCII, DBCS)

@item SBE
System Builder Edition (MS, Windows)

@item SBF
Sequential Block Filemanager (OS-9)

@item SBF
Simple Boot Flag (Linux, POST)

@item SBH
Secure Backbone Hub (Accton)

@item SBI
Storage Bus Interconnect

@item SBI
Synchronous Bus Interface

@item SBIS
Sustaining Base Information System

@item SBL
Super BASIC Language (BASIC)

@item SBLC
Sustaining Base Level Computer

@item SBMS
Southwestern Bell Mobile Service

@item SBOD
Switched Bunch Of Disks (Xyratex, FC)

@item SBP
SCSI-3 serial Bus Protocol (SAM)

@item SBR
Spectral Bandwidth Replication (MP3, AAC, EAC)

@item SBS
Small Business Server (MS)

@item SBUS
Sun [i/o interface] BUS (Sun, SPARC), "SBus"

@item SC
SubCommittee (ISO, TC, IEC, ...)

@item SCA
Scalable Cooperative Architecture

@item SCA
Software Corporation of America (manufacturer, USA)

@item SCA
Synchronous Clock Adjustment

@item SCADA
Supervisory Control And Data Acquisition

@item SCAF
Service Control Agent Function (IN)

@item SCAI
Scandinavian Conference on Artificial Intelligence (conference, FAIS, AI)

@item SCAM
SCSI Configured AutoMatically (SCSI)

@item SCAMC
Symposium on Computer Applications in Medical Care (Konferenz)

@item SCAN
Switched-Circuit Automatic Network

@item SCAP
Security Content Automation Protocol (CVE, NIST)

@item SCART
Syndicat des Constructeurs d' Appareils Radiorecepteurs et Televiseurs (org., video)

@item SCB
Shell Control Box (Balabit)

@item SCB
Subsystem Control Block (OS/2, IBM)

@item SCC
SCSI Controller Commands (SAM)

@item SCC
Serial Communication Controller (FCC, MCC)

@item SCC
Serial Controller-Chip (IC)

@item SCC
Softarc Certified Consulter (SoftArc)

@item SCC
Specialized Common Carrier

@item SCC
Standards Council of Canada (org., Canada)

@item SCC
Storage Connecting Circuit

@item SCC
System Configuration Card (Sun)

@item SCCP
Signaling Connection Control Part (MSC, GSM, mobile-systems)

@item SCCP
Skinny Client Control Protocol (Cisco, VoIP, TCP)

@item SCCS
Source Code Control System (Unix, AT&T, CM)

@item SCCS
Specialized Common Carrier Service

@item SCCS
Switching Control Center System

@item SCD
SPARC Compliance Definition (SI, SPARC)

@item SCDE
Significant CALS Data Elements

@item SCDJWS
Sun Certified Developer for Java Web Services (Sun, Java)

@item SCDMA
Synchronous Code Division Multiple Access (CDMA, mobile-systems)

@item SCDMS
Society for Clinical Data Management Systems (org., USA)

@item SCE
Sony Computer Entertainment (manufacturer, Sony)

@item SCE
Structure Chart Editor

@item SCEA
Sony Computer Entertainment America (Sony, manufacturer)

@item SCEF
Service Creation Environment Function (IN)

@item SCEIO
Societe Canadienne pour l'Etude de l'Intelligence par Ordinateur (org., Canada, AI)

@item SCF
Selective Call-Forwarding

@item SCF
Sequential Character Filemanager (OS-9)

@item SCF
Service Control Function (IN)

@item SCG
Security Classification Guide

@item SCH
Synchronization CHannel (GSM, mobile-systems)

@item SCHWAFEL
Self Constructing Hyper Wavelet Algorithms For Extrapolating Linguistics

@item SCI
Scalable Coherent Interface (ANSI)

@item SCID
Service Channel IDentifier

@item SCIT
Semi-Conductor and Interconnect Technologies

@item SCL
System Control Language

@item SCLT
Suse Certified Linux Trainer (SuSE, Linux)

@item SCM
Segment Control Module

@item SCM
Service Circuit Modul Mil., Germany

@item SCM
Service Configuration Manager (TR-069, ISP)

@item SCM
Service Control Manager (Windows NT)

@item SCM
Small Core Memory

@item SCM
Software Configuration Management

@item SCM
Supply Chain Management

@item SCMAD
Sun Certified Mobile Application Developer (Sun, Java, J2ME, JTWI)

@item SCMP
Stream Control Message Protocol (ST2)

@item SCMS
[scrambling] (DAT)

@item SCMS
Serial Copy Management System

@item SCN
Specifications Change Notice

@item SCNR
Sorry, Could Not Resist (slang, Usenet)

@item SCO
Santa Cruz Operation (manufacturer, Unix)

@item SCO
Synchronous ConnectionLess (HCI, Bluetooth)

@item SCOOPS
SCheme Object Oriented Programming System (OOP)

@item SCOPE
SCalable Object Processing Environment (Creamware)

@item SCOPE
Simple COmmunications Programming Environment (telecommunication)

@item SCOPE
Supervisory Control Of Program Execution (OS, CDC 6000)

@item SCP
Secondary Communications Processors

@item SCP
Secure CoPy (SSH)

@item SCP
Service Control Point (OSI)

@item SCP
Standard Configuration Profile (MODEM)

@item SCP
System Control Program (OS)

@item SCPC
Single Channel Per Carrier

@item SCPDOS
Seattle Computer Products Dis Operating System (OS, DOS, MS-DOS, predecessor), "SCP-DOS"

@item SCPM
SUSE Configuration Profile Management (Linux, SUSE)

@item SCR
Selective Call Rejection

@item SCR
Sustainable Cell Rate (UNI, ATM, VBR)

@item SCRI
Supercomputer Computations Research Institute (org., USA, HPC)

@item SCS
[systimax] Structured Cabling System (AT&T)

@item SCS
Silicon Controlled Switch

@item SCS
Singapore Computer Society (org., Singapur)

@item SCS
Small Computer System

@item SCS
SNA Character String (IBM)

@item SCS
Sun Control Station (Sun)

@item SCS
Switch Control Software (ForeRunner, ATM)

@item SCSA
Signal Computing System Architecture

@item SCSA
Sun Common SCSI Architecture (Sun)

@item SCSI
Small Computer Systems Interface (SCSI)

@item SCSL
Sun Community Source License (Sun)

@item SCST
SCSI Target framework for linux (SCSI, Linux)

@item SCSU
Standard Compression Scheme for Unicode (Unicode)

@item SCT
Subroutine Call Table

@item SCTE
Society of Cable Telecommunications Engineers (org.)

@item SCTP
Stream Control Transmission Protocol (IETF)

@item SCTS
Secondary Clear to Send

@item SCU
Selector Control Unit

@item SCU
Snoop Control Unit (ARM, MPCore)

@item SCU
System Control Unit (CPU, POWER)

@item SCUMM
Script Creation Utility for Maniac Mansion

@item SCVP
Simple Certificate Validation Protocol (cryptography)

@item SCWCD
Sun Certified Web Component Developer (Sun)

@item SCX
Specialized Communications eXchange

@item SD
Secure Digital [card] (CPRM)

@item SD
Self-Describing [file] (HP)

@item SD
Starting Delimiter (FDDI, Token Ring)

@item SD
Structured Design (CASE)

@item SD
Super Density [disk] (CD, Toshiba, Time Warner)

@item SD
System Display (Airbus, A380)

@item SDA
Screen Design Aid (IBM, ADT)

@item SDA
Shared Data Architecture

@item SDA
Software Design Automation

@item SDA
Source Data Automation

@item SDA
Static Data Authentication (EMV, cryptography)

@item SDA
Swappable Data Area (DOS)

@item SDA
System Display Architecture

@item SDAO
Simulated Data Access Object (DAO, J2EE, Java, DB)

@item SDAP
Service Discovery Application Profile (Bluetooth)

@item SDAV
Systems Design Automation Vendor

@item SDC
Sample Data Collection

@item SDC
Secure Digital Card (PDA)

@item SDC
Software Development Control [system] (CMU, CM)

@item SDC
Software Distribution Center

@item SDCB
Shared File Control Block (Apollo, DOMAIN)

@item SDCCH
Stand-alone Dedicated Control CHannel (GSM, DCCH, mobile-systems)

@item SDCD
Secondary Data Carrier Detect

@item SDD
Software Design Document

@item SDD
Super Density Disk (Toshiba, Time Warner, ...)

@item SDDAS
Southwest research Data Display and Analysis System

@item SDDI
Shielded Distributed Data Interface (FDDI, STP)

@item SDE
Service Data Element (grid)

@item SDE
Software Development Engineer

@item SDE
Software Development Environment

@item SDF
Screen Definition Facility

@item SDF
Standard Data Format

@item SDF
System Dialog Facility (BS2000)

@item SDFI
Secure Digital Forensic Imaging

@item SDH
Synchronous Digital Hierarchy (FDDI, ATM, SDH)

@item SDHC
Secure Digital High Capacity (SD)

@item SDI
Single Document Interface

@item SDI
Slovensko Drustvo Informatika (org., Slowakien)

@item SDI
Source Data Information

@item SDI
Standard Data Interface

@item SDI
Standard Disk Interconnect

@item SDI
Standard Disk Interface

@item SDI
Standard Drive Interface

@item SDI
Storage Device Interconnect

@item SDI
Storage Device Interface (Novell, Netware, SMS)

@item SDI
Super Data Interchange

@item SDIF
SGML Document Interchange Format (SGML, ISO, IS 9069)

@item SDIF
System Independent Data Format (Novell, SMS)

@item SDILINE
Selective Dissemination of Information onLINE

@item SDIMM
Single [RAS] Dual Inline Memory Module (DIMM, RAS), "S-DIMM"

@item SDIO
Secure Digital Input Output (SD)

@item SDIS
Switched Digital Integrated Service

@item SDK
Software Development Kit (MS, IBM)

@item SDL
Security Development Lifecycle (MS)

@item SDL
Simple Directmedia Layer

@item SDL
Specification and Description Language (CCITT)

@item SDL
System Design Language

@item SDLC
Synchronous Data Link Control (IBM, SNA)

@item SDLGR
Specification and Description Language / Graphical Representation, "SDL/GR" 

@item SDLLC
Synchronous Data Link Control Conversion (SNA, IBM)

@item SDLP
Standard Device Level Protocol

@item SDLT
Super Digital Line Tape (DLT, Streamer)

@item SDM
Short Data Message

@item SDM
Spatial Data Management

@item SDM
Sun Download Manager (Sun)

@item SDM
System Development Multitasking [benchmark] (DB, SPEC)

@item SDMA
Space Division Multiple Access

@item SDMA
Storage Device Migration Aid

@item SDMI
Secure Digital Music Initiative (org.)

@item SDMS
SCSI Device Management System (BIOS)

@item SDN
Software Defined Network

@item SDN
Software Distribution Net (FidoNet)

@item SDNS
Secure Data Network Service / System (USA, mil.)

@item SDOC
Selective Dynamic Overload Controls

@item SDOS
Software Dynamics Operating System (OS)

@item SDP
Scenario Design Power (TDP)

@item SDP
Service Delivery Point

@item SDP
Service Discovery Profile (Bluetooth)

@item SDP
Session Description Protocol (RFC 2327)

@item SDP
Shared Development Process (MS)

@item SDP
Software Development Plan

@item SDP
Specialized Data Point (IN)

@item SDP
Streaming Data Procedure

@item SDQ
Store Data Queue (Power4, IBM, CPU, SRQ)

@item SDR
Service DiRectory [tool] (SAP)

@item SDR
Shared Data Research

@item SDR
Signal-to-Distortion Ratio

@item SDR
Single Data Rate (GDR, QDR, ODR)

@item SDR
Store Data Register (IC)

@item SDR
Streaming Data Request

@item SDR
System Design Review

@item SDRAM
Synchronous Dynamic Random Access Memory (RAM, DRAM, IC, Intel, Samsung)

@item SDRP
Source Demand Routing Protocol

@item SDRSDRAM
Single Data Rate Synchronous Dynamic Random Access Memory (DRAM, RAM, IC), "SDR-SDRAM"

@item SDS
SubDivision Surfaces (3D)

@item SDS
Switched Data Service

@item SDS
Synchronous Data Set

@item SDS
Sysops Distribution System (BBS)

@item SDSAF
Switched Digital Services Applications Forum (org.)

@item SDSC
San Diego Supercomputer Center (org., USA)

@item SDSC
Synchronous Data Set Controller

@item SDSCNET
San Diego Supercomputer Center NETwork (network, USA), "SDSCnet"

@item SDSL
Single line Digital Subscriber Line (DSL)

@item SDSMA
Slotted Digital Sense Multiple Access (MODACOM), "S-DSMA"

@item SDSN
Secure Data System Network

@item SDT
Service Description Table (DVB)

@item SDT
Software Development Tools

@item SDT
Source Data Terminal

@item SDT
Systems Development Tool

@item SDTP
[PPP] Serial Data Transport Protocol (PPP, RFC 1963)

@item SDU
Service Data Unit (OSI)

@item SDU
Software Distribution Utilities (IBM, HP)

@item SDV
Switched Digital Video (VOD)

@item SDX
Storage Data ACceleration (ATAPI, WD, CD, DVD)

@item SDXC
Secure Digital eXtended Capacity (SD)

@item SE
Security Enhanced [linux] (Linux)

@item SE
Service / Systems Engineer

@item SE
Software Engineering

@item SE
Standard / Special Edition (IBM, OS/2)

@item SE
Switching Element

@item SE
System Extension

@item SEA
Self-Extracting Archive

@item SEA
Society for Electronic Access (org.)

@item SEA
System Enhancement Associates (manufacturer)

@item SEAC
Standards Eastern Automatic Computer

@item SEAL
Simple and Efficient Adaptation Layer (ATM)

@item SEAP
Service Element Access Point

@item SEB
Seat Electronic Box (Airbus, A380)

@item SEC
Single Edge Contact [card]

@item SECAM
SEquentiel Couleur Avec Memoire

@item SECB
Severely Errored Cell Block (UNI)

@item SECC
Single Edge Connector Case (CPU)

@item SECCOS
SEcure Chip Card Operating System (OS)

@item SED
Self-Encrypting Drive (Seagate)

@item SED
Stream EDitor (Unix)

@item SED
Surface-conducting electron Emitter Display (Toshiba)

@item SEDAS
Standardisiertes Einheitliches DatenAustauschSystem (EDI)

@item SEDISI
Asociacion Espanola de Empresas de Tecnologias de la Informacion (org., Spain, AETIC, predecessor)

@item SEE
Safenet Ethernet Encryptor (cryptography)

@item SEE
Societe des Electriciens et Electroniciens (org., France)

@item SEE
Software Engineering Environments

@item SEE
Systems Equipment Engineering

@item SEF
Source Explicit Forwarding

@item SEFS
Severely Errored Framing Seconds (DS1/E1, DS3/E3)

@item SEH
Structured Exception Header

@item SEHOP
Structured Exception Handler Overwrite Protection

@item SEI
Software Engineering Institute

@item SEL
Software Engineering Laboratory

@item SEL
Standard Elektrik Lorenz [ag] (manufacturer)

@item SEL
System Event Log (IPMI)

@item SELHPC
South East London - High Performance Computing [centre] (org.), "SEL-HPC"

@item SELINUX
Security Enhanced Linux (Linux, NSA, FLASK), "SELinux"

@item SEM
Secure Extension Mode (AMD, TCB)

@item SEM
Security Event Management (SIM)

@item SEM
Server Enhancement Module

@item SEM
Standard Error of the Mean

@item SEMS
SIP Express MediaServer (SIP, iptel)

@item SEO
Search Engine Optimization (WWW)

@item SEP
Someone Else's Problem (slang, Usenet, IRC)

@item SEPIA
Simple EMACS PERL InterAction (EMACS, PERL)

@item SEPP
Secure Electronic Payment Protocol (banking, IBM, Netscape, GTE)

@item SEQUEL
Structured English QUEry Language (IBM, DB, SQL, predecessor)

@item SERM
Structured Entity Relationship Model (DB, ERM)

@item SERT
Security Emergency Response Team (org., Australia, Internet)

@item SES
SCSI Enclosure Services (SCSI)

@item SES
Security Enabling Services (IBM)

@item SES
Severely Errored Seconds (DS1/E1)

@item SESAM
Synergetische Erkennung mittels Standbild, Akustik und Motorik (IIS)

@item SET
Secure Electronic Transactions (IBM, Visa, MS, IBM, Mastercard, Netscape, banking)

@item SET
Single Electronic Transistor

@item SET
Software Engineering Technology

@item SET
Standard d'Echange et de Transfert (AFNOR, France)

@item SETA
Systems Engineering and Technical Assistance

@item SETL
SEt Theory Language (New York Uni.), "SetL"

@item SETP
Secure Electronic Transactions Process

@item SETP
Stream Environment Transport Protocol

@item SEU
Software-Entwicklungs-Umgebung (CASE)

@item SEU
Source Entry Utility (IBM, ADT)

@item SF
Service Feature (IN)

@item SF
Sign Flag (assembler)

@item SF
Software Factories

@item SF
Standard Form

@item SF
Switching Fabric

@item SFBI
Shared Frame Buffer Interconnect

@item SFC
System File Checker (MS, Windows)

@item SFCC
Slat Flap Control Computer (Airbus, A380)

@item SFD
Simple Formattable Document (CCITT, MHS, X.420)

@item SFD
Start Frame Delimiter (ethernet)

@item SFD
Symbolic File Directory

@item SFF
Small Form Factor [committee] (org.)

@item SFLC
Software Freedon Law Center (org., GPL)

@item SFMJI
Sorry For My Jumping In (slang, Usenet, IRC)

@item SFP
Saved Frame Pointer (CPU, RAM)

@item SFP
Small Form-factor Pluggable (FC)

@item SFP
System File Protection (MS, WIndows)

@item SFPRNSB
Select a File for Processing and Read Next Spool Buffer (IBM, VM/ESA, CP)

@item SFPS
Secure Fast Packet Switching (Cabletron)

@item SFQL
Structured Full-text Query Language

@item SFS
Shared File System (IBM. CMS, VM/ESA)

@item SFS
Stepless Frequency Selection (ASUS)

@item SFS
Suomen Standardisoimisliitto [Standards Association of Finland] (org., Finland)

@item SFT
System Fault Tolerance (Novell)

@item SFT
System File Table (DOS)

@item SFTP
Screened Foiled Twisted Pair [cable] (UTP, TP)

@item SFTP
Simple File Transfer Protocol (RFC 913)

@item SFUG
Security Features User's Guide

@item SG
Signal Ground (MODEM)

@item SGA
Shared Global Array (DEC, VMS)

@item SGC
SCSI Graphic Commands (SAM)

@item SGCP
Simple Gateway Control Protocol (MGCP)

@item SGEMM
Single precision GEneral Matrix Multiply (GEMM, BLAS)

@item SGI
Silicon Graphics Incorporated (manufacturer, SGI)

@item SGM
SeGmentation Message

@item SGML
Standard Generalized Markup Language (ISO 8879, JTC1, RFC 1874, SGML)

@item SGMLB
Standard Generalized Markup Language - Binary version (SGML), "SGML-B"

@item SGMP
Simple Gateway Monitoring Protocol (RFC 1028)

@item SGRAM
Synchronous Graphics Random Access Memory (DRAM, RAM)

@item SGSN
Serving GPRS Support Node (GPRS, mobile-systems)

@item SGT
Surrounding Gate Transistor (IC)

@item SGTSI
Semi-Graphical Tree Structure Interface

@item SHA
Secure Hash Algorithm (cryptography, NIST)

@item SHA
Super High Aperture [LCD] (LCD)

@item SHA1
Secure Hash Algorithm 1 (cryptography, SHA)

@item SHED
Segmented Hypergraphics EDitor (MS, Windows, ADT)

@item SHF
Super-High Frequency

@item SHOE
Simple HTML Ontology Extensions (HTML, WWW)

@item SHTSI
Somebody Had To Say It (slang, Usenet)

@item SHTTP
Secure HyperText Transfer Protocol (HTTP), "S-HTTP" 

@item SHV
Standard High Volume [motherboard] (SMP, Intel)

@item SI
Schweizer Informatikergesellschaft (org., Switzerland)

@item SI
Skyrslutaeknifelags Islands (org., Iceland)

@item SI
Source Index [register] (CPU, Intel, assembler)

@item SI
SPARC International (org., manufacturer)

@item SI
System Identifier (DTD, URI, SGML, FPI)

@item SI
System Information

@item SIA
Semiconductor Industry Association (org., USA)

@item SIAM
Society for Industrial and Applied Mathematics (org., USA)

@item SIB
Service Independent building Block (IN)

@item SIBO
SIxteen Bit Organizer or SIngle Board Organizer (Psion, PDA, BIT)

@item SIC
Silicon Integrated Circuit

@item SIC
Standard Industry Classification

@item SIC
Subject Indicator Code

@item SICE
Society of Instrument and Control Engineers (org., Japan)

@item SICS
Swedish Institute of Computer Sciences (org., Sweden)

@item SID
Security IDentifier (AD, RID, ACL)

@item SID
Signaling IDentifier

@item SID
Society for Information Displays (org.)

@item SID
Sound Interface Device (audio, C64)

@item SID
SWIFT Interface Device (SWIFT)

@item SID
Symbolic Instruction Debugger (CP/M)

@item SID
System IDentification

@item SID
System Integration & Development, "SI&D"

@item SIDF
System Independent Data Format (Novell, SMS)

@item SIDM
Serial Impact Dot Matrix [printer]

@item SIDR
Service Independent Data Requester (Novell, Netware)

@item SIETEM
Siemens TTCN Test Manager (TTCN, Tektronix, SNI)

@item SIF
Significant Pel Field (MPEG)

@item SIFS
Short InterFrame Space (MAC, 802.11a, IFS, WLAN)

@item SIFT
Software Implemented Fault Tolerance (HIFT)

@item SIFTUFT
Sender-Initiated File Transfer/Unsolicited File Transfer (RFC 1440), "SIFT/UFT"

@item SIG
Special Interest Group

@item SIGART
[ACM] Special Interest Group on ARTificial intelligence (org., ACM, AI)

@item SIGBIT
Special Interest Group on Business Information Technology

@item SIGCAT
Special Interest Group for CD-ROM Applications Technology (CD)

@item SIGCPR
Special Interest Group on Computer Personal Research (org., ACM)

@item SIGCSE
Special Interest Group on Computer Science Education (org., ACM)

@item SIGDA
Special Interest Group on Design Automation (org., ACM)

@item SIGG
SIGnaturGesetz telecommunication, Germany, "SigG"

@item SIGL
SIGnal Line (REXX)

@item SIGMA
Software Industrialized Generator and Maintenance Aids system (MITI)

@item SIGNC
Special Internet Group Name Cache

@item SIGPLAN
Special Interest Group for Programming LANguages

@item SIGV
SIGnaturVerordnung (telecommunication), "SigV"

@item SIGWEB
Special Interest Group on the world wide WEB (org., UK)

@item SII
Static Invocation Interface

@item SIIA
Software and Information Industry Association (org., USA)

@item SILC
Secure Internet Live Conferencing

@item SILS
Secure Interoperable LAN/MAN Standard (LAN, MAN)

@item SILS
Standard for Interoperable LAN Security (LAN)

@item SIM
Security Information Management (SEM)

@item SIM
Signal Interface Module

@item SIM
Subscriber Identity Module (GSM, mobile-systems)

@item SIMD
Single Instruction [stream], Multiple Data [stream] (CPU)

@item SIMDIS
SIMulation DISposition (MBAG)

@item SIMIS
SIcheres MIkroprozessor System (SNI)

@item SIMM
Single Inline Memory Module (IC)

@item SIMNET
SIMulation NETwork (network)

@item SIMSA
	Swiss Interactive Media and Software Association (org.)

@item SINA
Sichere Inter-Netzwerk Architektur (BSI)

@item SIO
Simultan Input Output (QMS)

@item SIP
SCSI-3 Interlocked Protocol (SAM)

@item SIP
Session Initiation Protocol (IETF, VoIP, ENUM, RFC 2543)

@item SIP
Simulated Input Processor

@item SIP
SMDS Interface Protocol (SMDS)

@item SIP
Strategische InformationsPlanung (IM)

@item SIP
Symbolic Input Program

@item SIPC
Simply Interactive Personal Computer

@item SIPO
Serial In Parallel Out

@item SIPP
Simple Internet Protocol Plus (IP, IPV6, RFC 1710, Internet)

@item SIPP
SImple Polygone Processor (Unix)

@item SIPP
Single Inline Package Pin (IC)

@item SIPRNET
Secret IP Router NETwork (DISN, mil.)

@item SIPS
Session Initiation Protocol Secure (SIP, SSL, TCP)

@item SIPS
Super InPlane Switching (LCD, IPS), "S-IPS"

@item SIQ
Single Input Queue (IBM, OS/2)

@item SIR
Save Instruction Recognition

@item SIR
Selective Information Retrieval

@item SIR
Serial InfraRed (HP)

@item SIR
Sicherheit im Rechenzentrum (TPS)

@item SIR
Statistical Information Retrieval

@item SIR
Sustained Information Rate (SMDS)

@item SIRENE
Supplementary Information REquest at the National Entry (SIS, Europe)

@item SIS
Schengen Information System (police, Europe)

@item SIS
Silicon Integrated Systems [corp.] (manufacturer, Taiwan)

@item SIS
Software Information Services

@item SIS
Stellen-Informations-Service (WWW)

@item SIS
Strategic Information System

@item SISAL
Streams and Iteration in a Single-Assignment Language

@item SISD
Single Instruction [stream], Single Data [stream] (CPU)

@item SISO
Single Input, Single Output (WLAN)

@item SISSL
Sun Industry Standards Source License (Sun)

@item SIT
institut fuer SIchere Telekommunikation (GMD, org.)

@item SITD
Still In The Dark (slang)

@item SIWPS
Simple Internet White Pages Service (Internet)

@item SIZ
Sparkassen-Informatik-Zentrum (org., banking)

@item SJF
Shortest Job First

@item SKI
Service Key Identifier (X509v3, RFC 3280)

@item SKIA
Secure Key Issuing Authority (TESS)

@item SKID
Service Key IDentifier (X509v3, RFC 3280)

@item SKIMS
Schichtenuebergreifendes Kooperatives Immunsystem fuer Mobile, mehrseitige Sicherheit

@item SKIP
Simple Key-management for Internet Protocols (Internet, cryptography, Sun)

@item SKS
Synchronizing Key Server (PGP, GPG, PKS, KKS)

@item SLA
Service Level Agreement (ITIL, SLM)

@item SLAC
Secure Linux Administration Conference (Linux)

@item SLAD
Security Local Auditing DAEMON (BOSS, BSI)

@item SLAM
Simulation Language for Alternative Modeling

@item SLB
Segment Lookaside Buffer (CPU, Power4, IBM)

@item SLC
Service Level Contract

@item SLC
Short Length Cartridge (IBM, Streamer)

@item SLC
Simple Line Code [modulation]

@item SLC
Single Level Cell (IC, Flash, SLC)

@item SLD
Second Level Domain (Internet, ICANN)

@item SLDC
Synchronous Data Link Control

@item SLDRAM
SyncLink Dynamic Random Access Memory (DRAM, RAM)

@item SLE
Screen List Editing

@item SLED
Single Large Expensive Drive

@item SLED
SuSE Linux Enterprise Destop (SuSE, Linux)

@item SLES
SuSE Linux Enterprise Server (Linux, SUSE)

@item SLFP
Shared Frame Buffer Interconnect (ATI, Intel)

@item SLI
Scalable Link Interface (PCIe, Nvidia)

@item SLI
Scan Line Interleave (3D)

@item SLIC
Serial Link and Interrupt Controller (TSMP, Wyse)

@item SLIC
Subscriber Line Interface Circuit (PBX)

@item SLIK
SimpLIstic sKin interface (GTK)

@item SLIP
Serial Line Internet Protocol (Internet, RFC 1055), "SL/IP"

@item SLM
Service Level Management (ITIL)

@item SLM
Single Lock Manager (GFS)

@item SLMR
Silly Little Mail Reader

@item SLOS
SuSE Linux Office Server (SuSE, Linux)

@item SLOX
SuSE Linux Open eXchange server (SuSE, Linux)

@item SLP
Service Location Protocol (IP)

@item SLP
Service Logic Program (IN)

@item SLP
Symposium on Logic Programming (Konferenz)

@item SLP
System Locked Preinstallation (MS, Windows, XP, OEM)

@item SLQ
Super Letter Quality [fonts] (Star)

@item SLR
Scalable Linear Recording (Streamer, Tandberg)

@item SLS
Single Large Surface [display]

@item SLS
Softlanding Linux System (Linux)

@item SLS
Storage Library System

@item SLSI
Super Large Scale Integration

@item SLT
Solid-Logic Technology

@item SLU
Secondary Logical Unit

@item SLU
Serial Line Unit

@item SM
Smart Media [card]

@item SM
Sparse Mode (PIM, Multicast)

@item SMA
Shared Memory Architecture

@item SMA
Standardization Management Activity

@item SMAE
System Management Application Entity (OSI)

@item SMAF
Service Management Agent Function (IN)

@item SMAF
Synthetic Music Mobile Application Format (Yamaha, mobile-systems)

@item SMAP
System Management Application Process (OSI)

@item SMART
Self-Monitoring, Analysis and Reporting Technology (HDD, IDE, Conner, IBM, Quantum, Seagate, WD), "S.M.A.R.T."

@item SMASE
System Management Application Service Element (OSI)

@item SMB
Server Message Block [protocol] (IBM, Intel, MS)

@item SMB
Small Medium Business and enterprise [market]

@item SMB
Standards Managing Board (PIMA, I3C)

@item SMB
System Management Bus

@item SMBA
Shared Memory Buffer Architecture (Intel)

@item SMBP
Sever Message Block Protocol

@item SMC
SCSI-3 Medium changer Commands (SAM, SCSI)

@item SMC
Standard Microsystems Corporation (manufacturer)

@item SMD
Storage Module Device

@item SMD
Surface Mounted Device

@item SMD
System Management Bus ??? (Intel)

@item SMDAC
Single MAC Dual Attached Concentrator (FDDI, DAC, MAC)

@item SMDI
Simplified Message Desk Interface (Bell Labs)

@item SMDI
Storage Module Disk Interconnect

@item SMDL
Standard Music Description Language (ISO, IEC, CD 10743)

@item SMDR
Station Message Detail Recording

@item SMDR
Storage Management Data Requester (Novell, Netware, SMS)

@item SMDS
Switched Multimegabit Data Service (BELLCORE, BIT)

@item SMDSCNM
SMDS Customer Network Management (SMDS), "SMDS CNM"

@item SME
Society of Manufacturing Engineering (org., USA)

@item SME
Storage Management Engine (Novell, Netware, SMS)

@item SMEP
Supervisory Mode Execution Prevention (AMT, Intel)

@item SMF
Service Management Framework (IBM)

@item SMF
Service Management Function (IN)

@item SMF
Single Mode Fiberoptic cable (FDDI, MMF)

@item SMF
Standard MIDI File (MIDI)

@item SMF
System Management Function (MS, MOF)

@item SMFA
Special / System Management Functional Area (OSI)

@item SMFF
Script Mathematical Formula Formatter

@item SMG
Special Mobile Group (GSM, org., mobile-systems)

@item SMI
Storage Management Initiative (org., SAN, Bluetooth, SNIA)

@item SMI
Structure and identification of Management Information (OSI, RFC 1155/1902)

@item SMI
Sun Microsystems Inc. (manufacturer)

@item SMI
System Management Interrupt (SMB)

@item SMI
System Memory Interface (Power4, IBM)

@item SMI
System Monitoring Interface (Informix, DB)

@item SMIL
Synchronized Multimedia Integration Language (W3C, WWW)

@item SMIME
Secure/Multipurpose Internet Mail Extensions (MIME, MS, Lotus, Qualcomm, RSA, cryptography), "S/MIME"

@item SMING
Structure of Management Information - Next Generation (RFC 3780), "SMIng"

@item SMIOS
System Management Basic Input Output System (DMTF, BIOS)

@item SMIS
Service-Marketing-InformationsSystem (MBAG)

@item SMIS
Storage Management Initiative Specification (SMI, SAN, WBEM, CIM, SLP, SNIA), "SMI-S"

@item SMIT
System Management Interface Tool (IBM, AIX)

@item SMK
Software Migration Kit

@item SMK
Structured Meta-Knowledge

@item SML
Service Management Layer (TMN)

@item SML
Shared Memory Link (TCP/IP)

@item SML
Siemens Modular Link

@item SML
Standard Machine Language

@item SML
Standard Meta Language

@item SMLNJ
Standard Meta Language / New Jersey, "SML/NJ" 

@item SMM
System Management Mode (CPU)

@item SMM
System Manager's Manual (BSD, Unix)

@item SMOLED
Small Molecules Organic Light Emitting Display (OLED, LED)

@item SMP
Software Motion Picture (DEC)

@item SMP
Symmetric MultiProcessor [system] (SMP, AMP)

@item SMP
Symmetrisches MultiProzessor [system]

@item SMP
System Modification Program

@item SMPC
Shared Memory Parallel Computer (HPC)

@item SMPPPD
Suse Meta Point-To-Point DAEMON (SuSE, Linux, PPP, DAEMON)

@item SMPTE
Society of Motion Picture and Television Engineers (org.)

@item SMPU
Switch Module Processor Unit

@item SMR
Shingled Magnetic Recording (Seagate)

@item SMR
Source Maintainability and Reliability

@item SMR
Specialized Mobile Radio [systems]

@item SMRT
Signal Message Rate Timing

@item SMS
Service Management System

@item SMS
Short Message Service (GSM, mobile-systems)

@item SMS
Storage Management Services (Novell, Netware)

@item SMS
System-Managed Storage

@item SMS
Systems Management Server (MS, MOM)

@item SMSAC
Society of Management Science and Applied Cybernetics (org., India)

@item SMSC
Short Message Service Center (SMS, GSM, mobile-systems)

@item SMSCB
Short Message Service Cell Broadcast (SMS), "SMS CB"

@item SMSCEMI
Short Message Service Center External Machine Interface [protocol] (SMS)

@item SMSP
Storage Management Services Protocol (Novell, SMS)

@item SMT
Segment Table Map

@item SMT
Shared Memory Transport (X-Windows)

@item SMT
Simultaneous MultiThreading (CPU)

@item SMT
Staroffice Migration Toolkit (Sun)

@item SMT
Station ManagemenT (FDDI)

@item SMT
Surface-Mount Technology

@item SMTA
Subordinate Message Transfer Agent (MTA)

@item SMTP
Simple Mail Transfer Protocol (RFC 821, TCP/IP)

@item SMUG
Seldom Met Users Group [book] (HP, HP 3000)

@item SMUX
SNMP MUltipleXing protocol (SNMP, MUX, RFC 1227)

@item SN
Sequence Number

@item SN
Serial Number

@item SN
Subscriber Number (MS-ISDN, GSM, mobile-systems)

@item SN
Super Node (Kazaa, P2P)

@item SNA
Systems Network Architecture (IBM)

@item SNAC
SNA Network Access Controller (SNA, SDLC, IDS)

@item SNAC
SubNetwork ACcess [functions]

@item SNACP
[PPP] Systems Network Architecture Control Protocol (PPP, SNA, RFC 2043)

@item SNACP
SubNetwork ACcess Procedure (ISO, IS 8648, SNAC), "SNAcP"

@item SNADS
Systems Network Architecture Distribution Service (IBM, CCS)

@item SNAFU
Situation Normal All Fouled Up (slang)

@item SNAIP
[advanced] Systems Network Architecture/Internet Protocol (SNA, IP, RFC 1538), "SNA/IP"

@item SNAP
SubNetwork Access Protocol (LAN, ethernet)

@item SNAP
SubNetwork Attachment Point (IEEE 802.1a)

@item SNAP
System and Network Administration Program

@item SNAP
System Neutral Access Protocol (SciTech)

@item SNCP
Single Node Control Point (IBM, SNA)

@item SNDC
SubNetwork Dependent Convergence [functions] (OSI)

@item SNDCP
SubNetwork Dependent Convergence Procedure (ISO, IS 8648, OSI, SNDC)

@item SNEPS
Semantic NEtwork Processing System (GNU, LISP), "SNePS"

@item SNF
Server Natural Format (Fonts, X)

@item SNF
Shared Network Facilities

@item SNG
Satellite News Gathering

@item SNI
Service Name Indicator (TLS, RFC 3546)

@item SNI
Siemens Nixdorf Informationssysteme [AG] (manufacturer)

@item SNI
SNA Network Interconnection (IBM, VTAM, SNA)

@item SNI
Subscriber Network Interface (SMDS)

@item SNIA
Storage Networking Industry Association (org., NAS, SAN)

@item SNIC
SubNetwork Independent Convergence [functions] (OSI)

@item SNICP
SubNetwork Independent Convergence Procedure (ISO, IS 8648, OSI, SNIC)

@item SNK
Shin Nihon Kikaku [old term] (manufacturer, Japan)

@item SNL
Sandia National Laboratories (org., USA)

@item SNMP
Simple Network Management Protocol (RFC 1157/1902, TCP/IP, IETF)

@item SNMPOID
SNMP Object IDentifier (SNMP), "SNMP OID"

@item SNNS
Stuttgart Neural Network Simulator (IPVR, NN)

@item SNOBOL
StriNg Orientated symBOlic Language

@item SNP
SubNetwork Protocol

@item SNPA
Sub-Network Point of Attachment

@item SNPP
Simple Network Paging Protocol (RFC 1861, SMS)

@item SNR
Serial NumbeR (IMEI, GSM, mobile-systems)

@item SNR
Signal-to-Noise Ratio

@item SNRM
Set Normal Response Mode (SDLC, HDLC, ADDCP, LAPB)

@item SNRME
Set Normal Response Mode Extension (SNRME)

@item SNS
Secure Network Server

@item SNTP
Simple Network Time Protocol (NTP, RFC 2030)

@item SNW
Storage Networking World [conference]

@item SOA
Service Orientated Architecture

@item SOA
Start Of Authority record (DNS)

@item SOA
State Of the Art (slang)

@item SOAP
Simple Object Access Protocol (W3C, XML, HTML)

@item SOAP
Symbolic Optimal Assembly Program (IBM)

@item SOB
Start Of Block

@item SOBA
Service-Orientated Business Applications (SODA, SOA)

@item SOC
Security Operations Center

@item SOC
System-On-a-Chip

@item SOC
Systems and Option Catalog

@item SOCKS
SOCKet Secure

@item SOCO
Service Office/Central Office, "SO/CO"

@item SODA
Service-Orientated Developmenrt of Applications (SOA, SOBA)

@item SODA
Simplified OS for Distributed Applications (OS)

@item SODA
System Optimization and Design Algorithm

@item SODIMM
Small Outline Dual Inline Memory Module (DRAM, DIMM)

@item SODIS
SOftware Dokumentations- und InformationsSystem

@item SOE
Sony Online Entertainment (Sony)

@item SOE
Standard Operating Environment

@item SOE
Standards of Excellence

@item SOEP
Secondary Operand Execution Pipeline (Motorola, CPU), "sOEP"

@item SOF
Start Of Frame (S-ATA)

@item SOFABED
[davenport] Standard Open Formal Architecture for Browsable Electronic Documents

@item SOH
Section OverHead

@item SOH
Start Of Header

@item SOHO
Small Office / Home Office [market]

@item SOI
Silicon-On-Insulator [technology/wafer] (IC, IBM)

@item SOIF
Summary Object Interchange Format (WWW)

@item SOJ
Small-Outline J-lead [chip] (IC, DRAM)

@item SOL
Simulation-Oriented Language

@item SOLSA
Support of Localized Service Areas (ETSI), "SoLSA"

@item SOM
Self-Organizing Machine

@item SOM
Structured Object Method

@item SOM
System Object Model (IBM, ORB, CORBA)

@item SONDS
Small Office Network Data System

@item SONET
Synchronous Optical NETwork (FDDI, ATM, SDH)

@item SOOO
Star Office / Open Office, "SO/OO"

@item SOP
Standard Operating Procedure

@item SORM
Service Orientated Resource Management

@item SOS
Share Operating System (OS)

@item SOS
Sophisticated Operating System (OS, Apple)

@item SOS
Standards and Open Systems

@item SOS
Support On Site

@item SOS
Symbolic Operating System (OS)

@item SOSP
System Operational and Support Plan

@item SOTA
State of the Art (slang)

@item SOX
Sound EXchange [software]

@item SP
Security Policies (IPSec)

@item SP
Service Pack (MS, Windows NT, XP)

@item SP
Service Processor (Power4, IBM, IC)

@item SP
Service Processor (EMC)

@item SP
Service Provider (DMI)

@item SP
Signal Processor

@item SP
Simple visual Profile (MPEG)

@item SP
SPare (IMEI, GSM, mobile-systems)

@item SP
Speculative Precomputation

@item SP
Speech Processing

@item SP
Stack Pointer [register] (CPU, Intel, assembler)

@item SP
Structured Programming

@item SP
Support Pack (SAP)

@item SP
System Product

@item SP1
Service Pack 1 (MS, Windows, XP)

@item SP2
Service Pack 2 (MS, Windows, XP)

@item SPA
Software Publishers Association (org., USA)

@item SPA
Storage Pool Allocator (ZFS)

@item SPADE
Statistical Packet Anomaly Detection Engine (Snort, IDS)

@item SPAG
[european] Standards Promotion and Application Group (org., manufacturer, Europe)

@item SPAM
Send Phenomenal Amounts of Mail (Usenet, EMP, slang)

@item SPAM
Spiced Pork and hAM (Usenet, EMP)

@item SPANS
Simple Protocol for ATM Network Signalling (ForeRunner, ATM)

@item SPAP
Secure Password Authentication Protocol

@item SPAP
Shiva Password Authentication Protocol (PAP, 3Com)

@item SPARC
Scalable Processor ARChitecture (Sun)

@item SPARC
Standard Planning And Requirement Committee (ANSI, org.)

@item SPARQL
???

@item SPAT
Speech Pronunciation Analysis Training (Uni Mainz), "S.P.A.T."

@item SPB
Shortest Path Bridging (IEEE 802.1aq)

@item SPC
SCSI-3 Primary Commands (SAM, SCSI)

@item SPC
Solution Partner Center (IBM)

@item SPC
Stored Program Command

@item SPC
Stored Program Control

@item SPCF
Service Point Command Facility (IBM)

@item SPCS
Stored Program Control Systems

@item SPD
Security Policy Database (SP, IPSec)

@item SPD
Serial Presence Detect (EEPROM, SDRAM)

@item SPD
Software Product Description

@item SPD
Software Products Division

@item SPDEEPROM
Serial Presence Detect - Electronical Erasable Programmable Read Only MemorySerial Presence Detect (EPROM, IC, ROM), "SPD-EEPROM"

@item SPDIF
Sony/Philips - Digital Interface Format (audio, Sony, Philips), "S/P-DIF"

@item SPDL
Standard Page Description Language (ISO, IEC, IS 10180)

@item SPDN
Shared Private Data Network

@item SPDU
Session Protocol Data Unit (OSI, PDU, OSI/RM)

@item SPE
Symbolic Programming Environment

@item SPE
Synchronous Payload Envelope

@item SPE
Synergistic Processor Elements (IBM, Cell, PPE)

@item SPEC
System Performance Evaluation Corporation (org., RISC)

@item SPF
Sender Permitted From [old term] (SPAM)

@item SPF
Sender Policy Framework (SPAM)

@item SPF
Structured Programming Facility

@item SPI
SCSI-3 Parallel Interface (SAM, SCSI)

@item SPI
Security Parameter Index

@item SPI
Serial / Synchronous Peripheral Interface

@item SPI
Service Provider Interface (WOSA)

@item SPI
Software in the Public Interest, inc. (org.)

@item SPI
Software Products International (manufacturer)

@item SPI
Stateful Packet Inspection (TCP/IP)

@item SPICE
Scalable Parallel Intelligent Communications Engine

@item SPICE
Simulation Program with Integrated Circuit Emphasis

@item SPICS
Spare Parts Inventory Control System (MBAG)

@item SPID
Service Profile IDentifier (ISDN)

@item SPID
Service Protocol IDentifier

@item SPIM
SPAM over Instant Messaging (SPAM, IM)

@item SPIN
Sponsored Programs Information Network

@item SPIT
SPAM over Internet Telephony (SPAM, VoiP)

@item SPKM
Simple Public-Key [GSS-API] Mechanism (GSS, RFC 2025)

@item SPL
Samsung Printer Language

@item SPL
Set Priority Level (Unix)

@item SPL
Simple Programming Language

@item SPL
Sound Pressure Level

@item SPL
Sun Public License (Sun)

@item SPL
Systems Programming Language (HP, MPE, ALGOL, HP 3000)

@item SPL1
Simple visual Profile @@ Level 1 (MPEG, QCIF), "SP@@L1"

@item SPM
Session Protocol Machine (OSI, ISO 8327)

@item SPM
Set Program Mask

@item SPM
Software Performance Monitor

@item SPM
Source Program Maintenance

@item SPM
System Performance Monitor

@item SPM2
System Performance Monitor /2 (IBM, OS/2), "SPM/2"

@item SPMIDI
Scalable Polyphony MIDI (MIDI), "SP-MIDI"

@item SPML
Service Provisioning Markup Language (OASIS)

@item SPN
Substitution Permutation Network (cryptography)

@item SPOF
Single Point Of Failure

@item SPOOL
Simultaneous Peripheral Operations OnLine

@item SPOT
Smart Personal Object Technology (MS, Internet)

@item SPP
Scalable Parallel Processing (Intel)

@item SPP
Sequenced Packet Protocol

@item SPP
Serial Port Profile (Bluetooth, GAP, SPP)

@item SPP
Software Protection Platform (MS, Windows, Vista)

@item SPP
Standard Parallel Port

@item SPP
System Platform Processor (Nvidia)

@item SPPI
Structure of Policy Provisioning Information (RFC 3159)

@item SPR
Software Problem Report

@item SPREAD
Systems, Programming, Review, Engineering And Development

@item SPS
Semiconductor Product Sector (Motorola)

@item SPS
SpeicherProgrammierbare Steuerungstechnik

@item SPS
String Processing System

@item SPS
Support Package Stack (SAP, EP)

@item SPS
Symbolic Programming System

@item SPSL
Special-Purpose Simulation Language

@item SPSS
Statistical Package of the Social Sciences

@item SPT
Sectors Per Track

@item SPT
Shortest Path Tree (PIM, ST, Multicast)

@item SPTS
Single Program Transport Stream

@item SPU
Synergistic Processing Unit (IBM, Cell)

@item SPU
System Processing Unit

@item SPUCDL
Serial Peripheral Unit Controller/Data Link, "SPUC/DL" 

@item SPUD
Storage Pedestal Upgrade Disk / Drive

@item SPUR
Supercomputing Program for Undergraduate Research

@item SPX
Sequenced Packet eXchange (Novell, Netware)

@item SQ
Shielded Quart [cable]

@item SQ
Signal Quality (MODEM)

@item SQA
Software Quality Assurance

@item SQD
Signal Quality Detector

@item SQFP
Shrink Quad Flat Package (CPU)

@item SQL
Structured Query Language (ISO 9075, DB, 4GL)

@item SQLCLI
SQL Call Level Interface (SAG, SQL), "SQL/CLI"

@item SQLDA
Structured Query Language Descriptor Area (SQL)

@item SQLDMO
SQL Distributed Management Objects (MS, SQL Server, OLE, DB)

@item SQLDS
Structured Query Language/Data System (IBM, VMS), "SQL/DS"

@item SQLJ
Structured Query Language - Java (SQL, Java, DB, ANSI, NCITS)

@item SQLMED
Structured Query Language / Management of External Data (SQL, ISO, IEC), "SQL/MED"

@item SQLXML
Structured Query Language / eXtensible Markup Language (SQL, XML, ISO, IEC), "SQL/XML"

@item SQM
Software Quality Management

@item SR
Sensitivity Range (Fuji, photo, CCD)

@item SR
Service Release (MS)

@item SR
Source Routing [bridging]

@item SR
Status Register (IC, assembler)

@item SRAM
Static Random Access Memory (RAM, IC, RL)

@item SRAS
Secure Remote AccesS

@item SRAT
Static Resource Affinity Table (ACPI)

@item SRB
Stream Request Block

@item SRC
Sample Rate Converter (audio)

@item SRC
Semiconductor Research Council (org., USA)

@item SRC
Standard Context Routing (MODACOM)

@item SRC
System Resource Controller (AIX, IBM)

@item SRD
Screen Reader System

@item SRD
Secondary Received Data

@item SRD
Send and Request Data (Feldbus)

@item SRDF
Symmetrix Remote Data Facility (EMC)

@item SRE
Self Routing switch Element (ATM)

@item SRF
Science Research Foundation (org., UK)

@item SRF
Service Resource Function (IN)

@item SRF
Specifically Routed Frame

@item SRGB
Standardized Red Green Blue [colorspace] (RGB, Windows)

@item SRI
Stanford Research Institute (org., USA)

@item SRK
Storage Root Key (TPM, RSA)

@item SRL
Serial number revocation List (TCPA)

@item SRM
Security Reference Monitor (MS, Windows, ACL)

@item SRM
Storage Resource Management (SAN)

@item SRM
System Resources Manager

@item SRN
Source/Recipient Node (IBM)

@item SRP
Security Rollup Package (MS)

@item SRP
Software Reuse Program

@item SRP
Source Routing Protocol (IBM)

@item SRPI
Server Requester Programming Interface (IBM, API)

@item SRPM
Scalable Reverse Path Multicast (Multicast)

@item SRQ
Service ReQuest (GPIB)

@item SRQ
Store Reorder Queue (Power4, IBM, CPU)

@item SRS
Sound Retrieval System (Digital audio)

@item SRS
Sun Ray Software (Sun)

@item SRT
Secure Request Technology (banking, cryptography, Java)

@item SRT
Signal Requests Terminal

@item SRT
Source Route Transparent [bridges] (ethernet, Token Ring, IEEE 802.1D)

@item SRT
Speech Reception Threshold

@item SRTCP
Secure Real-Time Transport Control Protocol (SRTP)

@item SRTP
Secure Real-time Transport Protocol (RFC 3711, RTP)

@item SRTS
Synchronous Residual Time Stamp

@item SRVIFS
SeRVer Installable File System (IBM)

@item SS
Single Sided [disk] (FDD)

@item SS
Spread Spectrum (WLAN)

@item SS
Stack Segment [register] (CPU, Intel, assembler)

@item SS7
Signaling System 7 (ISDN)

@item SSA
Serial Storage Architecture (IBM)

@item SSAC
Security and Stability Advisory Committee (ICANN)

@item SSADM
Structured System Analysis and Design Method (DB)

@item SSAO
Screen-Space Ambient Occlusion (HBAO)

@item SSAP
Session Service Access Point (SAP, LLC, OSI/RM)

@item SSAP
Source link Service Access Point (SAP, LLC)

@item SSAS
Station Signaling and Announcement System

@item SSB
Single SideBand

@item SSBA
Suite Synthetique des Benchmarks de l'AFFU (MP)

@item SSBAM
Single SideBand Amplitude Modulation

@item SSC
Science Supercomputing Center (Uni Karlsruhe, Germany)

@item SSC
SCSI Stream Commands (SAM, SCSI)

@item SSC
Security Support Component (NGSCB, TCP)

@item SSC
Specialized Systems Consultants

@item SSCF
Service Specific Coordination Function (ATM)

@item SSCOP
Service Specific Connection Orientated Protocol (ATM)

@item SSCP
Service Switching & Control Point (IN)

@item SSCP
System Services Control Point (NAU, SNA, SSCP)

@item SSCP
Systems Security Certified Professional (ISC2)

@item SSCPNS
System Services Control Point Network Services (SSCP)

@item SSCS
Service Specific Convergence Sublayer (ATM)

@item SSD
Solid State Disk (HDD, RAM)

@item SSDA
Synchronous Serial Data Adapter

@item SSDC
Stack Segment Descriptor Cache [register] (SS, Intel, CPU)

@item SSDD
Single-Sided/Double-Density [disk] (FDD), "SS/DD"

@item SSDD
Solid State Disk Drive

@item SSDP
Simple Service Discovery Protocol (UPnP, UDP)

@item SSDU
Session Service Data Unit

@item SSE
Simple Screen Editor

@item SSE
Software Support Engineer

@item SSE
Streaming SIMD Extensions (Intel, Pentium, SIMD)

@item SSE
Structured Source Editing (Eclipse)

@item SSF
Service Switching Function (IN)

@item SSFDC
Solid State Floppy Disk Card (PCMCIA)

@item SSH
Secure SHell (Unix, Shell)

@item SSHD
Solid State Hybrid Drive (SSD)

@item SSI
[Schwedisches Strahlenschutzinstitut] (Sweden, org.)

@item SSI
Server Side Include [script] (HTTPD, CGI)

@item SSI
Small Scale Integration

@item SSI
Software Systems Interface

@item SSIA
Subject Says It All (slang)

@item SSID
Service Set IDentification (WLAN)

@item SSIMM
Single [RAS] Single Inline Memory Module (IC, RAS), "S-SIMM"

@item SSL
Secure Socket Layer (Netscape, RSA, WWW, cryptography)

@item SSLTLS
Secure Socket Layer / Transport Layer Security (RSA, cryptography, TLS), "SSL/TLS"

@item SSM
Set System Mask

@item SSM
Simplified Storage Management (HSM)

@item SSM
Source Specific Multicast (IETF, WG, Multicast, RFC 3569)

@item SSMA
SQL Server Migration Assistant (MS, SQL)

@item SSO
Single Sign On

@item SSP
Service Switching Point (IN)

@item SSP
Silicon Switch Processor (Cisco)

@item SSP
Standard Printer Port

@item SSP
Storage Service Provider

@item SSP
Structured Support Program

@item SSP
Switch to Switch Protocol (DLSW, RFC 1795)

@item SSP
Symposium on Security and Privacy (IEEE)

@item SSP
System Stack Pointer

@item SSP
System Support Program (OS, IBM)

@item SSPI
Security Support Provider Interface

@item SSR
Small Screen Rendering (WWW, Opera)

@item SSR
Solid-State Relay

@item SSRF
Server Side Request Forgery

@item SSSD
Single-Sided/Single-Density [disk] (FDD), "SS/SD"

@item SSSNA
Server to Server Systems Network Architecture (Banyan, VINES), "SS/SNA"

@item SST
Saitek Smart Technology

@item SST
Secure & Smart Technology (TPM), "S&ST"

@item SST
Simple SIPP Transition (Internet, SIPP)

@item SST
South Sumatra Time [+0700] (TZ)

@item SSTP
Screened Shielded Twisted Pair [cable] (STP, TP), "S/STP" 

@item ST
Seagate Technology (HDD)

@item ST
Security Target (CC)

@item ST
Segment Table / Type

@item ST
Shared Tree (PIM, SPT, CBT, Multicast)

@item ST
Stuffing Table (DVB)

@item ST2
[internet] STream protocol 2 (Internet, ATM, RFC 1819, Multicast)

@item STA
Spanning Tree Algorithm

@item STA
Static Timing Analysis

@item STACS
Symposium on Theoretical Aspects of Computer Science (Konferenz)

@item STAIRS
STorage And Information Retrieval System

@item STAM
Shared-Time Allocation Manager

@item STAR
Shareware Trade Association and Resources (org.)

@item STARS
Software Technology for Adaptable Reliable Systems

@item STAX
STreaming API for XML (XML, API), "StAX"

@item STB
Software Technical Bulletin

@item STC
Science and Technology Center (NSF, USA)

@item STC
Secure Transaction Channel (banking, V-One, cryptography)

@item STC
SeT Carry [flag] (assembler)

@item STC
Space Time Coding (WIMAX, 802.16e)

@item STC
Standard Transmission Code

@item STC
Sub-Technical Committee (ETSI)

@item STCIUR
Sub-Technical Committee International User Requirements (ETSI), "STC IUR"

@item STCP
Stream Control Transport Protocol

@item STD
Secondary Transmitted Data

@item STD
SeT Direction [flag] (assembler)

@item STD
State Transition Diagram

@item STD
Subscriber Trunk Dialing

@item STD
Suspend To Disk (BIOS, ACPI)

@item STDA
StreetTalk Directory Assistance (Banyan, VINES)

@item STDIN
STandarD INput

@item STDM
Synchronous Time Division Multiplexer

@item STDOUT
STandarD OUTput

@item STE
Section Terminating Equipment (SONET)

@item STE
Secure Terminal Equipment

@item STE
Spanning Tree Explorer

@item STE
Standard Terminal Equipment

@item STEP
STandard for the External representation / Exchange of Product data definition (ISO, DP 10303, CAD)

@item STF
Specialist Task Forces (ETSI)

@item STFT
Short Time Fourier Transformation

@item STFU
Shut The Fuck Up (slang, Usenet, IRC)

@item STGT
SCSI TarGeT framework (SCSI, Linux)

@item STI
SeT Interrupt [flag] (assembler)

@item STI
Sony - Toshiba - IBM [cell] (Sony, Toshiba, IBM, IC, SOC)

@item STI
Standard Tape Interface

@item STI
Still Image Architecture (Windows 98, WIA)

@item STIDC
Sony Toshiba IBM Design Center (Sony, Toshiba, IBM, Cell)

@item STII
[internet] STream protocol II (RFC 1819)

@item STING
Software Technology Interest Group (CERN, org.)

@item STIX
SmallTalk Interface to X (GNU)

@item STIX
Structured Threat Information eXpression (TAXII)

@item STL
Standard Template Library

@item STL
Standard Triangulation Language (CAD)

@item STLP
Secure Transport Layer Protocol

@item STM
Synchronous Transfer Mode (ATM, SDH)

@item STM
System Master Tape

@item STM1
Synchronous Transport Mode 1 [155,52 Mbps] (ATM, STM, SDH, OC-3), "STM-1"

@item STM12
Synchronous Transport Mode 12 [1866,24 Mbps] (ATM, STM, SDH, OC-36), "STM-12"

@item STM128
Synchronous Transport Mode 128 [39813,12 Mbps] (ATM, STM, SDH, OC-768), "STM-256"

@item STM16
Synchronous Transport Mode 16 [2488,32 Mbps] (ATM, STM, SDH, OC-48), "STM-16"

@item STM3
Synchronous Transport Mode 3 [466,56 Mbps] (ATM, STM, SDH, OC-9), "STM-3"

@item STM32
Synchronous Transport Mode 32 [4976,64 Mbps] (ATM, STM, SDH, OC-96), "STM-32"

@item STM4
Synchronous Transport Mode 4 [622,08 Mbps] (ATM, STM, SDH, OC-12), "STM-4"

@item STM6
Synchronous Transport Mode 6 [933,12 Mbps] (ATM, STM, SDH, OC-18), "STM-6"

@item STM64
Synchronous Transport Mode 64 [9953,28 Mbps] (ATM, STM, SDH, OC-192), "STM-64"

@item STM8
Synchronous Transport Mode 8 [1244,16 Mbps] (ATM, STM, SDH, OC-24), "STM-8"

@item STN
Scientific and Technical Network (network, JICST, FIZ)

@item STNLCD
SuperTwisted Nematic Liquid Crystal Display (LCD), "STN-LCD" 

@item STOC
Symposium on Theory Of Computing (Konferenz)

@item STONE
STructured and OpeN Environment (FZI Karlsruhe, Germany)

@item STORK
Secure indenTity acrOss boRders acKnowledged

@item STORM
Statistically-Oriented Matrix Program

@item STP
SATA Tunneling Protocol (SATA)

@item STP
Selective Tape Print

@item STP
Service Transaction Program (IBM)

@item STP
Shielded Twisted Pair [cable] (TP)

@item STP
Signaling Transfer Point (IN)

@item STP
Software Technology Park

@item STP
Software Through Pictures, "StP" 

@item STP
Spanning Tree Protocol (IEEE 802.1D, MSTP)

@item STP
System Training Program

@item STR
Synchronous Transmit Receive

@item STRD
STatistical Reference Datasets (NIST), "StRD"

@item STS
Synchronous Time Stamps (SDH)

@item STS
Synchronous Transport Signal

@item STS3C
Synchronous Transport System - level 3 Concatenated (SDH), "STS-3c"

@item STT
Secure Transaction Technology (MS, banking)

@item STT
Surface Tunnel Transistor (IC, DRAM, NEC)

@item STTL
Standard Transistor-Transistor Logic (TTL)

@item STTS
Secure Tape Transport Service

@item STU
Secure Telephone Unit

@item STUN
Simple Traversal of UDP through NAT (SIP, UDP, NAT, VoIP)

@item STV
Sprint Telecommunications Venture (org.)

@item STX
Start of TeXt

@item STX
Streaming Transformations for XML (XML)

@item SU
Screening Units

@item SU
Selectable Unit

@item SU
Signalling Unit

@item SU
Storage Unit

@item SU
Switch User (Unix)

@item SUA
Single User Account [feature] (Internet, NAT)

@item SUDS
Software Update and Distribution System

@item SUG
Sun User's Group (org., Sun, user group)

@item SUGA
Swedish User Group of Amiga (user group, Sweden, org.)

@item SUGD
Sun User's Group Deutschland (Sun, org., user group)

@item SUMC
Space Ultrareliable Modular Computer (RCA)

@item SUNET
Swedish University NETwork

@item SUNONE
Sun Open Network Environment (Sun, ONE)

@item SUNOS
SUN Operating System (Sun, OS, SPARC), "SunOS"

@item SUNVIEW
SUN's Visual Integrated Environment for Workstations (Sun, GUI)

@item SUPL
Secure User Plane Location (OMA, A-GPS)

@item SURANET
Southeastern Universities Research Association NETwork (network, USA), "SURAnet"

@item SURF
System Utilization Reporting Facility

@item SUS
Single Unix Specification (Unix)

@item SUS
Software Update Server / Service (MS)

@item SUSE
Software Und SystemEntwicklung [distribution] (Linux), "S.u.S.E."

@item SUSP
System Use Sharing Protocol

@item SUT
System Under Test

@item SUTP
Screened Unshielded Twisted Pair [cable] (UTP, TP), "S/UTP"

@item SUTT
Single User Test Tools

@item SUXGA
Super Ultra XGA [2048x1536] (XGA)

@item SV
StandortVerteiler (cable, EN 50 173)

@item SVA
Shared Virtual Area

@item SVABI
System V Application Binary Interface (Unix, AT&T, SCD)

@item SVC
SuperVisor Call (IBM, VM, VM/ESA)

@item SVC
Switched Virtual Call / Circuit (IBM, X.25)

@item SVC
Switched Virtual Circuit / Channel / Connection (ATM, PVC)

@item SVCD
Super Video Compact Disk (CD)

@item SVCI
Switched Virtual Circuit Identifier (SVC, ATM)

@item SVD
Schweizerische Vereinigung fuer Datenverarbeitung (org., Switzerland)

@item SVD
Simultaneous Voice/Data

@item SVD
Supplementary Volume Descriptor (CD, IS 9660)

@item SVE
Simple Virtual Environment

@item SVFS
System V File System (Unix)

@item SVG
Scalable Vector Graphics [format] (W3C, XML)

@item SVGA
Super Video Graphics Array [800x600] (VGA)

@item SVID
System V Interface Definition (Unix, AT&T, SCD)

@item SVIP
Secure Voice Improvement Program

@item SVK
Self Voicing Kit (IBM, Java)

@item SVM
Support Vector Machine [concept] (AI, KI)

@item SVMT
System Virtual Memory Table (BS2000)

@item SVP
SerVice Provider (ETSI, ETSI 201 671), "SvP"

@item SVPC
Single Variable Per Constraint

@item SVPMI
Super VGA Protected Mode Interface (VESA)

@item SVQ
Sorenson Video Quality (video, CODEC)

@item SVR3
System V Release 3 (Unix, OS, AT&T)

@item SVR4
System V Release 4 (Unix, OS, AT&T)

@item SVS
Single Virtual Space (IBM, OS, OS/SVS)

@item SW
Semantic Web (WWW)

@item SWAN
Secure WAN (RSA), "S/WAN"

@item SWAN
Sun Wide Area Network (Sun, WAN)

@item SWAP
Shared Wireless Application Protocol (HomeRF Association, WAP, WLAN)

@item SWAP
Simple Workflow Access Protocol

@item SWEDAC
[Staatliches Amt fuer Technische Akkreditierung] (Sweden, org.)

@item SWF
Small Web Format (Macromedia, Flash)

@item SWI
SoftWare Interrupts (RISC, OS)

@item SWICO
Schweizerischer Wirtschaftsverband der Informations-, Communikations- und Organisationstechnik (org., Switzerland)

@item SWIFT
Society for Worldwide Interbank Financial Telecommunication (org., banking)

@item SWIM
Someone Who Isn't Me (slang, Usenet, IRC)

@item SWIM
Super Woz' Integrated Machine

@item SWISH
Simple Web Indexing System for Humans (WAIS, WWW)

@item SWT
Standard Widget Toolkit (Eclipse, GUI, WTP)

@item SXGA
Super eXtended Graphics Adapter / Array [1280x1024]

@item SXU
Synergistic eXecution Unit (IBM, Cell, SPU)

@item SXVGA
Super eXtended VGA [1280x960] (VGA)

@item SYMM
SYnchronized MultiMedia working group (WAI)

@item SYSAD
SYStem ADministrator, "SysAd" 

@item SYSEX
SYStem EXecutive (OS, IBM, S/360)

@item SYSOP
SYStem OPerator (BBS), "SysOp" 

@end table

