@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item M2C
Model To Code (M2M, MDSD)

@item M2M
Machine To Machine [protocol]

@item M2M
Model To Model (M2C, MDSD)

@item MAC
Mandatory Access Control (MLS, DAC)

@item MAC
Media Access Control (ISO, OSI, LAN, , WLAN, ...)

@item MAC
Membership Advisory Committee (ICANN)

@item MAC
Message Authentication Code (SSL, SRT, cryptography)

@item MACH
Multilayer ACtuator Head

@item MACID
Media Access Control IDentifier, "MAC-ID"

@item MACOS
MACintosh Operating System (Apple, OS), "MacOS"

@item MACS
Manufacturing Application Control System (SNI)

@item MACS
MODEM Access Control System (MODEM, DES, cryptography), "M.A.C.S."

@item MACSBUG
Motorola Advanced Computer Symbolic deBUGger (Motorola)

@item MAD
Memory Address Driver strength (BIOS)

@item MAD
Message Address Directory

@item MAD
Militaerischer AbschirmDienst (mil., org.)

@item MADCAP
Multicast Address Dynamic Client Allocation Protocol (RFC 2730, Multicast)

@item MADE
Multimedia Application Development Environment (CWI)

@item MADK
Microsoft Activex Development Kit (ActiveX, MS)

@item MADT
Multiple APIC Description Table (ACPI, APIC)

@item MAE
Macintosh Application Environment (Apple, Sun, HPUX)

@item MAE
Metropolitan Area Exchange (Internet)

@item MAEC
Malware Attribute Enumeration and Characterization

@item MAINSAIL
MAchine INdependent SAIL (SAIL)

@item MAJC
Microprocessor Architecture for Java Computing [pronounced 'magic'] (Sun, Java)

@item MAJOUR
Modular Application for JOURnals (EWS, SGML)

@item MAM
Multi Access Module

@item MAME
Multiple Arcade Machine Emulator, "M.A.M.E."

@item MAN
Metropolitan Area Network

@item MANET
Mobile Ad-hoc NETwork (Internet)

@item MAP
Maintenance Analysis Procedure (IBM)

@item MAP
Manufacturing Automation Protocol (General Motors)

@item MAP
Microsoft Academic Program (MS)

@item MAP
Mobile Application Part (MSC, GSM, mobile-systems)

@item MAP27
Mobile Access Protocol [for MPT 1327] (MPT 1327), "MAP 27"

@item MAPASE
Mobile Application Part - Application Service Elements (MAP, MSC, GSM, mobile-systems), "MAP-ASE"

@item MAPEC
Multimedia APplications in Education Conference, "MApEC"

@item MAPI
Messaging Application Program Interface (MS, WOSA, API)

@item MAPOS
Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171)

@item MAPP
Microsoft Active Protections Program (MS)

@item MAPS
Microsoft Active Protection System (MS, MSE)

@item MAPS
Multiple Airflow Pass-through Structure (Scythe), M.A.P.S.

@item MAPTOP
Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP" 

@item MAR
Microprogram Address Register (IC)

@item MAR
Microsoft Authorized Refurbisher [program] (MS)

@item MARC
MAchine Readable Cataloging [record]

@item MARID
MTA Authorization Records in DNS (MTA, DNS, SPAM, IETF, WG)

@item MAS
Multi Agent Systems (AI)

@item MAS90
Mittelstands-Anwendungs-System 90 (IBM)

@item MASC
Multicast Address-Set Claim [protocol] (RFC 2909, Multicast)

@item MASE
Message Administration Service Element

@item MASM
Microsoft ASseMbler (MS, assembler)

@item MASS
Message Authentication Signature Standards (MTA, SPAM, WG)

@item MAU
Medium Access Unit

@item MAU
Medium Attachment Unit (IEEE 802.3, Transceiver)

@item MAU
Multistation Access Unit (Token Ring, Hub)

@item MAUS
Muensters Apple User Service (BBS, network), "M.A.U.S."

@item MAW
Microsoft At Work

@item MAWI
MAterialWIrtschaft

@item MAX
MAssively parallel uniX (Cray, OS, MIMD, MPP, Unix)

@item MAX
Media Access Exchange (Ascend)

@item MAX
Multimodaler AssemblierungseXperte (VR, Uni Bielefield)

@item MB
MailBox

@item MB
MegaByte

@item MBA
Memory Bus Adapter

@item MBAG
Mercedes-Benz AktienGesellschaft (user)

@item MBC
Multi Bit Cell (IC, PCMCIA, Flash, AMD, BIT)

@item MBCMS
Mercedes-Benz-Computer-Mikrofilm-System (MBAG), "MB-CMS"

@item MBE
Molecular Beam Epitaxy (IC; MOSFET)

@item MBIT
Mega Binary digIT (BIT), "MBit"

@item MBM
Media Bandwidth Management (DSL, Zyxel)

@item MBOA
MultiBand OFDM Alliance (org., OFDM)

@item MBPS
MegaBits Per Second (BIT)

@item MBR
Master Boot Record

@item MBS
Maximum Burst Size

@item MBSA
Microsoft Baseline Security Analyzer (MS, Windows)

@item MBSA
Microsoft Business and Services Agreement (MS)

@item MBUS
Module BUS [standard] (Sun, SPARC), "MBus"

@item MCA
Micro Channel Architecture (IBM, PS/2)

@item MCA
Mission Critical Applications

@item MCA
Model Centric Architecture (Skynamics)

@item MCAD
Mechanical CAD (carCAD, CAD)

@item MCAV
Modified Constant Angular Velocity

@item MCB
Memory Control Block (DOS, TPA)

@item MCBF
Mean Cycle Between Failure

@item MCC
Manchester Code Converter

@item MCC
Manchester Computing Centre (Linux)

@item MCC
Mitteldeutsches Communication Center (Leipzig)

@item MCC
Monitor and Control Center (Bundeswehr)

@item MCC
Multichannel Communication Controller (SCC, FCC)

@item MCD
Mini Client Driver (MS, Windows NT)

@item MCD
Multimedia Cartridge Drive (Nomai)

@item MCE
Machine Check Exception (Intel, CPU)

@item MCE
Media Center Edition (MS, Windows, XP, OEM)

@item MCEB
Military Communications-Electronics Board (org., mil., USA)

@item MCERT
Mittelstand Computer Emergency Response Team Germany

@item MCF
Meta Content Framework / Format (Apple, WWW)

@item MCF
MOM Connector Framework (MS, MOM)

@item MCGA
Multi Color Graphics Adapter (IBM, PS/2)

@item MCH
Memory Controller Hub [aka Northbridge] (Intel)

@item MCI
Measurement Layer Interface (UMA)

@item MCI
Media Control Interface

@item MCI
Microwave Communications Incorporated

@item MCL
Media Communication Lab (org., Uni Boston, USA)

@item MCM
Multi Carrier Modulation

@item MCM
MultiChip Module (CPU)

@item MCN
Metropolitan Campus Network

@item MCNE
Master Certified Netware Engineer (Novell, Netware)

@item MCNS
Multimedia Cable Network System (org.)

@item MCP
Master Control Program (OS)

@item MCP
Media and Communications Processor (IC)

@item MCP
Merlin Convenience Pack (IDB, OS/2)

@item MCP
Multiple-Chip Product (Intel)

@item MCP
Multiport / Multiprotocol Communication Processor

@item MCPAS
Master Control Program/Advanced System, "MCP/AS" 

@item MCPC
Multi Channel Per Carrier

@item MCPS
Microsoft Certified Product Specialist (MS, ATEC)

@item MCR
Minimum Cell Rate (UNI, ATM, PCR, ABR)

@item MCS
Material Control System

@item MCS
Message Conversion System

@item MCS
Modulation and Coding Scheme (EGPRS, mobile-systems)

@item MCS
MultiCast Server

@item MCS
Multi-Category Security (SELinux)

@item MCS
Multichannel Communications System (Mac)

@item MCS
Multivender Customer Services (DEC)

@item MCSD
Microsoft Certified Solution Developer (MS, ATEC)

@item MCSE
Microsoft Certified System Engineer (MS, ATEC)

@item MCSMP
Message Conversion System Message Processor (MCS)

@item MCSS
Mitac Computer Security System (Mitac)

@item MCT
Microsoft Certified Trainer (MS, ATEC)

@item MCTD
Mean Cell Transfer Delay (UNI, ATM)

@item MCTS
Multiple Console Time Sharing System (OS, CAD)

@item MCU
Management & Cascade Unit (Hub)

@item MCU
Master Control Unit (Nokia, OS)

@item MCU
Micro Controller Unit (SIA, RL)

@item MCU
Multipoint Controller Unit (VoiP)

@item MCVA
Modified Constant Angular Velocity (Optical Disk)

@item MD
Make Directory (DOS, OS/2)

@item MD
Management Domain

@item MD
Mini Disk (Sony)

@item MD2
Message Digest [algorithm] 2 (RFC 1115/1319)

@item MD4
Message Digest [algorithm] 4 (RFC 1320)

@item MD5
Message Digest [algorithm] 5 (RFC 1321)

@item MDA
Mail Delivery Agent

@item MDA
Medicated Digest Authentication (HTTP)

@item MDA
Mobile Digital Assistant (T-Mobile, PDA)

@item MDA
Model Driven Architecture (CASE, OMG)

@item MDA
Monochrome Display Adapter [720x350] (IBM, PC)

@item MDAC
Microsoft Data Access Components (MS)

@item MDBMS
Multidimensional DataBase Management System (DBMS, DB)

@item MDBS
Micro Data Base System (DB)

@item MDC
Message conversion system Directory Component (MCS)

@item MDC
Meta Data Coalition

@item MDCT
Modified Discrete Cosine Transformation

@item MDD
Model Driven Design (MDS)

@item MDDB
MultiDimensional DataBase (DB)

@item MDE
Mobile DatenErfassung, "mDE"

@item MDEF
Menu DEfinition Functions (Apple, CDEF)

@item MDI
Medium Dependent Interface (ethernet)

@item MDI
Mobile Data Initiative (org., GSM, mobile-systems)

@item MDI
Multiple Document Interface (MS, Windows)

@item MDI
Multiplex Device Interface

@item MDIS
MetaData Interchange Specification

@item MDIX
Medium Dependent Interface - crossed (MDI), "MDI-X"

@item MDK
MODEM Developers Kit (MODEM, MS)

@item MDL
Microstation Development Language (CAD)

@item MDM
Master Data Management

@item MDM
MicroDiskModule

@item MDM
Mobile Device Management (CA, Unicenter)

@item MDOP
Microsoft Desktop Optimization Pack (MS, Windows)

@item MDRAM
Multibank Dynamic Random Access Memory (RAM, DRAM, IC)

@item MDRC
Manufacturing Design Rule Checker

@item MDS
Manufacturing Design System

@item MDS
Microsoft Deployment Solution (MS, Windows, Vista)

@item MDSD
Model Driven Software Development

@item MDSE
Message Delivery Service Element

@item MDSP
Mobile Device Sync Protocol (Lotus)

@item MDT
Mechanical DeskTop (SGI)

@item MDT
Message Distribution Terminal

@item MDT
Microsoft Deployment Toolkit (MS)

@item MDT
Mittlere DatenTechnik

@item MDT
Mountain Daylight Time [-0600] (TZ, MST, USA)

@item ME
Mapping Entity

@item ME
Millennium Edition (MS, Windows)

@item MEBI
MEgaBInary [(2^10)^2] (IEC)

@item MEC
Memory Expansion Card

@item MEC
Microsoft Exchange Conference (MS)

@item MEF
Managed Extensibility Framework (MS)

@item MEG
Mega Evil Grin (slang, Usenet, IRC)

@item MEGA
MessdatenErfassung und Graphische Auswertung

@item MEI
Matsushita Electronics Incorporated (manufacturer, Japan)

@item MEL
Maya Embedded Language (Maya)

@item MEMS
Micro-ElectroMechanical System

@item MERS
Most Economic Route Selection

@item MERT
Multiple Environment, Real Time (OS)

@item MES
Manufacturing Execution System

@item MES
Menue-EntwicklungsSystem (Sinix, SNI)

@item MES
Minimum European Set (UTF, ISO 10646)

@item MESA
MetaEmailSearchAgent (WWW, Internet)

@item MESCH
Multi-WAIS Engine for Searching Commercial Hosts (WAIS, WWW)

@item MESFET
MEtal Semiconductor Field Effect Transistor (IC, FET)

@item MESH
Macintosh Enhanced SCSI Hardware (Apple, SCSI)

@item MESI
Modified - Exclusive - Shared - Invalid (SMP)

@item MESN
Media Event Status Notification

@item MESZ
MittelEuropaeische SommerZeit [+0200] (TZ)

@item MET
Memory Enhancement Technology (HP), "MEt"

@item MET
Micro Exposure Tool (Intel, EuropeV)

@item MET
Middle European Time [+0100] (TZ, CET, METDST, MEZ)

@item METAL
Machine Evaluation and Translation Language (Siemens)

@item METAL
Macro Expansion Template Attribute Language (TAL, ZPT, ZOPE)

@item METDST
Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)

@item MEU
Multiformat Engine Unit (LCD, Sony)

@item MEWDE
My EMACS Web Development Environment (EMACS, WWW)

@item MEZ
MittelEuropaeische [sommer] Zeit [+0200] (TZ)

@item MF
Multi Frequency

@item MFAST
Mwave Folded Array Signal Transform [DSP] (IBM, DSP)

@item MFC
Memory Flow Controller (SPE, Cell, IBM)

@item MFC
Microsoft Foundation Classes (MS)

@item MFC
Music Feature Card (IBM, Yamaha, MIDI)

@item MFD
Multi-Functional Display (Airbus, A380)

@item MFENET
Magnetic Fusion Energy NETwork

@item MFG
Mit Freundlichen Gruessen [= best wishes]

@item MFG
Multi-Function Gateway

@item MFI
MainFrame Interactive (IBM)

@item MFII
Multi-Functional [keyboard] II (IBM)

@item MFIP
Multi-Function Interoperability Processor

@item MFKS
MultiFunktionales KonferenzSystem

@item MFLOPS
Million FLoating-point Operations Per Second (CPU)

@item MFM
Modified Frequency Modulation

@item MFP
MultiFunction Product (HP)

@item MFS
Macintosh File System (Apple)

@item MFS
Message Format Service (IBM, IMS)

@item MFS
Mobile File Sync (IBM)

@item MFS
MOSIX File System (MOSIX, DFSA)

@item MFT
Master File Table (NTFS)

@item MFT
Multiprogramming with a Fixed number of Tasks (IBM, OS, OS/MFT, OS/MVT)

@item MFV
MehrFrequenzwahlVerfahren

@item MGA
Matrox Graphics Adapter (Matrox)

@item MGA
Monochrome Graphics Adapter

@item MGCP
Media Gateway Control Protocol (VoIP, RFC 2705)

@item MGI
Multi-Function Interpreter

@item MGM
Memory Grant Manager (Informix, DB)

@item MH
Mobile Host (MHP)

@item MH
Modified Huffman (Fax)

@item MHDL
MIMIC Hardware Description Language

@item MHEG
Multimedia and Hypermedia information coding Expert Group (JTC1, ISO)

@item MHL
Mobile High-definition Link

@item MHP
[columbia] Mobile Host Protocol

@item MHP
Multimedia Home Platform (ETSI)

@item MHPCC
Maui High Performance Computing Center (org., USA)

@item MHS
Message Handling System (GOSIP, X.400, Novell, SPX, IPX)

@item MHTML
Messaging HyperText Markup Language (HTML)

@item MHTML
MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RFC 2110)

@item MI
Management Interface

@item MIA
Missing In Action (telecommunication, Usenet, IRC)

@item MIAW
Movie In A Window

@item MIB
Management Information Base (OSI, SNMP)

@item MIC
Media Interface Connector (FDDI, PMD)

@item MIC
Memory in Cassette (Seagate, EEPROM, Streamer, AIT)

@item MIC
Memory Interface Controller (IBM, Cell)

@item MIC
Message Integrity Check / Code

@item MIC
Model-Integrated Computing

@item MIC
Multiple Interface Connection (Kyocera)

@item MICA
MODEM ISDN Channel Integration (Telebit, MODEM, ISDN)

@item MICE
Modular Integrated Communications Environment

@item MICO
MICO Is CORBA (ORB, CORBA, Uni Frankfurt)

@item MID
Message IDentifier (ATM)

@item MID
Mobile Information Device

@item MID
Multiple Interface Declaration (OLSR)

@item MIDI
Musical Instruments Digital Interface (MIDI)

@item MIDL
Microsoft Interface Definition Language (NT)

@item MIDP
Mobile Information Device Profile (J2ME, Java, JSR-118)

@item MIDPEG
Mobile Information Device Profile Expert Group (Sun, AOL, Motorola, NEC, Nokia, Palm, Samsung, Sharp, ...)

@item MIF
Module Interconnection Facility (Proteus)

@item MIG
Mach Interface Generator (Mach)

@item MII
Media Independent Interface

@item MIIS
Microsoft Identity Integration Server (MS)

@item MIKEY
Multimedia Internet KEYing (cryptography, VoIP)

@item MIL
Matrox Imaging Library

@item MILNET
MILitary NETwork (USA, mil., network)

@item MILOS
Maschinelle Indizierung auf Linguistischer Grundlage fuer OPAC Systeme (OPAC)

@item MILSTAR
Military Strategic TActical Relay (mil., USA)

@item MILSTD
Military STandarD (mil., USA), "MIL-STD"

@item MIMD
Multiple Instruction [stream], Multiple Data [stream] (CPU)

@item MIME
Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)

@item MIMO
Multiple Input, Multiple Output (WLAN)

@item MIMO
Multiple Input, Multiple Output (Agere-Systems, WLAN, Bell)

@item MIMOLA
Machine Independent MicrOprogramming LAnguage (HDL)

@item MIN
Multistage Interconnection Networks

@item MINC
Multilingual Internet Names Consortium (org., Internet)

@item MINISTREL
Models for INformatIon STorage and REtrievaL (OA, BIS, ESPRIT)

@item MINT
Mint is Not TOS (Atari), "MiNT"

@item MINT
Multimedia-kommunikation aif Integrierten Netzen und Terminals

@item MINX
Multimedia Information Network eXchange

@item MIO
Memory Input/Output (Motorola)

@item MIO
Modular Input/Output [architecture] (HP)

@item MIP
Main Information Packet (CD-MRW)

@item MIP
Multimission Interactive Picture

@item MIP
Multum In Parvo (3D, SAT)

@item MIPS
Microprocessor without Interlocked Piped Stages

@item MIPS
Million Instructions Per Second (CPU)

@item MIR
Maximum Information Rate

@item MIR
Micro-Instruction Register (IC)

@item MIS
Management Information System

@item MIS
Mega Iterations per Second

@item MIS
Micro Instruction Sequencer (Intel, CPU)

@item MIS
Mounting Interface Standard (VESA)

@item MISD
Multiple Instruction [stream], Single Data [stream] (CPU)

@item MISO
Multiple Input, Single Output (WLAN)

@item MISRA
Motor Industry Software Reliability Association (UK)

@item MISS
Mecklenburg Internet Service System (ISP)

@item MISSI
Multilevel Information System Security Initiative (org.)

@item MISX
Metered Services Information eXchange (Internet)

@item MIT
Management Information Tree

@item MIT
Massachusetts Institute of Technology (org., USA)

@item MIT
Mobile Internet Toolkit (MS, .NET)

@item MITM
Man In The Middle [[attack]]

@item MJ
Modular Jack

@item MKS
Mortice Kern Systems (manufacturer)

@item MKT
Multifunktionelles KartenTerminal (CT, ICC)

@item ML
Mail List

@item ML
Maintenance Lead (JCP)

@item ML
Meta Language

@item ML2
MaskLess Lithography

@item MLA
Mail List Agent

@item MLA
Micro Lens Array

@item MLC
Multi Level Cell (IC, PCMCIA, Flash, Intel, SLC)

@item MLD
Multicast Listener Discovery [protocol] (IPV6, Multicast, RFC 2710)

@item MLE
MultiLine Entry field (IBM, OS/2)

@item MLI
Measurement Layer Interface (UMA)

@item MLI
Multiple Link Interface (ODI)

@item MLIA
[symposium on] Machine Learning in Information Access (AAAI, AI, conference)

@item MLID
Multiple Link Interface Driver (ODI, LAN)

@item MLM
Mailing List Manager [software]

@item MLMA
Multi-Level Multi-Access (MAC)

@item MLP
Meridian Lossless Packaging (DVD, audio)

@item MLP
Mozilla Localization Project (Mozilla)

@item MLP
MultiLink Point-to-Point Protocol (PPP)

@item MLR
Multi-channel Linear Recording [technology] (Tandberg, Streamer)

@item MLS
MultiLevel Secure [operating systems / platforms] (SELinux)

@item MLT
Master Lower Tester (ISO 9646-3, TTCN)

@item MLT3
MuLTilevel-3 [encoding] (Schneider & Koch, FDDI), "MLT-3"

@item MM
Media Manager (Novell, Netware, SMS)

@item MM
Military Message (mil.)

@item MM
Mobile Management (RR, CM, GSM, mobile-systems)

@item MMA
Microcomputer Managers Association (org., USA)

@item MMA
MIDI Manufacturer Association (org., IMA)

@item MMAPI
Mobile Media API (Java, Sun, JMF, API, JSR-135)

@item MMC
Microsoft Management Console (MS, Windows NT, XP)

@item MMC
MIDI Machine Control

@item MMC
MultiMedia Commands (SAM)

@item MMC
MultiMediaCard

@item MMCA
MultiMediaCard Association (org.)

@item MMCD
MultiMedia Compact Disk (Sony, Philips, CD)

@item MMCDE
MultiMedia Compact Disk - Erasable (Sony, Philips, CD), "MMCD-E"

@item MMCF
MultiMedia Communications Forum (org.)

@item MMDO
Magnetic Modulation Direct Overwrite

@item MMDS
Multi-channel, Multi-point Distribution System

@item MMF
Make Money Fast (Usenet, ECP, EMP)

@item MMF
Memory Mapped File (Windows 95, Windows NT)

@item MMF
Multimode Fiberoptic cable (SMF)

@item MMFS
Manufacturing Message Format Standard (MAP)

@item MMHID
MultiMedia Human Interface Device

@item MMHS
Military Message Handling System (mil., MHS)

@item MMI
Mixed Mode Interpreter (JIT, IBM, Java)

@item MMIO
Memory Mapped I/O (I/O)

@item MML
Maker Markup Language (FrameMaker)

@item MMOG
Massive Multiplayer Online Games

@item MMORPG
Massive Multiplayer Online RolePlaying Games

@item MMP
Multilink Multichasis PPP (PPP)

@item MMPM2
MultiMedia Presentation Manager /2 (IBM, OS/2), "MMPM/2"

@item MMR
Modified Modified Read (Fax)

@item MMRSG
Mobile Multi-hop Relay Study Group (IEEE), "MMR SG"

@item MMS
Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506)

@item MMS
Maximum Message Size

@item MMS
Microsoft Media Server [protocol] (MS, Internet)

@item MMS
Module Making System (VMS)

@item MMS
Multilevel Mail Server

@item MMS
Multimedia Messaging Service (mobile-systems)

@item MMU
Mass Memory Unit

@item MMU
Memory Management Unit

@item MMVF
MultiMedia Video File [disk] (NEC, DVD)

@item MMWM
MultiMedia Window Manager (X-Windows)

@item MMX
Mobile Module PCI eXpress [specificiation] (Nvidia, PCIe)

@item MMX
MultiMedia eXtensions (Intel, CPU)

@item MNG
Multiple-image Network Graphics [format]

@item MNOS
Metal Nitride Oxide Semiconductor (IC)

@item MNP
Microcom Networking Protocol

@item MO
Machine Object (PO)

@item MO
Management Object (OSI)

@item MOB
Memory Ordering Buffer (Intel, CPU)

@item MOBA
Multiplayer Online Battle Arena (ARTS, RTS)

@item MOCS
Microsoft Official Curriculum Seminar (MS, ATEC, MCSD)

@item MOD
Magneto-Optical Disk (OD)

@item MODACOM
MObile DAta COMmunication

@item MODCA
Mixed Object Document Content Architecture (IBM), "MO:DCA"

@item MODEM
MOdulator DEModulator

@item MOE
Measure of Effectiveness

@item MOES
Molekulare Optisch-Elektrische Schaltungstraeger

@item MOESI
Modified - Owned - Exclusive - Shared - Invalid (AMD)

@item MOF
Managed Object Format (CIM, DMTF)

@item MOF
Meta Object Facility (OMG, UML)

@item MOF
Microsoft Operations Framework (MS)

@item MOLAP
Multidimensional OnLine Analytical Processing (OLAP)

@item MOLED
Molecule Organic Light Emitting Display (OLED)

@item MOLI
Microsoft OnLine Institute (MS)

@item MOLP
Microsoft Open Licence Pack (MS)

@item MOM
Message Orientated Middleware (IBM)

@item MOM
Microsoft Operations Manager (MS, SMS)

@item MONALISA
MOdelling NAturaL Images for Synthesis and Animation, "MONA LISA"

@item MONET
high data rate MObile interNET (network)

@item MOO
MUD Object Orientated (Internet, OOP, MUD)

@item MOOC
Massive Open Online Course (Internet)

@item MOP
Maintenance Operations Protocol (DEC)

@item MOP
Meta Object Protocol (CLOS)

@item MOP
Multiple Original Prints

@item MOPRIA
MObile PRinting Alliance (org., Canon, HP, Samsung, Xerox)

@item MOPS
Million Operations Per Second

@item MOR
Mining Object Repository (OP, Oracle, DB)

@item MOS
Master Operating System (OS, Varian)

@item MOS
Metal Oxide Semiconductor (IC)

@item MOS
Minimum Operating System (OS, UNIVAC 9200, UNIVAC 9300)

@item MOS
Multiprogramming Operating System (OS, NCR)

@item MOSA
Microsoft Online Subscription Agreement (MS)

@item MOSES
Major Open Systems Environment Standards

@item MOSFET
Metal Oxide Semiconductor Field Effect Transistor (IC, FET)

@item MOSIX
Multicomputer Operating System for UnIX (Unix, Cluster, MOSIX)

@item MOSP
Microsoft Online Services Partnership (MSN)

@item MOSPF
Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584)

@item MOSRO
MObiles-Sicherheits-ROboter-System

@item MOST
Media Orientated Systems Transport

@item MOST
Mobile Open Systems Technologies (UK, Uni Lancaster)

@item MOT
Means of Test

@item MOTIS
Message-Orientated Text Interchange System (ISO 10021, JTC1)

@item MOTSS
More Of The Sameold Sameold (Usenet)

@item MOU
Memorandum Of Understanding (IPOC, TLD, Internet)

@item MOUS
Microsoft Office User Specialist (MS, Windows)

@item MOVE
Microsoft Overlay Virtual Environment (MS)

@item MOVI
[projekt] MObile VIsualisierung (DFG)

@item MOWORM
Magneto-Optical Write Once Read Many, "MO-WORM" 

@item MP
[PPP] Multilink Protocol (MPPP, RFC 1990)

@item MP
Management Pack (MS, MOM)

@item MP
MegaPIXEL (PIXEL, photo)

@item MP
Multi Processor

@item MP
MultiProtocol

@item MP3
MPEG audio layer 3 (MPEG, audio, IIS, ISO)

@item MPC
Modular Port Concentrator

@item MPC
MPOA Client (MPOA, ATM)

@item MPC
Multimedia Personal Computer

@item MPD
Message Preparation Directory

@item MPDA
MultiPlatform DiskArray

@item MPDU
Message Protocol Data Unit (PDU)

@item MPE
Multi Protocol Encapsulation (DVB)

@item MPE
Multi-Programming Executive (OS, HP, HP 3000)

@item MPEG
Motion Picture Expert Group [old term] (MPEG)

@item MPEG
Moving Picture Expert Group (org., ISO 11172-1, JTC1)

@item MPEGTS
Moving Picture Expert Group - Transport Stream (MPEG, TS), MPEG-TS

@item MPEV
Multiple Programming Executive/V (HP), "MPE/V"

@item MPEXL
Multiple Programming Executive/XL (HP), "MPE/XL"

@item MPF1
MikroProFessor 1, "MPF 1"

@item MPI
Message Passing Interface (SMP, Cluster)

@item MPI
Multiprocessor Interconnect Bus

@item MPIF
Message Passing Interface Forum (manufacturer)

@item MPL
Mozilla Public License (Netscape)

@item MPLS
Multi-Protocol Label Switching (RFC 3031)

@item MPM
Metra Potential Method

@item MPM
Multi Processing Modul (Apache)

@item MPM
Multi-user ??? Program for Microcomputers (CP/M, OS, DR), "MP/M"

@item MPM2
MultiMedia Presentation Manager/2 (OS/2, IBM), "MPM/2"

@item MPML
Main Profile @@ Main Level (MPEG), "MP@@ML"

@item MPNET
Multi-user ??? Program / NETwork (MP/M, CP/NET, OS), "MP/NET"

@item MPNOS
Multi-user ??? Program / ??? (MP/NET, CP/NOS, OS), "MP/NOS"

@item MPOA
Multi-Protocol Over ATM (ATM)

@item MPOW
Multiple Purpose Operator Workstation

@item MPP
Massive Parallel Processor / Processing (MPP)

@item MPP
Message Posting Protocol (RFC 1204)

@item MPP
Message Processing Program

@item MPPC
Microsoft Point-to-Point Compression (MS, RFC 2118)

@item MPPD
Multi Purpose Peripheral Device

@item MPPE
Microsoft Point to Point Encryption (MS, cryptography, RFC 3078)

@item MPPP
Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)

@item MPR
Maet- och Provningsradet [National Board for Measurement and Testing] (org., Sweden, SWEDAC)

@item MPR
MultiPoint Relay (OLSR)

@item MPS
Megabytes Per Second

@item MPS
MPOA Server (MPOA, ATM)

@item MPS
Multi Processor Specification (BIOS, HT, MS, Windows)

@item MPS
MultiPage Signal (Fax)

@item MPS
MultiProcessor Specification (SMP, Intel)

@item MPSA
Microsoft Products and Services Agreement (MS)

@item MPSX
Mathematical Programming System eXtended (IBM)

@item MPT
Memory Performance Technology (BIOS, MSI)

@item MPT
Ministery of Post and Telecommunications (org., Japan)

@item MPT
MultiPort Transceiver

@item MPT1327
[British] Ministry of Post and Telecommunications [standard] 1327

@item MPTA
Multi Protocol Transport Architecture (IBM, SNA)

@item MPTCP
MultiPath TCP (TCP)

@item MPTN
Multi Protocol Transport Networking (IBM)

@item MPTS
Multi Protocol Transport Services (IBM, MPTN)

@item MPTS2
Multi Protocol Transport Services / 2 (IBM, OS/2), "MPTN/2" 

@item MPU
MicroProcessor Unit (SIA, RL)

@item MPU401
MIDI Processing Unit 401 (Roland, MIDI), "MPU 401"

@item MPW
Macintosh Programmers Workshop (Apple)

@item MPX
MultiProgramming eXecutive (IBM, OS, IBM 1800)

@item MPX
MultiProgramming eXecutive (OS)

@item MQI
Message Queueing Interface (IBM)

@item MQUIPS
Million QUality Improvements Per Second

@item MR
Magneto - Resistive (HDD)

@item MR
MODEM Ready (MODEM)

@item MR
Modified Read (Fax)

@item MRA
Multi Resolutions Analysis

@item MRAM
Magnetoresistive Random Access Memory (IC, RAM)

@item MRB
Method Request Broker (OMG)

@item MRBC
Multiple Resolution Bitmap Compiler (MS, Windows)

@item MRC
MOSIX Research the Clouds (MOSIX)

@item MRCF
Microsoft Realtime Compression Format (MS)

@item MRCI
Microsoft Realtime Compression Interface (MS)

@item MRCS
Multi-Rate Circuit Switching

@item MRH
Memory Repeater Hub (Intel)

@item MRIB
Multicast RPF Routing Information Base (RPF, Multicast, PIM, MSDP)

@item MRJ
Macintosh / MacOS Runtime for Java (Java, Apple)

@item MRJSDK
Macintosh Runtime for Java Software Developer Kit (Apple, Java), "MRJ SDK"

@item MRM
Multi Resolution Meshes (Intel, 3D)

@item MRML
Multimedia Retrieval Markup Language (Multimedia, Internet, XML)

@item MRNET
Minnesota Regional NETwork (network, USA)

@item MRO
Mandatory Router Option [flag] (CATNIP)

@item MROC
Multicommand Required Operational Capability

@item MROM
Macrocode Mask Read Only Memory (ROM)

@item MROM
Mask Read Only Memory (ROM)

@item MROMB
Modular RAID On MotherBoard (Intel, RAID, ZCR), "MRO MB"

@item MRP
Material / Manufacturing Resource Planning

@item MRP
Material Requirement Planning (PPS, CIM)

@item MRS
Media Recognition System (DAT)

@item MRSE
Message Retrieval Service Element

@item MRTD
Machine Readable Travel Document(s)

@item MRTG
Multi Router Traffic Grapher

@item MRU
Maximum Receive Unit [size] (SLIP, PPP)

@item MRU
Most Recently Used

@item MRX
MagnetoResistive eXtended [technology] (HDD)

@item MS
Memory Stick

@item MS
Message Store

@item MS
Meta Signaling (ATM, ???)

@item MS
MicroSoft (manufacturer, MS)

@item MS
Mobile Station (GSM, mobile-systems)

@item MSA
Management Service Architecture

@item MSA
MicroService Architecture (SOA)

@item MSA
MultiSource Assignment

@item MSAP
Management Service Access Point (OSI, OSI/RM, SAP)

@item MSAP
Mini Slotted Alternating Priorities (MAC)

@item MSATA
Mini Serial Advanced Technology Attachment (SATA), "mSATA"

@item MSB
Most Significant Bit (BIT)

@item MSBA
Microsoft Baseline Security Analyzer (MS)

@item MSC
MicroSoft C

@item MSC
Mobile services Switching Center (PLMN, GSM, GPRS, mobile-systems)

@item MSCDEX
MicroSoft Compact Disk EXtensions (CD)

@item MSCHAP
MicroSoft Challenge Handshake Authentication Protocol (MS), "MS-CHAP"

@item MSCM
Multiple Slots on Continuation Mechanism (DQDB)

@item MSCP
Mass Storage Control Protocol

@item MSCS
MicroSoft Cluster Server [Wolfpack] (MS, Cluster)

@item MSCT
Microsoft Shared Computer Toolkit (MS)

@item MSD
Most Significant Digit

@item MSDE
MicroSoft Data Engine (MS, DB)

@item MSDE
Microsoft SQL server Desktop Engine / Environment (MS, SQL)

@item MSDL
MicroSoft Download Library (MS)

@item MSDN
Macintosh Software Distribution Network (FidoNet, Apple)

@item MSDN
MicroSoft Developer Network (MS)

@item MSDNAA
MicroSoft Developer Network Academic Alliance (MS)

@item MSDOS
MicroSoft Disk Operating System (MS, OS, PC)

@item MSDP
Multicast Source Discovery Protocol (Internet, PIM-SM, Multicast, RFC 3618)

@item MSE
Mean Squared Error

@item MSE
MicroSoft Exchange server (MS)

@item MSE
Microsoft Security Essentials (MS)

@item MSE
Multimedia Software Engineering (Multimedia)

@item MSEN
Media Status Event Notification

@item MSFIS
MicroSoft Fax Information Service (MS)

@item MSFP
Management Service Focal Point (IBM)

@item MSFTEU
Maximum Surprise For The End User (slang, Cygwin)

@item MSH
Microsoft SHell (MS)

@item MSI
Medium Scale Integration

@item MSI
MicroSoft Installer (MS, WIndows)

@item MSI
Micro-Star International (manufacturer, Taiwan)

@item MSIE
MicroSoft Internet Explorer (MS, WWW, MSIE)

@item MSIL
MicroSoft Intermediate Language (MS, .NET, CLI)

@item MSISDN
Mobile Station ISDN Number (PLMN, GSM, mobile-systems), "MS-ISDN"

@item MSIX
Metered Services Information eXchange [protocol] (Internet, ISP)

@item MSJVM
MicroSoft Java Virtual Machine (MS, Java)

@item MSL
Maximum Segment Lifetime (TCP/IP)

@item MSL
Microsoft Software Library (Internet, MS)

@item MSL
Mirrored Server Link

@item MSM
Media Support Module (ODI)

@item MSM
Metal Semiconductor Metal (IC)

@item MSMQ
MicroSoft Message Queue [server / services] (MS)

@item MSN
Microsoft Support Network (Internet, MS)

@item MSN
Monitoring cell Sequence Number (UNI, ATM)

@item MSN
Multiple Subscriber Number (Euro-, ISDN)

@item MSNF
Multiple Systems Networking Facility (IBM)

@item MSOS
Mass storage Operating System (OS, CDC)

@item MSP
Media Signal Processor (Samsung, MMX, ARM)

@item MSP
Message Security Protocol

@item MSP
Message Send Protocol (RFC 1159)

@item MSP
Multitasking System Program (OS, Hemenway)

@item MSP7
Modular System Program /7 (OS, IBM), "MSP/7"

@item MSPI
M&T Software Partner International [gmbh]

@item MSPL
MicroSoft Public License (MS, Ms-RL), "Ms-PL"

@item MSR
Machine Specific Register (IC)

@item MSR
Mess-, Steuer- und Regelungssysteme

@item MSR
Mobile Support Router (MHP)

@item MSR
Model Specific Register (Intel, Pentium, IC)

@item MSRL
MicroSoft Reciprocal License (MS, Ms-PL), "Ms-RL"

@item MSRN
Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM, mobile-systems)

@item MSRPC
MicroSoft Remote Procedure Call (MS, DCOM), "MS-RPC"

@item MSRT
Malicious Software Removal Tool (MS)

@item MSS
Maximum Segment Size (TCP, ADSL)

@item MSS
Microsoft Speech Server (MS)

@item MSS
MIMOLA Software System (MIMOLA)

@item MSS
Mobile Synchronisation Services (mobile-systems)

@item MSSE
Message Submission Service Element

@item MST
Mountain Standard Time [-0700] (TZ, MDT, USA)

@item MSTP
Multiple Spanning Tree Protocol (STP, VLAN, IEEE 802.1s)

@item MSTSC
MicroSoft Terminal Services Client (MS)

@item MSU
Millions of Service Unit (IBM, TC)

@item MSVC
Meta-Signaling Virtual Channel (ATM)

@item MSVC
MicroSoft Visual C++ (MS)

@item MSW
Machine Status Word

@item MSXML
Microsoft XML core services (MS, COM, XML,)

@item MT
Machine [assisted] Translation

@item MT
Mannesmann Tally [gmbh] (manufacturer)

@item MT
Message Transfer / Type

@item MT
Mobile Termination (GSM, mobile-systems)

@item MT
Moluccas Time [+0830] (TZ)

@item MTA
Mail Transport Agent (SMTP)

@item MTA
Main Table Area (CD-MRW)

@item MTA
Message Transfer Agent (MTS, OSI, X.400)

@item MTBF
Mean Time Between Failure (HDD, ...)

@item MTBRP
Mean-Time-Between-Parts-Replacement

@item MTC
Master Test Component (ISO 9646-3, TTCN)

@item MTC
MIDI Time Code (MIDI)

@item MTD
Memory Technology Driver (IBM, PC-DOS)

@item MTDA
Mean Time Data Availability

@item MTDS
Magnetic Tape Operating System (OS)

@item MTE
MuTating Engine (Viren), "MtE"

@item MTEC
Motorola Training and Education Center (org., Chicago)

@item MTF
Message Text Formats

@item MTF
Microsoft Tape Format (MS)

@item MTF
Modulation Transfer Function

@item MTH
Memory Translator Hub (Intel)

@item MTI
MIPS Technologies Inc. (manufacturer, SGI)

@item MTJ
Magnetic Tunnel Junction (MRAM)

@item MTOS
Magnetic Tape Operating System (OS, Datapoint)

@item MTP
Media Transfer Protocol (Windows, MCE)

@item MTP
Memory Translation and Protection (Infiniband)

@item MTP
Message Transfer Part (ISDN, GSM, mobile-systems)

@item MTR
Mining Table Repository (OP, Oracle, DB)

@item MTRJ
Mechanical Transfer Registered Jack

@item MTRR
Memory Type Range Register (CPU, Pentium Pro, IC)

@item MTS
Magnetic Tape System (OS, HP, HP 2100)

@item MTS
Message Transfer System (MHS)

@item MTS
Michigan Terminal System (OS)

@item MTS
Microsoft Transaction Server (MS, DB, WSH, COM)

@item MTT
MailTrusT (cryptography)

@item MTTF
Mean Time To Failure

@item MTTFF
Mean Time To First Failure

@item MTTR
Mean Time to Recovery / Repair / React

@item MTTR
Mean Time Trouble Repair

@item MTU
Maximum Transmission Unit (SLIP, PPP, IP, PPPoE)

@item MTU
Message Transfer Unit

@item MUA
Mail User Agent

@item MUBIS
MUltimediales BueroInformationsSystem (OA, BIS, TU Braunschweig), "MuBIS"c

@item MUCK
Multi-User Chat Kingdom (MUD)

@item MUD
Multi-User Dungeon (MUD)

@item MUGD
MUMPS User Group Deutschland (MUMPS, user group, Org), "MUG-D"

@item MUI
Management User Interface (OMF, UI)

@item MUI
Multimedia User Interface (SGI, UI)

@item MULDEM
MULtiplexer-DEMultiplexer

@item MULE
MULtilingual Enhancement of GNU EMACS (EMACS, GNU)

@item MULTICS
MULTiplexed Information and Computing Service (OS, MIT, Bell)

@item MULTOS
MULtimedia Office Server (OA, BIS, ESPRIT)

@item MUMPS
Massachusetts general hospital Utility Multi-Programming System

@item MUMPS
Multi-User Multi-Programming System ??? (OS, DEC)

@item MUMPS
MUMPS Development Committee (org., MUMPS)

@item MUPAD
Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD"

@item MUSH
Multi-User Shared Hallucination (MUD)

@item MUSICAM
Masking-pattern adapted Universal Subband Integrated Coding And Multiplexing (MPEG, Digital audio)

@item MUT
Master Upper Tester (ISO 9646-3, TTCN)

@item MUTIOI
???, "MuTIOI"

@item MUTOS
MultiUser-/multitasking Operating System (GDR, OS)

@item MUEW
eW MonopolUEbertragungsWeg, "MueW"

@item MUX
MUltipleXer

@item MVA
Multi Vendor Architecture

@item MVA
Multidomain Vertical Alignment [technology] (LCD, Fujitsu)

@item MVC
Model View Controller (Smalltalk, GUI)

@item MVC
Multi-View-CODEC (Blu-ray, 3D)

@item MVCC
MultiVersion Concurrency Control [system] (PostgeSQL, DB)

@item MVI
Motion Video Instructions (DEC, CPU, Alpha)

@item MVIF
Multi-Vendor Interacting Forum (org., IN)

@item MVP
Most Valuable Professional [bonus program] (MS)

@item MVRCA
Magnalink Variable Resource Compression Algorithm (PPP, RFC 1975)

@item MVS
Multiple Virtual Storage (IBM, OS, OS/MVS)

@item MVS
Multiple Virtual System (OS)

@item MVSESA
Multiple Virtual Storage/Extended System Architecture (IBM), "MVS/ESA"

@item MVSESASP
Multiple Virtual Storage/Extended System Architecture System Product (IBM), "MVS/ESA SP"

@item MVSSP
Multiple Virtual Storage/System Product, "MVS/SP" 

@item MVSTSO
Multiple Virtual Storage/Time Sharing Option (IBM), "MVS/TSO"

@item MVSXA
Multiple Virtual Storage/eXtended Architecture, "MVS/XA" 

@item MVT
Multiprogramming with a Variable number of Tasks (IBM, OS/MVT, OS)

@item MWC
Mobile World Congress (mobile-systems, conference)

@item MWCM
Molecular Wire Crossbar Memory (RAM, IC, HP)

@item MWI
Media Wearout Indicator (SSD)

@item MWS
Management WorkStation

@item MWS
Matsushita White Skipping (Fax)

@item MX
Mail eXchange (Unix)

@item MXB
Multimedia eXension Board (SNI)

@item MXC
Multimedia eXtension Connector

@item MXM
Mobile PCI eXpress Module (Nvidia, PCI)

@item MXML
Macromedia Flex Markup Language (Macromedia, XML)

@item MYDP
MobilitY DisplayPort, "MyDP"

@item MZ
Mark Zbikowski (MS-DOS, MCB)

@item MZAP
Multicast-scope Zone Announcement Protocol (RFC 2776, Multicast)

@end table

