@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item T1
[digital] Transmission link 1 [1.544 Mbit/s] (DS1, BIT)

@item T2
[digital] Transmission link 2 [6.312 Mbps] (DS2)

@item T3
[digital] Transmission link 3 [44.736 Mbps] (DS3)

@item T4
[digital] Transmission link 4 [274.176 Mbps] (DS4)

@item TA
TerminalAdapter (ISDN)

@item TA
Transmitter Address (FPK)

@item TAAI
Taiwanese Association for Artificial Intelligence (org., Taiwan, AI)

@item TAC
Technical Assistance Center (Cisco)

@item TAC
Technology Access Center (Rogue-Wave)

@item TAC
Terminal Access Circuit

@item TAC
Terminal Access Controller (ARPANET, MILNET)

@item TAC
Type Approval Code (IMEI, GSM, mobile-systems)

@item TACACS
Terminal Access Controller Access Control System (RFC 1492)

@item TACS
Total Access Communication Service (mobile-systems)

@item TACTIS
Thai API Consortium / Thai Industrial Standard [codeset] (API, TIS)

@item TADI
Time Assigned Data Interpolation

@item TADIL
TActical Digital Information Link (mil.)

@item TADS
Test and Debug System

@item TAE
Telekommunikations-AnschlussEinheit (DTAG)

@item TAF
Terminal Access Facility

@item TAFIM
Technical Architecture Framework for Information Management (JIEO, mil.)

@item TAG
Technical Advisory Group (PIMA, I3C)

@item TAG
Technical Architecture Group (W3C)

@item TAIS
Technisch-Administratives InformationsSystem

@item TAIS
Toshiba America Information Systems [inc] (manufacturer, USA, Toshiba)

@item TAL
TeilnehmerAnschlussLeitung telecommunication, Germany

@item TAL
Template Attribute Language (XHTML, ZPT, ZOPE)

@item TALAE
TALigent Application Program (Taligent), "TalAE"

@item TALDE
TALigent Development Environment (Taligent), "TalDE"

@item TALES
Template Attribute Language Expression Syntax (TAL, METAL, ZOPE)

@item TALISMAN
Tracing Authors' rights by Labelling Image Services and Monitoring Access Network [project] (Europe)

@item TALOS
TALigent Object Services (Taligent), "TalOS"

@item TAMINO
Transaction Architecture for Managing InterNet Objects (DBMS, DB, Internet)

@item TAN
Table / Total Area Network

@item TAN
TransAction Number (banking)

@item TANJ
There Ain't No Justice (slang, Usenet, IRC)

@item TANSTAAFL
There Ain't No Such Thing As A Free Lunch (slang, Usenet)

@item TAO
Topics, Associations, Occurrences (XTM)

@item TAO
Track At Once (CD-R)

@item TAP
Telocator Alphanumeric input Protocol (SNPP, PCIA, SMS, USA)

@item TAP
Terminal Access Point (cable)

@item TAP
Test Access Port (IC, IEEE 1149.1, JTAG)

@item TAP
The Ada Project

@item TAP
Topfield Application Program

@item TAP
Transport und Archivierung Produktdefinierender daten (org., DIN, STEP, CIM)

@item TAPI
Telephony Application Program Interface (Intel, MS, WOSA, CTI)

@item TAR
Tape ARchiver (Unix)

@item TARGET
Thrustmaster Advanced pRogramming Graphical EdiTor, T.A.R.G.E.T

@item TAS
Tag Abuse Syndrome (SGML, HTML, slang)

@item TASE
Telecontrol Application Service Element (ICCP)

@item TASI
Time-Assigned Speech Interpolation

@item TASM
Turbo ASseMbler (Borland, assembler)

@item TAT
Theoretical Arrival Time (GCRA)

@item TAUCIS
Technikfolgenabschaetzung - Ubiquitaeres Computing und Informationelle Selbstbestimmung (BMBF)

@item TAXII
Trusted Automated eXchange of Indicator Information

@item TB
Tabular Bayes' [algorithm]

@item TB
TeraByte

@item TB
Transparent Bridging

@item TBB
Trusted Building Block (TCPA)

@item TBC
Time Base Corrector (video)

@item TBCP
Tagged Binary Control Protocol (Adobe, PS)

@item TBI
Total Business Integration [system]

@item TBR
Technical Basis for Regulations (ISDN)

@item TBRPF
Topology dissemination Based on Reverse-Path Forwarding (RFC 3684)

@item TBS
Turn Based Strategy [game] (RTS)

@item TBW
TeraBytes Written

@item TC
Task Committee (IFIP)

@item TC
Technical Committee (ISO, OASIS, ...)

@item TC
Temporary Capacity (IBM)

@item TC
Terminal Computer

@item TC
Terminal Controller

@item TC
Thin Client

@item TC
Topology Control [message] (OLSR)

@item TC
Transaction Capabilities

@item TC
Transfer Control

@item TC
Transmission Control

@item TC
Transmission Convergence

@item TC
Trust Center (cryptography)

@item TC
TurboCache (graphics)

@item TCA
information technology & TeleCommunications Association (org.)

@item TCA
Taipei Computer Association (org., Taiwan)

@item TCA
Target Channel Adapter (Infiniband)

@item TCA
Typo3 Configuration Array

@item TCAF
Thin Client Application Framework (Java, LDAP, IBM)

@item TCAM
TeleCommunications Access Method (IBM, telecommunication)

@item TCAM
Ternary Content Addressable Memory (CAM)

@item TCAP
Transaction Capabilities Applications Part (MSC, GSM, IN, mobile-systems)

@item TCB
Task Control Block (BS2000)

@item TCB
Trusted Computing Base (MS, Palladium)

@item TCC
Telecommunications Center

@item TCE
Typo3 Core Engine (Typo3)

@item TCF
Thin Client Framework (IBM, Java)

@item TCF
Transparent Computing Facility

@item TCFS
Transparent Cryptographic FileSystem (Linux, cryptography)

@item TCG
Trusted Computing Group (org., DRM, AMD, HP, IBM, Intel, MS, ...)

@item TCH
Traffic CHannel (GSM, mobile-systems)

@item TCI
Test Cell Input (UNI, ATM)

@item TCK
Technology Compatibility Kit (JCP, Java, Sun)

@item TCK
Test ClocK (TAP, IC)

@item TCL
Tool Command Language

@item TCLTK
Tool Command Language/ToolKit (TCL, X-Windows), "TCL/TK"

@item TCM
Thermal Conduction Module

@item TCM
Time Compression Multiplexer

@item TCM
Trellis Coded Modulation

@item TCNS
Thomas Conrad Network System (LAN)

@item TCO
Test Cell Output (UNI, ATM)

@item TCO
Tjaenstemaennens CentralOrganisation (Sweden, org.)

@item TCO
Total Cost of Ownership

@item TCOS
Telesec Chipcard Operating System (OS)

@item TCP
Tape Carrier Package (CPU)

@item TCP
Test Coordination Procedure

@item TCP
Transmission Control Protocol (ARPANET)

@item TCPA
Trusted Computing Platform Alliance (org., cryptography, DRM, TCPA)

@item TCPACO
TCP Alternate Checksum Option (RFC 1146, TCP), "TCP-ACO"

@item TCPBEUI
Transmission Control Protocol BIOS Extended User Interface (NETBIOS, TCP, UI)

@item TCPC
The Clean Personal Computer group (org., manufacturer, Grafikkarten)

@item TCPIP
Transmission Control Protocol/Internet Protocol (RFC 793, IP), "TCP/IP"

@item TCPLDP
TCP extensions for Long Delay Paths (RFC 1072, TCP)

@item TCQ
Tagged Command Queueing (Linux, SCSI)

@item TCRTP
Tunneling multiplexed Compressed Real Time Protocol (RTP, RFC 4170)

@item TCS
Transmission Convergence Sublayer (ATM)

@item TCSEC
Trusted Computer System Evaluation Criteria (Orange Book, NCSC, USA)

@item TCSH
Trustedi C SHell (Unix, Shell)

@item TCU
Tape Control Unit

@item TCU
Timing Control Unit

@item TCU
Transmission Control Unit

@item TD
Transmit Data (MODEM)

@item TDA
TestDatenAuswerter (IC)

@item TDB
Task DataBase

@item TDB
Track Descriptor Block (UDF, CD-R)

@item TDC
Tape Data Controller

@item TDC
Terrestrial Data Circuit

@item TDCC
Transportation Data Coordinating Committee (org., USA)

@item TDD
Telecommunications Device for Deaf

@item TDD
Test Driven Development

@item TDD
Time Division Duplex (mobile-systems)

@item TDDSG
TeldeDienstDatenSchutzGesetz telecommunication, IUKDG, Germany

@item TDED
Trade Data Elements Directory (ISO 7372)

@item TDF
Title Definition Format (DVD)

@item TDG
TeleDienstGesetz telecommunication, IUKDG, Germany

@item TDI
Test Data Input (TAP, IC)

@item TDI
Trusted Database Interpretation (DB)

@item TDJ
Transfer Delay Jitter

@item TDL
Trusted Device List (DCI)

@item TDM
Telekom Designed Networks (DTAG)

@item TDM
Time Division Multiplexing

@item TDMA
Time Division Multiple Access (mobile-systems)

@item TDMB
Terrestrial Digital Multimedia Broadcasting (DMB), "T-DMB"

@item TDMOIP
Time Division - Multiplex Over Internet Protocol (IP, DSL), "TD-MoIP"

@item TDMS
Terminal Data Management System

@item TDN
Telekom Designed Network

@item TDNN
Time Delay Neural Net (NN)

@item TDO
Test Data Output (TAP, IC)

@item TDOP
Time Dilution Of Precision (GPS)

@item TDOS
Tape and Disk Operating System (OS, RCA Spectra 70)

@item TDP
Telocator Data Protocol (PCIA, SMS, USA)

@item TDP
Thermal Design Power (CPU, ACP, SDP)

@item TDP
Triton Data Path (Intel, Triton, IC)

@item TDR
Time Domain Reflectometer (cable)

@item TDS
Tabular Data Stream [protocol] (Sybase)

@item TDSCDMA
Time Division Synchronous Code Division Multiple Access (mobile-systems, CDMA)

@item TDSL
Telekom Digital Subscriber Line (DTAG, Germany), "T-DSL"

@item TDSV
Telekommunikation-DatenSchutzVerordnung (BMWI)

@item TDT
Time and Date Table (DVB, UTC)

@item TDU
Telesoftware Data Unit (BTX)

@item TE
Terminal Endpoint (ISDN)

@item TE
Terminal Equipment

@item TE
Traffic Engineering [extension] (OSPF, RFC 3630)

@item TE
Type Enforcement [access control] (SELinux)

@item TEA
Telekommunikations-Anschluss-Einheit (DTAG)

@item TEA
Tiny Encryption Algorithm (cryptography)

@item TEAMA
Taiwanese Electric Appliance Manufacturer's Association (org., Taiwan)

@item TEBI
TEraBInary [(2^10)^4] (IEC)

@item TEC
Text Encoding Converter (Apple)

@item TEC
Trace Execution Cache (Intel, Pentium, CPU)

@item TECO
Tape / Text Editor and COrrector (MIT)

@item TEDAX
TExt DAta eXchange [protocol] (MacOS)

@item TEDIS
Trade Electronic Data Interchange Systems (EDI, Europe)

@item TEI
Text Encoding Initiative [application] (SGML)

@item TELAS
TELephony Application System (CTI, SNI)

@item TELEVAS
Telephony Value Added Services (WAP), "TeleVAS"

@item TELIS
TEileLogistik-InformationsSystem (MBAG)

@item TELNET
TELephone NETwork (Unix, Internet, RFC 854)

@item TELNETD
TELephone NETwork DAEMON (Unix, TELNET, DAEMON)

@item TEN
TransEuropean Networks (network)

@item TER
Typo3 Extension Repository (Typo3)

@item TERENA
Trans-European Research and Education Networking Association (org., Netherlands, Europe)

@item TERMCAP
TERMinal CAPability (Unix)

@item TERMINFO
TERMinal INFOrmation (Unix)

@item TES
Technology Enabled Marketing

@item TESLA
Timed Efficient Stream Loss-tolerant Authentication (RFC 4082)

@item TESS
The Exponential Security System (RFC 1824)

@item TEXEL
TEXture ELement (3D)

@item TF
Trace Flag (assembler)

@item TFCC
Task Force on Cluster Computing (IEEE, Org)

@item TFE
Thin Film Electronics (manufacturer, Norway, Sweden)

@item TFI
Terminal Facility Identifier (T-Online)

@item TFLOPS
Tera FLoating-point Operations Per Second (CPU)

@item TFM
Trusted Facility Manual

@item TFP
Tops Filing Protocol

@item TFRP
TCP Friendly Rate Control (TCP, RFC 3448)

@item TFS
Team Foundation Server (MS, ALM)

@item TFS
Translucent File System

@item TFT
Task File Table (BS2000)

@item TFT
Thin Film Transistor (LCD)

@item TFTP
Trivial File Transfer Protocol (UDP, RFC 1350/1782/1783/1784/1785)

@item TFTR
Trivial File Transfer Protocol

@item TGC
Terminal Group Controller

@item TGMS
TransGear Media Server (Transgear)

@item THAMA
Trident Hardware-Assisted MPEG-2/AC-3 (Trident, MPEG, DVD, AC-3)

@item THD
Total Harmonic Distortion (audio)

@item THDN
Total Harmonic Distortion plus Noise (audio), "THD+N"

@item THE
Technische Hoogeschool Eindhoven (OS), "T.H.E."

@item THE
The Hessling Editor

@item THENET
Texas Higher Education NETwork (network, USA), "THEnet"

@item THP
Transparent Huge Pages (Linux)

@item THT
Token Holding Timer (FDDI, Token Ring)

@item THUMS
Total HUman Model for Safety (Toyota, VPD)

@item TI
Technical Interchange (conference, IBM)

@item TI
Texas Instruments (manufacturer)

@item TIA
Telecommunications Industries Association (org.)

@item TIA
Thanks In Advance (slang, Usenet, IRC)

@item TIA
The Internet Adapter [software]

@item TID
Technical Information Document (Novell)

@item TID
Touch Interactive Display

@item TIDL
Tool Integration Description Language (JCF)

@item TIDSE
Techniken fuer Interaktives Storytelling und Entertainment (conference, ZGDV)

@item TIE
Terminal Interface Equipment

@item TIES
Time Independent Escape Sequence (MODEM)

@item TIFF
Tag / Tagged Image File Format (Aldus)

@item TIGA
Texas Instruments Graphics Adapter (Texas Instruments)

@item TIIAP
Telecommunications and Information Infrastructure Assistance Program (USA)

@item TIL
Tech Info Library (Apple, WWW)

@item TIM
Thermal Interface Material (CPU)

@item TIM
Token Interface Module (Token Ring)

@item TIMTOWTDI
There Is More Than One Way To Do It (PERL)

@item TIMTOWTDI
There Is More Than One Way To Do It (PERL, slang)

@item TINA
Telecommunication Information Network Agent (IN)

@item TINA
Telecommunication Information Networking Architecture (IN)

@item TINAC
TINA Consortium (org., IN, TINA), "TINA-C"

@item TINC
There Is No Cabal! (slang, Usenet, Linux, Debian)

@item TINYTP
Tiny Transport Protocol (IRDA)

@item TIP
Terminal Interface Processor (ARPANET)

@item TIP
Transputer Image Processing

@item TIPC
Texas Instruments Personal Computer (TI)

@item TIPC
Transparent Inter Process Communication [protocol]

@item TIPHON
Telecommunications and Internet Protocol Harmonization Over Networks (ETSI, WG)

@item TIPS
Truevision Image Paint Software (TI)

@item TIS
Thai Industrial Standard

@item TIS
Tools Interface Standard [committee] (org., IBM, Lotus, MS, Watcom, SCO, Unix)

@item TIS
TPM Interface Specification (TPM)

@item TISN
Tokyo International Science Network (network)

@item TITN
Traitement de l'Information-Techniques Nouvelles (manufacturer, France)

@item TK
TeleKommunikation

@item TK
Temporal Key (FPK)

@item TKIP
Temporal Key Integrity Protocol (WEP, WLAN, WPA)

@item TKO
TeleKommunikationsOrdnung

@item TKUEV
Telekommunikations-UEberwachungsverordnung Germany

@item TKV
TeleKommunikationsVerordnung

@item TL
Telecommunication Leadership [standard] (QuEST)

@item TL
Transform and Lighting (3D), "T&L"

TL;DR        Too Long; Didn't Read (slang, Usenet, IRC)

@item TLA
Three Letter Acronym (slang)

@item TLAP
Token ring Link Access Protocol (LAP)

@item TLB
Translation Lookaside Buffer (CPU)

@item TLD
Top Level Domain (Internet, ICANN.)

@item TLDP
The Linux Documentation Project (Linux)

@item TLER
Time Limited Error Recovery (WD, RAID)

@item TLG
TeleDiensteGesetz Germany

@item TLI
Transport Layer Interface

@item TLI
Transport Level Interface (AT&T)

@item TLN
Trunk Line Network

@item TLP
Thread Level Parallelism (CPU)

@item TLP
Transactional Licensing Program (Adobe)

@item TLP
Transmission Level Point

@item TLS
Thread Local Storage

@item TLS
Transport Layer Security [protocol] (SSL, TCP)

@item TLSP
Transport Layer Security Protocol (ISO)

@item TLV
Type - Length - Value

@item TLVTTL
Terminated Low Voltage Transistor Transistor Logic

@item TM
TeleMail (BBS, Berlin, Germany, telecommunication)

@item TM
Terminal Manager (Bull, DSA)

@item TM
Tools for MIME (EMACS, GNU, MIME)

@item TM
TradeMark

@item TM
Traffic Management

@item TM
Transaction Monitor (TP)

@item TM
Turing Machine

@item TMA
Thinfilm Micromirror Array

@item TMC
Taiwan Mycomp Corporation (manufacturer)

@item TMC
Thinking Machines Corporation (manufacturer)

@item TMC
Traffic Message Channel (GPS)

@item TMCC
Time-Multiplexed Communication Channel

@item TMCL
Topic Map Constraint Language (XTM, TMQL)

@item TMDB
Tivoli Management Data Base (Tivoli, DB)

@item TMDS
Transition Minimized Differential Signaling (VESA, LCD, DVI)

@item TMDS
Transmission Minimized Digital Signal

@item TME
Telocator Message Entry [protocol] (SNPP)

@item TME
Tivoli Management Environment (Tivoli)

@item TMF
Tivoli Management Framework (Tivoli)

@item TMF
Transaction Monitoring Facility (DB, Tandem)

@item TMG
TestMusterGenerator (IC)

@item TMG
The Master Genealogist

@item TMN
Telecommunication Management Network (IN)

@item TMP
Test Management Protocol

@item TMPDU
Test Management Protocol Data Unit (ISO 9646-1, PDU), "TM-PDU"

@item TMQL
Topic Map Query Language (XTM, TMCL)

@item TMR
Transient Memory Record

@item TMR
Triple Modular Redundancy

@item TMS
Telecommunications / Telephone Management System

@item TMS
Test Mode Select (TAP, IC)

@item TMS
Time Multiplexed Switch

@item TMS
Truth Maintenance System (AI)

@item TMSC
Tape Mass Storage Control (DEC)

@item TMSCP
Tape Mass Storage Control Protocol

@item TMSI
Temporary Mobile Subscriber Identity (MM, GSM, mobile-systems)

@item TMSS
[LambdaManager] Terabit MultiService Switch (Lucent, LambdaXtreme, BIT)

@item TMTO
Time Memory Trade-Off

@item TMTOWTDI
There's More Than One Way To Do It (slang, PERL)

@item TMU
Time Measurement Unit

@item TMUX
Transport MUltipleXing protocol (RFC 1692), "TMux"

@item TN
Terminal Node

@item TNC
Terminal Node Controller

@item TNC
Threaded Neill Concelman [connector]

@item TNC
Trusted Network Connect (TCG)

@item TNEF
Transportation Neutral Encapsulation Format (MAPI, MIME, MS)

@item TNFS
Trusted Network File System (NFS)

@item TNL
Technical NewsLetter (IBM)

@item TNLCD
Twisted Nematic Liquid Crystal Display (LCD), "TN-LCD" 

@item TNMOC
The National Museum Of Computing (org., UK)

@item TNPC
Taiwanese New Pc Consortium (org., Taiwan)

@item TNS
Transit Network Selection

@item TNTC
Too Numerous To Count (slang, Usenet, IRC)

@item TNVIP
TelNet Visual Information Projection [protocol] (TELNET, VIP, RFC 1921)

@item TO
Template Object (Typo3)

@item TOA
Target of Authentication (CC)

@item TOB
T-Online Billing (T-Online)

@item TOC
Table Of Contents (CD)

@item TODS
Transactions on Database Systems (ACM, DB)

@item TOE
Target of Evaluation (CC)

@item TOE
TCP/IP Offline Engine (TCP/IP, IC)

@item TOEM
Technical Original Equipment Manufacturer

@item TOFU
Text Over, Full-quote Under (slang, Usenet)

@item TOKREUI
TOKen-Ring Extended User Interface (IBM, Token Ring)

@item TOLD
Trebor's Obnoxious Lunchmeat Detector (SPAM, Mac, Eudora)

@item TOM
T-Online Messenger (T-Online, IM)

@item TOMS
Transactions on Mathematical Software (ACM)

@item TOOIS
Transactions on Office Information Systems (ACM)

@item TOOL
[conference on] Technology of Object-Orientated Languages and Systems (OOP, conference)

@item TOP
Technical and Office Protocols

@item TOP
The OS-9 Project (OS-9)

@item TOPICS
Total On-Line Program and Information Control System

@item TOPLAS
Transactions on Programming Languages and Systems (ACM)

@item TOPS
Timesharing / Total OPerating System (DEC, OS)

@item TOS
Tape Operating System (OS, RCA Spectra 70)

@item TOS
Teletype Operating System (OS, Microdata)

@item TOS
The Operating System (Atari, OS)

@item TOS
Tramiel Operating System (Atari, OS)

@item TOS
Type Of Service (IP)

@item TOS360
Tape ??? Operating System /360 (IBM, S/360, OS), "TOS/360"

@item TOSMAPDS
TOShiba Microprocessor Aided Power system control - DynaStream (DCS, Toshiba), "TOSMAP-DS"

@item TOT
Time Offset Table (DVB)

@item TOT
Totally Off-Topic (slang, Usenet, IRC)

@item TP
Transaction Processing

@item TP
Turbo Pascal (Borland)

@item TP
Twisted Pair [cable] (LAN)

@item TP0
Transport Protocol class 0 (OSI)

@item TP4
Transport Protocol class 4 (OSI)

@item TPA
Third Party Applications

@item TPA
Transient Program Area (DOS)

@item TPC
The PERL Conference (PERL)

@item TPC
Transaction Processing Council (org., manufacturer, DB)

@item TPC
Transmit Power Control (HiperLAN/2, WLAN)

@item TPCC
Third Party Call Control

@item TPCC
TPC benchmark C (TPC), "TPC-C"

@item TPCE
TPC benchmark E (TPC), "TPC-E"

@item TPCH
TPC benchmark H (TPC), "TPC-H"

@item TPCW
TPC benchmark W (TPC, WWW), "TPC-W"

@item TPD
Technical Product Documentation

@item TPDDI
Twisted Pair Distributed Data Interface (FDDI, STP, Chipcom)

@item TPDU
Transport Protocol Data Unit (OSI, OSI/RM, PDU, ICC)

@item TPE
Twisted Pair Ethernet (ethernet)

@item TPF
Transaction Processing Facility (IBM, MVS/XA)

@item TPI
Tracks Per Inch (HDD)

@item TPM
Traditional Power Management

@item TPM
Transactions-Per-Minute

@item TPM
Trusted Platform Module (TCPA)

@item TPMS
Transaction Processing Management System

@item TPPMD
Twisted Pair Physical layer Medium Dependent (FDDI), "TP-PMD" 

@item TPQ
True Phone Quality (CAT)

@item TPR
Task Priority Register (IC)

@item TPRM
Transaction Programmer's Reference Manual (Sun)

@item TPS
TeleProcessing Systeme [gmbh] (provider)

@item TPS
Transaction Processing System

@item TPS
Transactions Per Second (DB, DBMS)

@item TPT
Twisted Pair Transceiver

@item TPU
Turbo Pascal Unit (TP, Borland)

@item TPW
Turbo Pascal for Windows (Borland)

@item TQ
Tagged Queuing (SCSI, HDD)

@item TR
Task Register (CPU, Intel, assembler, IC)

@item TR
Technical Report (DSL-Forum, WT)

@item TRAP
Tandem Recursive Algorithm Process

@item TREC
Text REtrieval Conference (Konferenz)

@item TREC
Texture and Rendering Engine Compression

@item TRIB
Transfer Rate of Information Bits (BIT)

@item TRIF
Tiled Raster Interchange Format

@item TRILL
Transparent Interconnection of Lots of Links (RFC 5556)

@item TRIP
Telephony Routing over IP (IP, RFC 3219)

@item TRIPS
Trade Related aspects of Intellectual Property rightS (GATT)

@item TRIZ
Teorija Reschenija Isobretatelskich Zadatsch

@item TRM
Technical Reference Model

@item TRMM
Token Ring Management Module (Token Ring)

@item TRNG
True Random Number Generator

@item TROFF
Typesetter New Run-OFF (Unix)

@item TROLI
Token Ring Optimized Link Interface (Token Ring)

@item TRON
The Realtime Operating system Nucleus

@item TRP
Token Ring serial Port

@item TRR
Token Ring Repeater

@item TRT
The Right Thing (slang, Usenet, IRC)

@item TRT
Token Rotation Timer (FDDI, Token Ring)

@item TS
Time Slot

@item TS
Time Stamp

@item TS
Traffic Shaping

@item TS
Transport Stream

@item TS
TriState (IC)

@item TSA
Target Service Agent (Novell, Netware, SMS)

@item TSA
Telecommunication Society of Australia (org., Australia)

@item TSAD
Transmit Service Availability Data (CIU, IBM)

@item TSANET
Technical Support Alliance NETwork (org., manufacturer, Lotus, Oracle, HP, ...), "TSANet"

@item TSAP
Transport Service Access Point (OSI, OSI/RM, SAP)

@item TSAPI
Telephony Server Application Programmer Interface (AT&T, Novell, API)

@item TSC
Time Stamp Counter (IC, Intel, Pentium)

@item TSC
Triton System Controller (Intel, Triton, IC)

@item TSCT
Tangan Silence Control Technology (Tangan)

@item TSD
Ton-Saettigung-Dunkelstufe (color system)

@item TSDU
Transport Service Data Unit (OSI, OSI/RM)

@item TSE
[Windows] Terminal Server Edition] (Windows, MS)

@item TSE
Technical Support Engineer (Sun)

@item TSE
TestSteuerEinheit (IC)

@item TSEE
Technical System Engineering Environment (Westmount, CASE)

@item TSF
TOE Security Functions (CC, TOE)

@item TSFE
TypoScript Front End (Typo3)

@item TSI
Time Slot Interchanger

@item TSIG
Trusted Systems Interoperability Group (org.)

@item TSM
Text Service Manager (Apple)

@item TSM
Time Sharing Monitor (OS, IBM)

@item TSM
Tivoli Storage Manager (Tivoli, IBM)

@item TSM
Topology Specific Module (ODI)

@item TSMC
Taiwan Semiconductor Manufacturing Company (manufacturer, Taiwan)

@item TSMP
True Symmetric MultiProcessor

@item TSN
Task Sequence Number (BS2000)

@item TSO
Telecommunications Service Order

@item TSO
Time Sharing Option

@item TSOCMS
Time Sharing Option/Conversational Monitor System (IBM, VME), "TSO/CMS"

@item TSOE
Time Sharing Option/Extensions (IBM), "TSO/E"

@item TSOP
Thin Small Outline Package (DRAM, IC)

@item TSP
Texture and Shading Processor (IC, graphics)

@item TSP
Time Synchronization Protocol

@item TSP
Travelling Salesman Problem

@item TSP1
Test Synchronization Protocol 1+ (TTCN, ETSI), "TSP1+"

@item TSPI
TAPI Service Provider Interface (TAPI)

@item TSR
Terminate and Stay Resident

@item TSS
Task State Segment (Intel)

@item TSS
Time-Sharing System

@item TSSDC
Task State Segment Descriptor Cache (CPU)

@item TSST
Toshiba Samsung Storage Technologies (manufacturer)

@item TSTN
Triple SuperTwisted Nematic (LCD)

@item TSTS
Transaction and Switching and Transport Services (BELLCORE)

@item TSW
TeleSoftWare (T-Online)

@item TSX
TimeSharing eXecutive (OS, IBM, IBM 1800)

@item TTCAN
Time Triggered Communication on Controller Area Network (CAN)

@item TTCN
the Tree and Tabular Combined Notation (OSI, IUT)

@item TTF
TrueType Font

@item TTFF
Time To First Fix (GPS)

@item TTFN
Ta-Ta For Now (slang, Usenet, IRC)

@item TTG
Transmit Time Gap

@item TTKC
The Thursday Killers Clan (user group)

@item TTL
TietoTekniikan Liitto [ry] (org., Finland)

@item TTL
Time To Live (IP)

@item TTL
Transistor Transistor Logic

@item TTLS
Tunneled Transport Layer Security [protocol] (TLS, SSL, WLAN)

@item TTML
Tagged-Text Markup Language (Nokia, mobile-systems)

@item TTP
Time Triggered Protocol

@item TTP
Tiny Transmission Protocol (IRDA, IRLMP)

@item TTP
Trusted Third Parties (cryptography)

@item TTRP
Time Token Rotation Protocol (FDDI)

@item TTRT
Target Token Rotation Time (FDDI)

@item TTS
Text To Speech [system]

@item TTS
Transaction Tracking System (DB, Netware)

@item TTS
Trouble Ticketing System

@item TTW
Through The Web (WWW, ZMI, ZOPE)

@item TTY
TeleTYpe

@item TTYL
Talk To You Later (slang, Usenet, IRC)

@item TUB
Technische Universitaet Berlin (org.)

@item TUBA
TCP and UDP with Bigger Addresses (TCP, UDP, RFC 1347)

@item TUC
Total User Cell count (UNI)

@item TUCAA
The Ultimate Computer Acronyms Archive (Internet, WWW)

@item TUCD
Total User Cell Difference (UNI)

@item TUE
Trusted User Engine (NGSCB, MS, Palladium)

@item TUG
TeX User's Group (org., user group, TeX)

@item TUI
Text-Based User Interface (UI)

@item TUM
Technische Universitaet Muenchen (org.)

@item TUNIS
Toronto UNIversity System (OS)

@item TUP
Telephone User Path (ISDN)

@item TUT
Transistor Under Test

@item TUX
Torvalds UniX (Linux), "Tux"

@item TVOL
TV OnLine cable service (WorldGate, Internet)

@item TVOS
Terminal Velocity Operating System (3drealms)

@item TVS
Transparent Voice Signalling (VOFR)

@item TVST
TeilnehmerVermittlungsSTelle (DTAG), "TVSt"

@item TWAIN
Technology Without An Important Name

@item TWB
Terrestrial Wide-Band [networking]

@item TWINKLE
The Weizman INstitute Key Locating Engine (cryptography)

@item TWIP
[one] TWentIeth of a Point [1 inch = 72 points] (DTP)

@item TWOS
Time Warp Operating System (OS, Hypercube)

@item TXGA
Tesselar XGA [1920x1400] (XGA)

@item TXT
Trusted eXecution Technology (AMT)

@item TXTRR
TXT Resource Record (DNS, RFC 1035), "TXT-RR"

@item TZ
Time Zone (Internet, TZ)

@end table

