@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2014 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item L1
Level 1 [cache]

@item L2
Level 2 [cache]

@item L2F
Layer 2 Forwarding [protocol] (Shiva, Cisco, IP, IPX, LLC)

@item L2TP
Layer 2 Tunneling Protocol (PPP, VPN, IP, RFC 2661)

@item L3VPN
Layer 3 Virtual Private Network (VPN)

@item LA
[MPEG] Licensing Administration (MPEG)

@item LA
Limited Availability (IBM, OS/2)

@item LA
Location Area (MSC, GSM, mobile-systems)

@item LAC
Lotus Authorized Consultants (Lotus)

@item LACNIC
Latin American and Caribbean Internet Addresses Registry (org., Internet)

@item LACP
Link Aggregation Control Protocol (IEEE 802.3ad, IEEE 802.1ax)

@item LADSPA
Linux Audio Developer's Simple Plug-in API (Linux, API)

@item LADT
Lexikon der Abkuerzungen in der Datentechnik und Telekommunikation (WWW)

@item LADT
Local Access Data Transport

@item LAEC
Lotus Authorized Education Center (Lotus)

@item LAG
Logical Address Group (ION)

@item LAM
Local Area Multicomputer (Parallel Computing)

@item LAME
LAME Ain't an MP3 Encoder (MP3)

@item LAMP
Linux, Apache, MySQL, PHP (Linux, Apache, PHP, DB, SQL)

@item LAMPP
Linux, Apache, MySQL, PHP and PERL (Linux, Apache, DB, SQL, PHP, PERL)

@item LAN
Local Area Network (LAN)

@item LANANA
Linux Assigned Names And Numbers Authority (Linux, org.)

@item LANCE
LAN Controller for Ethernet (LAN)

@item LANE
Local Area Network Emulation [over ATM specification] (ATM)

@item LANL
Los Alamos National Laboratory (org., USA)

@item LAP
LAN Access Profile (Bluetooth, SPP, LAN)

@item LAP
Link Access Procedure / Protocol (CCITT, X.25)

@item LAPACK
Linear Algebra PACKage (FORTRAN)

@item LAPB
Link Access Procedure - Balanced (CCITT, LAP, X.25)

@item LAPD
Link Access Procedure on the D channel (X.21, ISDN, TA)

@item LAPIC
Local Advanced Programmable Interrupt Controller (PIC)

@item LAPM
Link Access Procedure for Modem

@item LAPS
LAN Adapter and Protocol Support

@item LASER
Light Amplification by Stimulated Emission of Radiation

@item LASS
Local Area Signaling Service

@item LAT
Local Area Transport (DEC)

@item LATA
Local Access Transport Area

@item LATM
Local Asynchronous Transfer Mode

@item LAVAS
LAger- und VersandAbwicklungsSystem (MBAG)

@item LAVC
Local Area VAX Cluster (VAX, DEC)

@item LAW
Local Authority Workstation

@item LAWN
Local Area Wireless Network

@item LBA
Logical Block Addressing (EIDE)

@item LBAC
Label Based Access Control (DB2, Informix, DB)

@item LBCAST
Lateral Buried Charge Accumulator and Sensing Transistor array (Nikon, photo)

@item LBM
Local Bus Master

@item LBN
Logical Block Number (LBA)

@item LBR
Last Branch Recording (Intel, CPU, IC)

@item LBS
Location Based Service (mobile-systems)

@item LBT
Local Bus Targets

@item LBX
Low-Band with X

@item LC
Linux Computer (Corel)

@item LC
Loopback Capability (UNI, ATM, OAM)

@item LCA
[Sair] Linux [and GNU] Certified Administrator (Linux, GNU, Unix)

@item LCA
Logic Cell Array

@item LCC
Local Control Center

@item LCCM
LAN Client Control Manager (IBM, LAN)

@item LCD
Liquid-Crystal Display (LCD)

@item LCD
LISP Code Directory (EMACS)

@item LCD
Loss of Cell Delineation (UNI, ATM)

@item LCG
LHC Computing Grid [old term] (WLCG, CERN)

@item LCGI
Local Common Graphics Interface (CGI, WWW)

@item LCM
LEAF Creation Method (EES, cryptography)

@item LCN
Local Control Network (Issendorf)

@item LCN
Logical Channel Numbers

@item LCOS
Liquid Crystal On Silicon (LCD)

@item LCP
[PPP] Link Control Protocol (PPP, RFC 1570)

@item LCP
[Sair] Linux [and GNU] Certified Professional (Linux, GNU, Unix)

@item LCR
Least Cost Routing

@item LCS
Laboratory for Computer Science (MIT)

@item LCS
Linux Compatibility Standard (Linux)

@item LCS
Liquid Crystal Shutter

@item LCS
Lotus Communication Server

@item LCSS
Liquid Crystal Stereoscopic Shutter [display]

@item LCT
Last Compliance Time (GCRA)

@item LCU
LAN CID Utility (LAN, CID, IBM)

@item LCV
Line Coding Violation [error event] (DS1/E1, DS3/E3)

@item LD
LAN Destination (ATM)

@item LDA
Local Delivery Agent

@item LDAP
Lightweight Directory Access Protocol (RFC 1777, X.500, DS, AD, CORBA)

@item LDAPAPI
Lightweight Directory Access Protocol Application Program Interface (LDAP, RFC 1823, API), "LDAP API"

@item LDCM
LANDesk Client Manager

@item LDD
Lightly Doped Drain (IC, MOSFET)

@item LDDM
Longhorn Display Driver Model (MS, Windows, Vista)

@item LDID
Logical Disk IDentifier (MS)

@item LDP
Label Distribution Protocol (IETF, RFC 3036, MPLS)

@item LDP
Linux Documentation Project (Linux)

@item LDP
Loader Debugger Protocol (RFC 909)

@item LDPC
Low Density Parity Check Codes (WIMAX, 802.16e)

@item LDR
Light Detect Resistor

@item LDS
	Lightweight Directory Services (AD, MS)

@item LDT
Lightning Data Transfer [bus] (AMD)

@item LDT
Local Descriptor Table (CPU, Intel)

@item LDTR
Load Descriptor Table Register (CPU, Intel, assembler, IC)

@item LDTRC
Local Descriptor Table Register Cache (LDT, Intel, CPU)

@item LDVA
LaenderDatenVerareitungsAnlage

@item LDW
Lane Departure Warning (car)

@item LE
LAN Emulation (LANE, ATM)

@item LEA
Law Enforcement Agency (ETSI, ETSI 201 671)

@item LEAF
Law Enforcement Access Field (EES, cryptography)

@item LEAP
Lightweight Extensible Authentication Protocol (Cisco, EAP, cryptography, WLAN)

@item LEARP
LAN Emulation Address Resolution Protocol (LANE, ARP, ATM), "LE-ARP"

@item LEAS
LATA Equal Access System

@item LEC
LAN Emulation Client (LANE, ATM)

@item LEC
Layered Error Correction (CD)

@item LEC
Local Exchange Carrier (FCC, LATA, IEC)

@item LECID
LAN Emulation Client IDentifier (LANE, ATM, LEC)

@item LECS
Local area network Emulation Configuration Server (ATM, LANE, LEC)

@item LED
Light-Emitting Diode

@item LEDBAT
Low Extra Delay BAckground Transport

@item LEI
Lotus Enterprise Integrator (Lotus)

@item LEL
Link, Embed and Launch (UNIX)

@item LELA
Linksys EasyLink Advisor

@item LEMP
Lightning ElectroMagnetic Pulse

@item LEN
Loi pour la confiance dans l'Economie Numerique (France)

@item LEN
Low Entry Networking (IBM, SNA, PU)

@item LENS
Laser Engineered Net-Shaping

@item LEO
LeitungsEndgeraet, Optisch Mil., Germany

@item LEO
Link Everything Online (WWW, TUM)

@item LER
Last Exception Record (MSR, Intel, CPU)

@item LES
LAN Emulation Server (LANE, ATM)

@item LES
Line Errored Seconds (DS1/E1, DS3/E3)

@item LF
Line Feed (ASCII)

@item LF
Login Facility (DCE)

@item LFA
Link Field Address (Forth)

@item LFA
Local Feature Analysis

@item LFAP
Light-weight Flow Admission Protocol (Cabletron, RFC 2124)

@item LFB
Linear Frame Buffer (CPU, VESA)

@item LFCC
Linux Federation for Commercial Customers (Linux)

@item LFE
Low Frequency Effect (audio)

@item LFG
Looking For Group (MMORPG, slang, GLF)

@item LFN
Long File Names

@item LFNBK
Long File Name BacKup (MS)

@item LFO
Low Frequency Oscillator

@item LFS
Linux From Scratch (Linux, org.)

@item LFS
Log-Structured File System (FS)

@item LFS
Loopback File System

@item LFSR
Linear Feedback Shift Register (IC)

@item LFU
Least Frequently Used

@item LG
Liebe Gruesse (slang, Usenet, IRC)

@item LGMR
Laser Guided Magnetic Recording

@item LGPL
Lesser General Public License (GPL, GNU)

@item LGPO
Local Group Policy Object (AD, GPO)

@item LGX
Linux/GNU/X [distribution] (Yggdrasil, Linux, GNU)

@item LHS
Left Hand Side (NGSCB, MS, Palladium)

@item LI
Lawful Interception (ETSI)

@item LIB
Linear Incremental Backoff (CSMA/CD, BEB)

@item LIC
Licensed Internal Code

@item LICCC
Licensed Internal Code Configuration Control (IBM)

@item LID
Local IDentifier (Infiniband)

@item LIDO
LInux cluster DOrtmund, "LiDO"

@item LIF
Low Insertion Force (IC)

@item LIFD
Last In First Drop

@item LIFE
Laboratory for International Fuzzy Engineering [research] (MITI)

@item LIFE
Logistics Interface For manufacturing Environment

@item LIFO
Last In First Out

@item LIJP
Leaf Initiated Join Parameter

@item LIKS
Lietuvos kompiuterininko Sajunga (org., Litauen)

@item LILO
LInux [boot] LOader (Linux)

@item LIM
Lotus - Intel - Microsoft (manufacturer)

@item LIMAD
Linear MAgnetic Drive [technology]

@item LIMDOW
Laser / Light Intensity Modulation, Direct OverWrite (MOD)

@item LIMEMS
Lotus - Intel - Microsoft Expanded Memory Specification (Lotus, Intel, MS, EMS), "LIM EMS"

@item LIMS
Lawful Interception Management System (Utimaco)

@item LIN
Local Interconnect Network [bus]

@item LINCAT
LINux Compatibility Assurance Toolkit (Linux, Sun, Solaris)

@item LINQ
Language INtegrated Query (MS, VB, C#)

@item LIP
Large Internet Packet

@item LIP
Loop Initialization Primitive (SCSI)

@item LIPKEY
Low Infrastructure Public KEY [meachanism]

@item LIPS
Logical Inferences Per Second (AI, KI, XPS)

@item LIR
Link Incident Report (Cisco)

@item LIR
Local Internet Registry (Internet)

@item LIRC
Linux Infrared Remote Control (Linux)

@item LIS
Logical IP Subnet (RFC 1577, ION)

@item LISA
Linux Installation & System Administration (Linux, LST)

@item LISA
Localization Industry Standards Association (org.)

@item LISP
LISt Processor (LISP)

@item LISP
Lots of Isolated Silly Parentheses (LISP, slang)

@item LISUAF
[thueringer] LandesInformationsSystem Umwelt, Agrar und Forst (UIS), "LIS-UAF"

@item LITA
Library and Information Technology Association (org., USA)

@item LITTA
Latvijas Informacijas Tehnologiju un Telekomunikaciju Asociacija (org., Lettland)

@item LIU
Line Interface Unit

@item LIV
Link Integrity Verification

@item LIVE
LInux VErband (Linux, org.)

@item LIVID
Language Identification and Voice IDentification

@item LIW
Long Instruction Word (CPU)

@item LKI
Labor fuer Kuenstliche Intelligenz (org., KI, Hamburg, Germany)

@item LLAP
Localtalk Link Access Protocol (AppleTalk, LAP)

@item LLATMI
Lower Layer ATM Interface (ATM)

@item LLB
Local Location Broker (NCS)

@item LLC
Logical Link Control (IEEE 802.2, ISO, OSI)

@item LLCSNAP
Logical Link Control/SubNetwork Access Protocol (LLC, SNAP), "LLC/SNAP"

@item LLMNR
Link-Local Multicast Name Resolution (IP, TCP, UDP)

@item LLN
Line Link Network

@item LLNL
Lawrence Livermore National Laboratory (org., USA)

@item LLP
Link Level Protocol (BTX)

@item LLP64
Long [32 bit], Long [32 bit], Pointer 64 [bit] (BIT)

@item LLVM
Low Level Virtual Machine [old term] (GCC)

@item LMAO
Laughing My Ass Off (slang, Usenet, IRC)

@item LMDS
Local Multi-point Distribution System

@item LME
Large Memory Enabled [devices and drivers] (DAC)

@item LME
Layer Management Entity (OSI)

@item LMFAO
Laughing My Fucking Ass Off (Usenet, IRC, slang)

@item LMI
Layer Management Interface (ATM)

@item LMML
Learning Material Markup Language

@item LMQ
Load Miss Queue (Power4, IBM, CPU)

@item LMS
Library Maintenance System (BS2000)

@item LMU
LAN Manager for Unix (Unix), "LM/U" 

@item LMX
LAN Manager for uniX (LAN, Unix, MS), "LM/X"

@item LNA
Low Noise Amplifier (GPS)

@item LNB
Line Number Block

@item LNN
Lotus Notes Network (Lotus)

@item LOC
LAN Operations Center (LAN)

@item LOC
Lines Of Code

@item LOC
Loss of Cell delineation (UNI, ATM)

@item LOCIS
Library Of Congress Information System (Internet)

@item LOCT
Layered Open Crypto Toolkit (RSA, cryptography)

@item LOD
Level Of Detail (3D)

@item LOF
Loss of Frame (UNI, ATM, DS3/E3)

@item LOL
Laughing Out Loud (slang, Usenet, IRC)

@item LOLITA
Language for the On-Line Investigation and Transformation of Abstractions

@item LOM
Laminated Object Manufacturing

@item LOM
LAN On Motherboard (LAN)

@item LON
Local Operation Network

@item LOOPS
LISP Object Oriented Programming System (Xerox, OOP, LISP)

@item LOP
Language Orientated Programming

@item LOP
Loss of Pointer (UNI)

@item LOPEC
Large-area, Organic & Printed Electronics Convention, "LOPE-C"

@item LOS
Line Of Sight (WIMAX, NLOS)

@item LOS
Local Operating System

@item LOS
Loss of Signal (UNI, ATM)

@item LOSP
LOw SPeed channel connector (Cray, I/O)

@item LOV
List Of Values (DB, Oracle, Java)

@item LOVIS
LagerOrtVerwaltungs- und InformationsSystem (MBAG)

@item LP
Line Printer (Unix)

@item LP
Linear Programming

@item LP
Logical Partition (LVM)

@item LP32
Long and Pointer 32 [bit] (BIT)

@item LPAE
Large Physical Address Extension

@item LPAN
Logical Processing Area Network

@item LPAR
[conference on] Logic for Programming, Artificial intelligence and Reasoning (AI, conference)

@item LPB
[S3] Local Peripheral Bus

@item LPC
Linear Predictive Coding (voice processing)

@item LPC
Low Pin Count [interface] (ICH)

@item LPD
Line Printer DAEMON

@item LPDA
Link Problem Determination Aid

@item LPDP
Line Printer DAEMON Protocol (RFC 1179)

@item LPDU
Link Protocol Data Unit

@item LPEX
Live Parsing eXtensible Editor (IBM, OS/2)

@item LPF
League for Programming Freedom (org.)

@item LPI
Lines Per Inch

@item LPI
Linux Professional Institute (Linux, org.)

@item LPP
Licensed Program Product (IBM)

@item LPPB
Land Pre Pit level Before [recording] (DVD-R)

@item LPPL
Latex Project Public License

@item LPR
Line Printer Remote / Request (printing)

@item LPR
Low Priority Request (VUMA)

@item LPS
Lines Per Second

@item LPS
Lotus Professional Services (Lotus)

@item LPT
Line PrinTer

@item LPX
Lean Packet eXchange (Ximeta, IDE, LAN)

@item LPX
Low Profile eXtended [motherboard/form factor]

@item LQ
Letter Quality

@item LQM
Link Quality Monitoring (PPP)

@item LR
Location Register (LA, GSM, mobile-systems)

@item LRBNI
Larrabee New Instructions (Intel)

@item LRC
Longitudinal Redundancy Check

@item LRDIMM
Load-Reduced-DIMM (DIMM, IC), "LR-DIMM"

@item LRH
Local Route Header (Infiniband)

@item LRPC
Lightweight Remote Procedure Calls (OLE)

@item LRQ
Load Reorder Queue (Power4, IBM, CPU)

@item LRS
Line Repeater Station

@item LRU
Least Recently Used

@item LRZ
Leibniz RechenZentrum (org., BADW)

@item LS
LAN Server (IBM)

@item LSA
Link State Advertisement (OSPF)

@item LSA
Lotus Solution Architecture (Lotus)

@item LSAPI
Licensed Services Application Program Interface (MS, API)

@item LSASS
Local Security Authority Subsystem Service (MS, Windows)

@item LSB
Least Significant Bit (BIT)

@item LSB
Linux Standard Base (Linux, FSG)

@item LSDU
Link Service Data Unit

@item LSE
Linux Scalability Effort (Linux)

@item LSE
Local Subscriber Environment

@item LSF
Load Sharing Facility

@item LSI
Large Scale Integration

@item LSI
Latent Semantic Indexing

@item LSL
Link Support Layer (ODI)

@item LSM
Linux Security Modules (Linux)

@item LSM
Linux Software Map (Linux)

@item LSN
Logical Sector Numbers (OS-9)

@item LSO
Linux Standards Organization (org., Linux)

@item LSP
Label Switched Path

@item LSP
Layered Service Provider (MS, Windows, TCP, UDP, NetBIOS)

@item LSPP
Labeled Security Protection Profile (CC, SELinux)

@item LSR
Leaf Setup Request

@item LST
Linux Support Team [distribution] (Linux)

@item LSU
LAN Service Unit (LAN)

@item LSU
Load/Store Unit (Power4, IBM, CPU)

@item LT
Lagrande Technology (Intel, Pentium, CPU)

@item LT
Line Termination (ADSL)

@item LT
Logical Terminal (IBM)

@item LT
Lower Tester (ISO 9646-1)

@item LTC
Line Termination Coordinator

@item LTC
Linux Technology Center (Linux, Unix, IBM)

@item LTC
Longitudinal Time Code (video)

@item LTE
Line Terminating Equipment (SONET)

@item LTE
Long Term Evolution (mobile-systems)

@item LTERM
Logical TERMinal (IBM), "LTerm"

@item LTID
Logical Terminal IDentifier (IBM)

@item LTO
Linear Tape Open (Streamer, IBM, HP, Seagate)

@item LTO
Link Time Optimization

@item LTPS
Low Temperature PolySilicon (LCD)

@item LTPSTFT
Low Temperature PolySilicon Thin Film Transistor (TFT, LCD)

@item LTS
Long Time Support

@item LTSS
Lawrence TimeSharing System (OS, LLNL)

@item LU
Logical Unit (NAU)

@item LU62
Logical Unit 6.2 (IBM), "LU6.2"

@item LUA
Least-priviledged User Account [old term] (MS, Windows, Vista, UAP)

@item LUG
Local Users Group

@item LUN
Logical Unit Number (SCSI)

@item LUNA
Leuchtendatei fuer UnfallfluchtNAchforschungen (INPOL)

@item LUNI
LANE User Network Interface (LANE, ATM)

@item LUP
Language UPgrade (MS)

@item LUT
Look-Up Table (RAMDAC, FPGA, RL)

@item LV
Logical Volume (LVM)

@item LV
Low Voltage

@item LVD
Low Voltage Differential [technology] (SCSI, Symbois Logic)

@item LVDS
Low Voltage Differential Signal (TI, NSC)

@item LVE
Live Video Extension (video)

@item LVM
Logical Volume Manager (AIX, HP/UX, OSF/1, HDD)

@item LVN
LandesVerwaltungsNetz (Baden-Wuerttemberg)

@item LVS
Layout Versus Schematic [check] (DRC, IC)

@item LVTTL
Low Voltage Transistor Transistor Level (IC)

@item LW
Living Worlds (VRML)

@item LWC
Last Working Configuration (ESCD, PNP, BIOS)

@item LWE
LinuxWorld Conference & Expo (Linux, Europe)

@item LWL
LichtWellenLeiter (cable)

@item LWP
Library for WWW in PERL (PERL, WWW)

@item LWP
Light Weight Process (Sun, OS)

@item LX
Linear eXecutable (OS/2)

@item LZS
Lempel-Ziv-Stac [compression]

@item LZSDCP
[PPP] Lempel-Ziv-Stac - Data Compression Protocol (PPP, RFC 1967), "LZS-DCP"

@item LZW
Lempel-Ziv-Welch [compression]

@end table

